#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"
##########################################################
echo "Collecting media"
mik_collect_media ORACLECOMMS_OSM_ACCOUNT_CONFIGURATION
echo "Media collected"

mik_run_remote ${OSM_HOST} ${OSM_HOST_OS_USER_NAME} ${OSM_SCRIPT_MODULE_NAME}/osm/go_prepare_osm_topology.sh ${OSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR} 
/bin/bash -c "export MIK_ASKPASS_HOST=${OSM_HOST} ; export MIK_ASKPASS_USER=${OSM_HOST_OS_USER_NAME} ; export SSH_ASKPASS=${MANAGEABLE_INSTALL_TOOL_DIR}/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${OSM_HOST_OS_USER_NAME}@${OSM_HOST}:${OSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/osm/osm_topology ${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/accounts_config/osm_topology"
source ${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/accounts_config/osm_topology

/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/aia_topology $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config"
source $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/aia_topology

if [ $OSM_CLUSTER == 0 ]
then
        LOCAL_ARCHITECTURE_TYPE=s
        SOLUTION_DEPLOYMENT_TARGET=$MSERVER_OSM_NAME_1
else
        LOCAL_ARCHITECTURE_TYPE=c
fi

if [ $IS_SOA_CLUSTERED == 0 ]
then
        SOLUTION_ACCOUNT_SAF_SERVERURLS=$MSERVER_SOA_HOSTNAME_1:$MSERVER_SOA_PORT_1
else
        SOLUTION_ACCOUNT_SAF_SERVERURLS=$MSERVER_SOA_HOSTNAME_1:$MSERVER_SOA_PORT_1
        for (( c=2; c<=${SOA_SERVER_COUNT}; c++ )); do
                host="MSERVER_SOA_HOSTNAME_"$c
                port="MSERVER_SOA_PORT_"$c
                eval hosteval='${'$host'}'
                eval porteval='${'$port'}'
                SOLUTION_ACCOUNT_SAF_SERVERURLS=$SOLUTION_ACCOUNT_SAF_SERVERURLS,$hosteval:$porteval
        done
fi

source $OSM_SUITE_DOMAIN_HOME_DIR/bin/setDomainEnv.sh
SOLUTION_OSM_SAF_PASSWORD=`$JAVA_HOME/bin/java weblogic.security.Encrypt $OSM_WEBLOGIC_ADMIN_USER_PASSWORD`

/usr/bin/unzip -q -o -d $OSM_MEDIA_DOWNLOAD_DIR/OracleComms_OSM_Account_Configuration $OSM_MEDIA_DOWNLOAD_DIR/OracleComms_OSM_Account_Configuration.zip
cd $OSM_MEDIA_DOWNLOAD_DIR/OracleComms_OSM_Account_Configuration

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/accounts_security_config.py
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo OSM_WEBLOGIC_ADMIN_USER=$OSM_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo OSM_WEBLOGIC_ADMIN_USER_PASSWORD=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo OSM_HOST=$OSM_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo OSM_ADMIN_SERVER_WEBLOGIC_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo OSM_MEDIA_DOWNLOAD_DIR=$OSM_MEDIA_DOWNLOAD_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/accounts_security_config.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/accounts_security_config.py
/bin/bash -c "export CONFIG_JVM_ARGS=\"-Djava.security.egd=file:/dev/./urandom -Dweblogic.management.confirmKeyfileCreation=true\" ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/accounts_security_config.py"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/config.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo ACCT_ADMIN_SERVER_LISTEN_ADDRESS=$OSM_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo ACCT_ADMIN_SERVER_LISTEN_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT>> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo ACCT_CLUSTER_NAME=$CLUSTER_NAME_OSM >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
echo ACCT_USER_NAME=$OSM_MEDIA_DOWNLOAD_DIR/OracleComms_OSM_Account_Configuration/config-scripts/accountsConfigFile.secure >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/config.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/config.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/map.properties
cp $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/config.properties $OSM_MEDIA_DOWNLOAD_DIR/OracleComms_OSM_Account_Configuration/config/config.properties

$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -file OSM.SolutionConfig.xml -Daia.weblogic.home=$OSM_WEBLOGIC_HOME_DIR -Dheadless.mode=true -Daia.wls.lib.dir=$OSM_WEBLOGIC_HOME_DIR/server/lib -Dwls.password=$OSM_MEDIA_DOWNLOAD_DIR/OracleComms_OSM_Account_Configuration/config-scripts/accountsKeyFile.secure  -Dsolution.deploymentTarget=$SOLUTION_DEPLOYMENT_TARGET -Darchitecture.type=$LOCAL_ARCHITECTURE_TYPE -Dsolution.account.saf.serverURLs=$SOLUTION_ACCOUNT_SAF_SERVERURLS -Dsolution.account.saf.userName=$OSM_WEBLOGIC_ADMIN_USER -Dsolution.account.saf.password=$SOLUTION_OSM_SAF_PASSWORD $ACCOUNTS_SCRIPT_TARGET
