#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

#source $THIS_DIR/../../common/knobs
if [ -z "${MIK_KNOBS_PATH}" ]
then
  MIK_KNOBS_FILE=${THIS_DIR}/../../common/knobs
  MIK_KNOBS_RELATIVE_PATH=accounts_config/common/knobs
else
  MIK_KNOBS_FILE=${THIS_DIR}/../../../${MIK_KNOBS_PATH}
  MIK_KNOBS_RELATIVE_PATH=${MIK_KNOBS_PATH}
fi
source ${MIK_KNOBS_FILE}

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"
##########################################################
userConfigTarget=$1
#--------------------------------------------------------------------------------
# Blanket Configure Shell
source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm
#--------------------------------------------------------------------------------

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config.sh
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo OSM_SDK_HOME_DIR=$OSM_SDK_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo ORACLE_HOME=$ORACLE_HOME >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo LD_LIBRARY_PATH=$LD_LIBRARY_PATH >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo JAVA_HOME=$JAVA_HOME >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo APP_ROOT=$OSM_SDK_HOME_DIR/XMLImportExport >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config.sh.template > $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config.sh
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
cp $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config.sh $OSM_SDK_HOME_DIR/XMLImportExport/config.sh
cp $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/EncryptPasswords.sh $OSM_SDK_HOME_DIR/XMLImportExport/EncryptPasswords.sh

echo CONFIG_FILE=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config/config.xml >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo DB_USER=$OSM_DB_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo DB_PASSWORD=$OSM_DB_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo OSM_WEBLOGIC_ADMIN_USER=$OSM_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo OSM_WEBLOGIC_ADMIN_USER_PASSWORD=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/expect_script.template > $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/expect_script
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties

echo OSM_DB_HOST=$OSM_DATABASE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo OSM_DB_PORT=$OSM_DATABASE_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo OSM_DB_SID=$OSM_DATABASE_SID >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo OSM_ADMIN_SERVER_WEBLOGIC_HOST=$OSM_ADMIN_SERVER_WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo OSM_ADMIN_SERVER_WEBLOGIC_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config/config.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config/config.xml
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties


chmod 750 /private/aiacom_test_install/osm/SDK/XMLImportExport/config.sh
chmod 750 /private/aiacom_test_install/osm/SDK/XMLImportExport/EncryptPasswords.sh
chmod 750 $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/expect_script

cd /private/aiacom_test_install/osm/SDK/XMLImportExport
$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/expect_script
cd -

#TODO use refresh.metadata od XMLImportExport
if [ $userConfigTarget == 'osm'  ]
   then userConfigFileLoc=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/UserConfig.xml
elif [ $userConfigTarget == 'o2a'  ]
   then userConfigFileLoc=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config/UserConfig.xml
fi
/bin/bash -c "export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -Dosm.sdk.home=$OSM_SDK_HOME_DIR -Dweblogic.admin.server.host=$OSM_ADMIN_SERVER_WEBLOGIC_HOST -Dweblogic.admin.server.port=$OSM_ADMIN_SERVER_WEBLOGIC_PORT -Dwlsadmin.user=$OSM_WEBLOGIC_ADMIN_USER -Dwlsadmin.password=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD -Doracle.middleware.home=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR -Dconfig.file=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/config/config.xml -DUserConfig.file=$userConfigFileLoc -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/build.xml assign.workgroup"

echo WEBLOGIC_ADMIN_USER=$OSM_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo WEBLOGIC_HOST=$OSM_ADMIN_SERVER_WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
echo WEBLOGIC_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
if [ $userConfigTarget == 'osm'  ]
   then echo USER=osmadmin >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
elif [ $userConfigTarget == 'o2a'  ]
   then echo USER=osm >> $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
fi
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/asign_weblogic_groups.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/asign_weblogic_groups.py
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/map.properties
/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $OSM_WEBLOGIC_HOME_DIR/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/asign_weblogic_groups.py"


/bin/bash -c "$MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/admin/do_stop_osm.sh; $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/admin/do_start_osm.sh"

