#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo CONFIGURATION FAILED" ERR
set -e
set -E
set -o pipefail

if [ -z "${MIK_KNOBS_PATH}" ]
then
  MIK_KNOBS_FILE=${THIS_DIR}/../common/knobs
  MIK_KNOBS_RELATIVE_PATH=accounts_config/common/knobs
else
  MIK_KNOBS_FILE=${THIS_DIR}/../../${MIK_KNOBS_PATH}  
  MIK_KNOBS_RELATIVE_PATH=${MIK_KNOBS_PATH}
fi


MIK_INSTALL_JAVA=1
echo "sourcing MIK_KNOBS_FILE = ${MIK_KNOBS_FILE}"
source ${MIK_KNOBS_FILE}
## OSM uses JDK 1.7, O2A uses JDK 1.8 This config_access needs to be ran to get JDK 1.8, this has to be set again MIK_INSTALL_JAVA=1!!!
## if at later time, OSM and O2A all use the same JDK version, this MIK_INSTALL_JAVA=   should leave it blank
MIK_INSTALL_JAVA=1

source ${MANAGEABLE_INSTALL_TOOL_DIR}/common/mik_lib

source ${MANAGEABLE_INSTALL_TOOL_DIR}/common/media_map

#--------------------------------------------------------------------------------
# Configure

mik_create_access ${OSM_HOST} ${OSM_HOST_OS_USER_NAME}
mik_create_su_access ${OSM_HOST} ${OSM_HOST_OS_USER_NAME}
mik_create_access ${AIA_MIDDLEWARE_HOST} ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}

mik_run_remote ${OSM_HOST} ${OSM_HOST_OS_USER_NAME} ${OSM_SCRIPT_MODULE_NAME}/osm/go_prepare_osm_topology.sh ${OSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR}
/bin/bash -c "export MIK_ASKPASS_HOST=${OSM_HOST} ; export MIK_ASKPASS_USER=${OSM_HOST_OS_USER_NAME} ; export SSH_ASKPASS=${MANAGEABLE_INSTALL_TOOL_DIR}/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${OSM_HOST_OS_USER_NAME}@${OSM_HOST}:${OSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/osm/osm_topology ${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/accounts_config/osm_topology"
source ${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/accounts_config/osm_topology
source ${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/common/osm_lib
populate_osm_servers
for i in `/usr/bin/seq 1 ${#servers[*]}`;
do
  echo "mik_create_access ${servers[i]} ${users[i]}"
  mik_create_access ${servers[i]} ${users[i]}
done
mik_run_remote $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME accounts_config/accounts_config/prepare_aia_topology.sh $AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR
/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/aia_topology $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config"
source $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/aia_topology

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
mik_create_access $AIA_MIDDLEWARE_CLUSTER_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME
fi

mik_create_media_access ORACLECOMMS_OSM_ACCOUNT_CONFIGURATION

echo Access configured
