#!/bin/bash
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

echo "Configuration read"

#--------------------------------------------------------------------------------
# Stopping AIA Middleware

echo "Stopping AIA Middleware"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
echo WEBLOGIC_ADMIN_USER=$WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
echo AIA_WEBLOGIC_DOMAIN_NAME=$AIA_WEBLOGIC_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
MSERVER_SOA_HOSTNAME_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_HOSTNAME=\$MSERVER_SOA_HOSTNAME_${i}
  MSERVER_SOA_HOSTNAME_LIST=${MSERVER_SOA_HOSTNAME_LIST},${MSERVER_SOA_HOSTNAME}
done
echo MSERVER_SOA_HOSTNAME_LIST=${MSERVER_SOA_HOSTNAME_LIST#?} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
echo SOA_SERVER_COUNT=$SOA_SERVER_COUNT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/shutdown_wls.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/shutdown_wls.py
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/map.properties

MSERVER_SOA_NAME_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_NAME=\$MSERVER_SOA_NAME_${i}
  MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST},${MSERVER_SOA_NAME}
done
/bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py stop ${MSERVER_SOA_NAME_LIST#?}"

#if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
#   /bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py stop ${WEBPROXY_SERVER_NAME}"
#fi

/bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $WEBLOGIC_HOME_DIR/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/shutdown_wls.py"

echo "AIA Middleware stopped"
