#!/bin/bash
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

# -----------------------------------------------------------------------------
# Generate Tear Sheet

echo "-------------------------------------------------------------------------------"
echo "AIA Middleware $DEFAULT_AIA_VERSION"
echo "-------------------------------------------------------------------------------"
echo
echo "AIA Middleware $DEFAULT_AIA_VERSION"
echo "  URLs:"
echo "    http://${WEBLOGIC_HOST}:${WEBLOGIC_PORT}/em (${WEBLOGIC_ADMIN_USER}/${WEBLOGIC_ADMIN_USER_PASSWORD})"
echo "    http://${WEBLOGIC_HOST}:${WEBLOGIC_PORT}/console (${WEBLOGIC_ADMIN_USER}/${WEBLOGIC_ADMIN_USER_PASSWORD})"
echo "  Host: ${WEBLOGIC_HOST} (${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`)"
echo "  Logs:"
echo "    ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBLOGIC_HOST}:${AIA_WEBLOGIC_DOMAIN_HOME_DIR}/servers/AdminServer/logs/AdminServer.log"
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MANAGED_SERVER_NAME=\$MSERVER_SOA_NAME_${i}
  eval MANAGED_SERVER_HOSTNAME=\$MSERVER_SOA_HOSTNAME_${i}
  echo "    ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${MANAGED_SERVER_HOSTNAME}:${AIA_WEBLOGIC_DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/logs/${MANAGED_SERVER_NAME}.log"
done
echo "  Admin:"
echo "    ${MANAGEABLE_INSTALL_TOOL_DIR}/$AIA_SCRIPT_MODULE_NAME/admin/start_aiamw.sh"
echo "    ${MANAGEABLE_INSTALL_TOOL_DIR}/$AIA_SCRIPT_MODULE_NAME/admin/stop_aiamw.sh"
echo "  AIA Middleware domain home: ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBLOGIC_HOST}:${AIA_WEBLOGIC_DOMAIN_HOME_DIR}/servers/AdminServer/"
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
  echo "  $SOA_SERVER_COUNT SOA Managed Servers are CLUSTERED:-"
else
  echo "  SOA Managed Server is NON-CLUSTERED:-"
fi
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MANAGED_SERVER_NAME=\$MSERVER_SOA_NAME_${i}
  eval MANAGED_SERVER_PORT=\$MSERVER_SOA_PORT_${i}
  eval MANAGED_SERVER_MACHINE_NAME=\$MSERVER_SOA_MACHINE_NAME_${i}
  eval MANAGED_SERVER_HOSTNAME=\$MSERVER_SOA_HOSTNAME_${i}
  echo "    ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${MANAGED_SERVER_HOSTNAME}:${AIA_WEBLOGIC_DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/"
done
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
  #echo "  WebProxy Details:"
  #echo "    ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBPROXY_SERVER_HOSTNAME}:${AIA_WEBLOGIC_DOMAIN_HOME_DIR}/servers/${WEBPROXY_SERVER_NAME}/"
  echo "  Oracle HTTP Server Details:"
  echo "    ${OHS_HOST_OS_USER_NAME}/`mik_getsec ${OHS_HOST} ${OHS_HOST_OS_USER_NAME}`@${OHS_HOST}:${WEBTIER_ORACLE_HOME_DIR}"
  echo "    OHS Port - ${OHS_PORT}"
fi
# TODO get from remote host
#  echo "    {`/bin/more /etc/oracle-release` (`/bin/uname -m`)}"
# TODO DB schemas and passwords
echo
echo "Oracle Database $DEFAULT_DATABASE_VERSION"
echo "  ${DATABASE_HOST}:${DATABASE_PORT}:${DATABASE_GLOBAL_NAME}"
echo "  Host: ${DATABASE_HOST} (${DATABASE_HOST_OS_USER_NAME}/`mik_getsec ${DATABASE_HOST} ${DATABASE_HOST_OS_USER_NAME}`)"
echo "  SYS user: sys/${DATABASE_SYS_USER_PASSWORD}"
echo "  SYSTEM user: system/${DATABASE_SYS_USER_PASSWORD}"
echo "  Oracle home: ${DATABASE_HOST_OS_USER_NAME}/`mik_getsec ${DATABASE_HOST} ${DATABASE_HOST_OS_USER_NAME}`@${DATABASE_HOST}:${DATABASE_ORACLE_HOME_DIR}/"
# TODO get from remote host
#  echo "    {`/bin/more /etc/oracle-release` (`/bin/uname -m`)}"
echo
echo "Manageable Install Kit $RODOD_INSTALL_KIT_VERSION"
echo "  Working MIK home: `/usr/bin/id -un`@`/bin/hostname -f`:${MANAGEABLE_INSTALL_TOOL_DIR}/"
echo "  AIA Middleware MIK home: ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBLOGIC_HOST}:${WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR}/"
echo "  DB MIK home: ${DATABASE_HOST_OS_USER_NAME}/`mik_getsec ${DATABASE_HOST} ${DATABASE_HOST_OS_USER_NAME}`@${DATABASE_HOST}:${DATABASE_HOST_MANAGEABLE_INSTALL_TOOL_DIR}/"
echo "-------------------------------------------------------------------------------"
