#!/bin/bash
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



echo "Reading configuration"

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`
source $THIS_DIR/../common/knobs

echo "Configuration read"

# Verify command line parameters
if [ $# -ne 4 ]; then
	echo "Usage: $0 hostName machineName domainLocation nmPort"
	exit 1
fi
export HOST_NAME=$1
export MACHINE_NAME=$2
export DOMAIN_LOCATION=$3
export nmPort=$4

# Verify we are running on desired host
TMPFILE=`mktemp -t checkhost.XXXXXXXXXX` || exit 1
#hostname | grep ${HOST_NAME} >> $TMPFILE
hostname -f | grep ${HOST_NAME} >> $TMPFILE
if [ ! -s $TMPFILE ]; then
	rm -f $TMPFILE
	echo "Running on "`hostname`" but expected "${HOST_NAME}".  Exiting."
	exit
fi
rm -f $TMPFILE

# Create node manager home directory for this host
export THIS_NM_HOME=${WEBLOGIC_HOME_DIR}/common/nodemanager/${HOST_NAME}
#export THIS_NM_HOME=${WEBLOGIC_HOME_DIR}/common/nodemanager

if [ ! -e ${THIS_NM_HOME}/startNodeManager.sh ]; then
	mkdir -p ${THIS_NM_HOME}

	# Copy nodemanager.domains and startNodeManager.sh
	rm -rf ${THIS_NM_HOME}/*
	cp ${DOMAIN_LOCATION}/nodemanager/nodemanager.domains ${THIS_NM_HOME}
	cp ${WEBLOGIC_HOME_DIR}/server/bin/startNodeManager.sh ${THIS_NM_HOME}

	$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/update_config.sh "replaceexactstring" "startNodeManager.sh"  ${THIS_NM_HOME} ${THIS_NM_HOME} '${WL_HOME}/../oracle_common/common/nodemanager'
	chmod 771 ${THIS_NM_HOME}/startNodeManager.sh 

	# Create nodemanager.properties	
	touch ${THIS_NM_HOME}/nodemanager.properties
	echo "NodeManagerHome=${THIS_NM_HOME}" >> ${THIS_NM_HOME}/nodemanager.properties
	echo "ListenAddress=${HOST_NAME}" >> ${THIS_NM_HOME}/nodemanager.properties
	echo "ListenPort=${nmPort}" >> ${THIS_NM_HOME}/nodemanager.properties
	echo "SecureListener=false" >> ${THIS_NM_HOME}/nodemanager.properties
	echo "StartScriptEnabled=true" >> ${THIS_NM_HOME}/nodemanager.properties
	echo "StopScriptEnabled=true" >> ${THIS_NM_HOME}/nodemanager.properties
	echo "QuitEnabled=true" >> ${THIS_NM_HOME}/nodemanager.properties
	echo "DomainDirRemoteSharingEnabled=true" >> ${THIS_NM_HOME}/nodemanager.properties

	# Update domain with NM
	${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureNodeManager.py ${MACHINE_NAME} ${DOMAIN_LOCATION} ${HOST_NAME} ${nmPort}

	# Start nodemanager
	export JAVA_OPTIONS="-DDomainRegistrationEnabled=true"
	echo "Starting NodeManager on ${HOST_NAME} ..."
	nohup ${THIS_NM_HOME}/startNodeManager.sh >> ${THIS_NM_HOME}/nodemanager.log 2>&1 &
	#nohup ${THIS_NM_HOME}/startNodeManager.sh &
	sleep 15
	echo "... NodeManager started on ${HOST_NAME}"
else
	#nodemanage is already set for this host. Just enroll this new server
	# Update domain with NM
	${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureNodeManager.py ${MACHINE_NAME} ${DOMAIN_LOCATION} ${HOST_NAME} ${nmPort}

fi


