#!/bin/sh
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`
source $THIS_DIR/../common/knobs
source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

#--------------------------------------------------------------------------------
# Generate Install Tool Driver Files
echo DATABASE_CLIENT_HOME_DIR=$DATABASE_CLIENT_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/map.properties
echo ORACLE_INVENTORY_DIR=$ORACLE_INVENTORY_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/map.properties
echo DATABASE_HOST_NAME=$DATABASE_HOST_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/map.properties
echo DATABASE_CLIENT_ORACLE_HOME_DIR=$DATABASE_CLIENT_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/deinstall_client.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/deinstall_client.rsp

/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/map.properties

#--------------------------------------------------------------------------------
# Shutdown AIA MW

#--------------------------------------------------------------------------------
# Clean OHS
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
    mik_run_remote $OHS_HOST ${OHS_HOST_OS_USER_NAME} $OHS_SCRIPT_MODULE_NAME/ohs/ungo.sh $MANAGEABLE_INSTALL_TOOL_DIR
fi


echo "Stopping AIA MW"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_ADMIN_USER=$WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo AIA_WEBLOGIC_DOMAIN_NAME=$AIA_WEBLOGIC_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo AIA_WEBLOGIC_DOMAIN_HOME_DIR=$AIA_WEBLOGIC_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
MSERVER_SOA_NAME_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_NAME=\$MSERVER_SOA_NAME_${i}
  MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST},${MSERVER_SOA_NAME}
done
MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST#?}
#if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
#   echo MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST},${WEBPROXY_SERVER_NAME} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
#else
#   echo MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
#fi
echo MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/stop_aiafp.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/stop_aiafp.py
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
/bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py stop $MSERVER_SOA_NAME_LIST"
/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $WEBLOGIC_HOME_DIR/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/stop_aiafp.py"

# TODO stop Derby? ${WL_HOME}/common/derby/bin/stopNetworkServer.sh

# TODO wait for down
/bin/sleep 60

echo "AIA MW stopped"

#--------------------------------------------------------------------------------
# Clean RCU respositories

$COMMON_ORACLE_HOME_DIR/bin/rcu -silent -dropRepository -databaseType ORACLE -connectString $DATABASE_HOST:$DATABASE_PORT:$DATABASE_SID -dbUser $DATABASE_SYS_USER_NAME -dbRole sysdba -variables RCU_LOG_LOCATION=$APPLICATIONS_HOME_DIR/logs -schemaPrefix $MDS_DATABASE_SCHEMA_PREFIX -component MDS -component IAU -component IAU_APPEND -component IAU_VIEWER -component OPSS -component UCSUMS -component WLS -component STB -component SOAINFRA -f < $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/rcu_password_answers

#--------------------------------------------------------------------------------
# Deinstall Database Client
$DATABASE_CLIENT_ORACLE_HOME_DIR/deinstall/deinstall -silent -paramfile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/deinstall_client.rsp

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
   #----------------------------------------
   # create list of all host names
   #----------------------------------------
   for serverType in SOA; do
        SERVER_COUNT=0
        SERVER_TYPE=$serverType
        serverCountString=$serverType"_SERVER_COUNT"
        eval SERVER_COUNT='${'$serverCountString'}'
        if [ ${SERVER_COUNT} -gt 0 ];then
           for (( c=1; c<=${SERVER_COUNT}; c++ )); do
                hostKey="MSERVER_"$SERVER_TYPE"_HOSTNAME_"$c
                eval hostVal='${'$hostKey'}'
                mhostList=$mhostList','$hostVal
           done
           mhostList=$(echo $mhostList|sed -e 's/,/ /g')
           mhostList=($mhostList)
           #echo "Found ${#mhostList[@]} hosts, ${mhostList[@]} for serverType $serverType"
        fi
   done

   #----------------------------------------
   # create list of unique host names passing allHostList
   #----------------------------------------
   declare -a uniqHostNames=`echo ${mhostList[@]}|awk '{for(i=1;i<NF+1;i++) printf "%s\n",$i}'|sort|uniq`
   uniqHostNames=$(echo ${uniqHostNames[@]}|sed -e 's/\n/ /g')
   uniqHostNames=(${uniqHostNames[@]})
      
   for currentHost in "${uniqHostNames[@]}"; do
      echo "Cleaning host $currentHost ..."
	  if [ "$currentHost" != "${WEBLOGIC_HOST}" ]; then
		echo "UnMounting the shared location on this host $currentHost"
  	   mik_run_remote $currentHost $WEBLOGIC_HOST_OS_USER_NAME $AIA_SCRIPT_MODULE_NAME/aiafp/unmountClusterSharedLoc.sh $WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR
     fi
      echo "/bin/rm -rf $WEBLOGIC_MIDDLEWARE_HOME_DIR" > clean_aiamw.sh
      echo "/bin/rm -rf $AIA_HOME_DIR" >> clean_aiamw.sh
	  echo "/bin/rm -rf $CLUSTER_SHARED_LOCATION" >> clean_aiamw.sh 
     /bin/bash -c "export MIK_ASKPASS_HOST=${currentHost} ; export MIK_ASKPASS_USER=${WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -t -o StrictHostKeyChecking=no ${WEBLOGIC_HOST_OS_USER_NAME}@$currentHost /bin/bash -s < clean_aiamw.sh"
      rm -rf clean_aiamw.sh
   done
   
   #removing the cluster mounted folder from exports
   if grep -Fxq "${CLUSTER_SHARED_LOCATION} *(rw)" /etc/exports ; then
		grep -v "${CLUSTER_SHARED_LOCATION} *(rw)" /etc/exports > temp 
		/bin/bash -c "SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' mv temp /etc/exports"
		rm -rf temp	
   fi
	
else
   /bin/rm -rf $WEBLOGIC_MIDDLEWARE_HOME_DIR
   /bin/rm -rf $AIA_HOME_DIR
fi
