#!/bin/bash
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



echo "Deployment of WebProxyApp started...."

echo "Reading configuration"

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`
source $THIS_DIR/../common/knobs

WEBINF="${AIA_WEBLOGIC_DOMAIN_HOME_DIR}/apps/WebProxyApp/WEB-INF"
mkdir -p $WEBINF
cp $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/weblogic.xml.template $WEBINF/weblogic.xml

echo "Configuration read"

echo "Generating installation driver files"

echo WEBLOGIC_ADMIN_USER=$WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBPROXY_SERVER_NAME=$WEBPROXY_SERVER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBPROXY_DEPLOY_PATH=${AIA_WEBLOGIC_DOMAIN_HOME_DIR}/apps/WebProxyApp >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
CLUSTER_ADDRESS_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_HOSTNAME=\$MSERVER_SOA_HOSTNAME_${i}
  eval MSERVER_SOA_PORT=\$MSERVER_SOA_PORT_${i}
  CLUSTER_ADDRESS_LIST="${CLUSTER_ADDRESS_LIST}|${MSERVER_SOA_HOSTNAME}:${MSERVER_SOA_PORT}"
done
echo CLUSTER_ADDRESS_LIST=${CLUSTER_ADDRESS_LIST#?} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/web.xml.template > $WEBINF/web.xml
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/deployWebProxyApp.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/deployWebProxyApp.py

/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

echo "Installation driver files generated"



/bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/deployWebProxyApp.py"

echo "....Deployment of WebProxyApp Finished"
