#!/bin/bash
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

#----------------------------------------
# create list of all host names
#----------------------------------------

declare -a mhostList
#for serverType in WSM BASE BAM SOA; do
for serverType in SOA; do

   SERVER_COUNT=0
   SERVER_TYPE=$serverType
   serverCountString=$serverType"_SERVER_COUNT"
   eval SERVER_COUNT='${'$serverCountString'}'

   echo "SERVER_TYPE = $SERVER_TYPE"
   echo "SERVER_COUNT = $SERVER_COUNT"

   if [ ${SERVER_COUNT} -gt 0 ];then
      for (( c=1; c<=${SERVER_COUNT}; c++ )); do
         hostKey="MSERVER_"$SERVER_TYPE"_HOSTNAME_"$c
         eval hostVal='${'$hostKey'}'
         mhostList=$mhostList','$hostVal
      done
      mhostList=$(echo $mhostList|sed -e 's/,/ /g')
      mhostList=($mhostList)
      #echo "Found ${#mhostList[@]} hosts, ${mhostList[@]} for serverType $serverType"
   fi

done

#----------------------------------------
# create list of unique host names
#----------------------------------------

declare -a uniqHostNames=`echo ${mhostList[@]}|awk '{for(i=1;i<NF+1;i++) printf "%s\n",$i}'|sort|uniq`
uniqHostNames=$(echo ${uniqHostNames[@]}|sed -e 's/\n/ /g')
uniqHostNames=(${uniqHostNames[@]})

echo "Found ${#uniqHostNames[@]} unique hosts, ${uniqHostNames[@]}"


for currentHost in "${uniqHostNames[@]}"; do
#check if it is local host or remote
if [ "$currentHost" != "${WEBLOGIC_HOST}" ]; then
   echo "Found remote host $currentHost ..."

   #echo "Generating installation driver files for Remote install of weblogic and SOA Suite on $currentHost"
   #eval SOA_MANAGEDSERVER_HOST=\${MSERVER_SOA_HOSTNAME_$VAR}
   echo "Installing Weblogic and SOA Suite on $currentHost"
   mik_run_remote $currentHost $WEBLOGIC_HOST_OS_USER_NAME $AIA_SCRIPT_MODULE_NAME/aiafp/install_wls_soa.sh $WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR
   echo "Completed installing Weblogic and SOA Suite on $currentHost"

fi
done

