#!/bin/sh
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

echo "Prevalidating installation environment"


echo "JAVA_HOME : $JAVA_HOME"
$JAVA_HOME/bin/java -cp $THIS_DIR/../common:$THIS_DIR/../../common prevalidate_install_aiafp $THIS_DIR/../..

echo "Installation environment prevalidated"

#--------------------------------------------------------------------------------
# Generate Install Tool Driver Files

echo "Generating installation driver files"

echo MDS_DATABASE_SCHEMA_NAME=$MDS_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo MDS_DATABASE_SCHEMA_PASSWORD=$MDS_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SOA_DATABASE_SCHEMA_NAME=$SOA_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SOA_DATABASE_SCHEMA_PASSWORD=$SOA_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SOA_DATABASE_SCHEMA_PREFIX=$SOA_DATABASE_SCHEMA_PREFIX >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SDPM_DATABASE_SCHEMA_NAME=$SDPM_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SDPM_DATABASE_SCHEMA_PASSWORD=$SDPM_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo STB_DATABASE_SCHEMA_NAME=$STB_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo STB_DATABASE_SCHEMA_PASSWORD=$STB_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo IAU_APPEND_DATABASE_SCHEMA_NAME=$IAU_APPEND_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo IAU_APPEND_DATABASE_SCHEMA_PASSWORD=$IAU_APPEND_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo IAU_VIEWER_DATABASE_SCHEMA_NAME=$IAU_VIEWER_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo IAU_VIEWER_DATABASE_SCHEMA_PASSWORD=$IAU_VIEWER_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo OPSS_DATABASE_SCHEMA_NAME=$OPSS_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo OPSS_DATABASE_SCHEMA_PASSWORD=$OPSS_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_SYS_USER_NAME=$DATABASE_SYS_USER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_SYS_USER_PASSWORD=$DATABASE_SYS_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo JAVA_HOME=$JAVA_HOME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_HOME_DIR=$WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SOA_HOME_DIR=$SOA_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo AIA_WEBLOGIC_DOMAIN_HOME_DIR=$AIA_WEBLOGIC_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo AIA_WEBLOGIC_DOMAIN_NAME=$AIA_WEBLOGIC_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_ADMIN_USER=$WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo COMMON_ORACLE_HOME_DIR=$COMMON_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_CLIENT_ORACLE_HOME_DIR=$DATABASE_CLIENT_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_CLIENT_HOME_DIR=$DATABASE_CLIENT_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_HOST=$DATABASE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_PORT=$DATABASE_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_GLOBAL_NAME=$DATABASE_GLOBAL_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_SID=$DATABASE_SID >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo DATABASE_SID_UPPERCASE=$DATABASE_SID_UPPERCASE >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_HOST_OS_GROUP_NAME=$WEBLOGIC_HOST_OS_GROUP_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo ORACLE_INVENTORY_DIR=$ORACLE_INVENTORY_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo AIA_HOME_DIR=$AIA_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo AIA_HOME_NAME=$AIA_HOME_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo AIA_INSTANCE_NAME=$AIA_INSTANCE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SOA_SERVER_COUNT=$SOA_SERVER_COUNT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo CLUSTER_NAME_SOA=$CLUSTER_NAME_SOA >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo MSERVER_COHERENCE_PORT=$MSERVER_COHERENCE_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo APPLICATIONS_HOME_DIR=$APPLICATIONS_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo OHS_SCRIPT_MODULE_NAME=$OHS_SCRIPT_MODULE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo MSERVER_SOA_MACHINE_NAME_1=$MSERVER_SOA_MACHINE_NAME_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo OHS_INSTANCE_NAME=$OHS_INSTANCE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo OHS_PORT=$OHS_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo SSL_PORT=$SSL_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo OHS_ADMIN_PORT=$OHS_ADMIN_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo CLUSTER_SHARED_LOCATION=$CLUSTER_SHARED_LOCATION >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo MDS_MAX_CONNECTION_POOL=$MDS_MAX_CONNECTION_POOL >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

MSERVER_SOA_NAME_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_NAME=\$MSERVER_SOA_NAME_${i}
  MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST},${MSERVER_SOA_NAME}
done
echo MSERVER_SOA_NAME_LIST=${MSERVER_SOA_NAME_LIST#?} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
MSERVER_SOA_PORT_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_PORT=\$MSERVER_SOA_PORT_${i}
  MSERVER_SOA_PORT_LIST=${MSERVER_SOA_PORT_LIST},${MSERVER_SOA_PORT}
done
echo MSERVER_SOA_PORT_LIST=${MSERVER_SOA_PORT_LIST#?} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
MSERVER_SOA_MACHINENAME_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_MACHINENAME=\$MSERVER_SOA_MACHINE_NAME_${i}
  MSERVER_SOA_MACHINENAME_LIST=${MSERVER_SOA_MACHINENAME_LIST},${MSERVER_SOA_MACHINENAME}
done
echo MSERVER_SOA_MACHINENAME_LIST=${MSERVER_SOA_MACHINENAME_LIST#?} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
OHS_SERVERURLS=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_HOSTNAME=\$MSERVER_SOA_HOSTNAME_${i}
  eval MSERVER_SOA_PORT=\$MSERVER_SOA_PORT_${i}
  OHS_SERVERURLS_LIST=${OHS_SERVERURLS_LIST},${MSERVER_SOA_HOSTNAME}:${MSERVER_SOA_PORT}
done
MSERVER_SOA_HOSTNAME_LIST=
for i in `/usr/bin/seq 1 ${SOA_SERVER_COUNT}`;
do
  eval MSERVER_SOA_HOSTNAME=\$MSERVER_SOA_HOSTNAME_${i}
  MSERVER_SOA_HOSTNAME_LIST=${MSERVER_SOA_HOSTNAME_LIST},${MSERVER_SOA_HOSTNAME}
done
echo MSERVER_SOA_HOSTNAME_LIST=${MSERVER_SOA_HOSTNAME_LIST#?} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
#echo WEBPROXY_SERVER_NAME=$WEBPROXY_SERVER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
#echo WEBPROXY_SERVER_PORT=$WEBPROXY_SERVER_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
#echo WEBPROXY_SERVER_MACHINE_NAME=$WEBPROXY_SERVER_MACHINE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
#echo WEBPROXY_SERVER_HOSTNAME=$WEBPROXY_SERVER_HOSTNAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo MSERVER_JMS_STORAGE_DIR=$MSERVER_JMS_STORAGE_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo MSERVER_TLOGS_STORAGE_DIR=$MSERVER_TLOGS_STORAGE_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo IS_SOA_CLUSTERED=$IS_SOA_CLUSTERED >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
   echo MANAGED_SERVER_PORT=0 >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo MANAGED_SERVER=$CLUSTER_NAME_SOA >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo CLUSTER_CHECK=true >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo CLUSTER_PROXY_HOST=$CLUSTER_PROXY_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo CLUSTER_PROXY_PORT=$CLUSTER_PROXY_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo OHS_SERVERURLS=${OHS_SERVERURLS_LIST#?} >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
else
   echo MANAGED_SERVER_PORT=$MSERVER_SOA_PORT_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo MANAGED_SERVER=$MSERVER_SOA_NAME_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo CLUSTER_CHECK=false >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo CLUSTER_PROXY_HOST='' >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
   echo CLUSTER_PROXY_PORT='' >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

fi

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aiafp_database_cfg.sql.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aiafp_database_cfg.sql

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/rcu_password_answers.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/rcu_password_answers

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.xml

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.rsp

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/soa_cfg.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/soa_cfg.rsp

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/create_soa_domain.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/create_soa_domain.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/launch.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/launch.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/disableHostnameVerification.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/disableHostnameVerification.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/removeDummySOA.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/removeDummySOA.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureNodeManager.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureNodeManager.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/startServer.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/startServer.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/stopServer.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/stopServer.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureSOA.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureSOA.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureCoherence.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureCoherence.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/AIAFP_CompleteResponse.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/AIAFP_CompleteResponse.rsp

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/client.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/client.rsp

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/tnsnames.ora.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/tnsnames.ora

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/mod_wl_ohs.conf.aia_middleware.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/mod_wl_ohs.conf.aia_middleware

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/apply_jrf.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/apply_jrf.py

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/createOHSInstance.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/createOHSInstance.py


/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

echo "Installation driver files generated"

#-------------------------------------------------------------------------------
# Collect media

echo "Collecting media"

mik_collect_media DB_CLIENT_64
mik_collect_media FMW
mik_collect_media SOA
# Download O2CPIP media
AIA_HOST_AIAPIP_MEDIA_DOWNLOAD_DIR=/private/downloads/aiacompip
mik_collect_media AIA_PIPS

# mik_collect_media P22524811_121300_GENERIC 

echo "Media collected"

#--------------------------------------------------------------------------------
# TODO database client pre-reqs

#--------------------------------------------------------------------------------
# Install Database Client

echo "Installing database client"

/usr/bin/unzip -o -q -d $DATABASE_CLIENT_MEDIA_DOWNLOAD_DIR $DATABASE_CLIENT_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_DB_CLIENT_64
$DATABASE_CLIENT_MEDIA_DOWNLOAD_DIR/client/runInstaller -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/client.rsp -invPtrLoc $APPLICATIONS_HOME_DIR/oraInst.loc -waitforcompletion || RET_CODE=$?
# OUI return code of 6: The installation was successful after you proceeded by disregarding a few prerequisite checks or warnings.
# OUI return code of 253 (-3): The attempted installation encountered a prerequisite failure. Some of the required prerequisites have not been met. See the logs for details.
case "$RET_CODE" in
"")  ;;
0)  ;;
6)  ;;
253) ;;
*) false
  ;;
esac
/bin/bash -c "SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' $DATABASE_CLIENT_ORACLE_HOME_DIR/root.sh"
/bin/bash -c "SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' cp $APPLICATIONS_HOME_DIR/oraInst.loc /etc/"
/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/database/tnsnames.ora $DATABASE_CLIENT_ORACLE_HOME_DIR/network/admin
echo -e "\nADR_BASE = $DATABASE_CLIENT_HOME_DIR" >> $DATABASE_CLIENT_ORACLE_HOME_DIR/network/admin/sqlnet.ora

echo "Database client installed"

#--------------------------------------------------------------------------------
# Install WebLogic

echo "Installing WebLogic"


/usr/bin/unzip -o -q -d $WEBLOGIC_MEDIA_DOWNLOAD_DIR $WEBLOGIC_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_FMW
echo "$JAVA_HOME/bin/java -d64 -jar $WEBLOGIC_MEDIA_DOWNLOAD_DIR/fmw_12.2.1.3.0_infrastructure.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.rsp -invPtrLoc $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR/oraInst.loc"
$JAVA_HOME/bin/java -d64 -jar $WEBLOGIC_MEDIA_DOWNLOAD_DIR/fmw_12.2.1.3.0_infrastructure.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.rsp -invPtrLoc $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR/oraInst.loc

echo "WebLogic installed"

#--------------------------------------------------------------------------------
# Install SOA Suite

echo "Installing SOA Suite"

/usr/bin/unzip -o -q -d $SOA_MEDIA_DOWNLOAD_DIR/soa $SOA_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_SOA
$JAVA_HOME/bin/java -d64 -jar $SOA_MEDIA_DOWNLOAD_DIR/soa/fmw_12.2.1.3.0_soa.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/soa_cfg.rsp -invPtrLoc $APPLICATIONS_HOME_DIR/oraInst.loc
echo "SOA Suite installed"

#--------------------------------------------------------------------------------
# Applying SOA Patches

#echo "Patching SOA Suite"

#/bin/bash -c "$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/apply_soa_patches.sh"

#echo "SOA Suite patched"

#--------------------------------------------------------------------------------
# Deploy Oracle HTTP Server

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
   echo "Installing OHS"
   #Install OHS
   /bin/bash -c "export MIK_KNOBS_PATH=$OHS_SCRIPT_MODULE_NAME/common/knobs_aia_middleware ; $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/go.sh"
   echo "OHS installed"
fi

#--------------------------------------------------------------------------------
# Install Weblogic, Soa Suite on other managed servers

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
   /bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/installBinariesRemote.sh"
fi

#--------------------------------------------------------------------------------
# Configure the AIA Database

echo "Creating schemas"

/bin/mkdir -p $APPLICATIONS_HOME_DIR/logs

echo " APPLICATIONS_HOME_DIR $APPLICATIONS_HOME_DIR" 
# TODO create ODI schema
$COMMON_ORACLE_HOME_DIR/bin/rcu -silent -createRepository -databaseType ORACLE -connectString $DATABASE_HOST:$DATABASE_PORT:$DATABASE_SID -dbUser $DATABASE_SYS_USER_NAME -dbRole sysdba -variables RCU_LOG_LOCATION=$APPLICATIONS_HOME_DIR/logs -schemaPrefix $MDS_DATABASE_SCHEMA_PREFIX -component MDS -component IAU -component IAU_APPEND -component IAU_VIEWER -component OPSS -component UCSUMS -component WLS -component STB -component SOAINFRA -f < $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/rcu_password_answers
echo "Schemas created"

echo "Configuring database"

/bin/sh -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/common/.bashrc_aiafp ; $DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus $DATABASE_SYS_USER_NAME/$DATABASE_SYS_USER_PASSWORD@//$DATABASE_HOST:$DATABASE_PORT/$DATABASE_GLOBAL_NAME as sysdba @$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aiafp_database_cfg.sql"

echo "Database configured"


#--------------------------------------------------------------------------------
# Create WebLogic Domain

echo "Creating WebLogic domain"

/usr/bin/unzip -q -o -d $AIA_HOST_AIAPIP_MEDIA_DOWNLOAD_DIR $MEDIA_LOC_AIA_PIPS
cd $AIA_HOST_AIAPIP_MEDIA_DOWNLOAD_DIR
$JAVA_HOME/bin/java -jar comms_home_installer_generic.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/AIAPIPResponse_temp.rsp


cd /private/downloads/temp_install/comms_home/src/SCEApp
./SCEApp.sh $WEBLOGIC_MIDDLEWARE_HOME_DIR
cd -
# don't delete the temp_install now as we need it for copying SCEApp to the remote hosts as well after the domain copy.
#rm -rf /private/downloads/temp_install



# Copying aia 12.1.3 files done.
/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $WEBLOGIC_HOME_DIR/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/create_soa_domain.py"

$PERL_PROGRAM -pi.bak -e 's/PORT_MEM_ARGS=.*/PORT_MEM_ARGS="-XX:MaxPermSize=2048M -Xms2024m -Xmx3096m"/' $AIA_WEBLOGIC_DOMAIN_HOME_DIR/bin/setSOADomainEnv.sh

/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/setUserOverrides.sh $AIA_WEBLOGIC_DOMAIN_HOME_DIR/bin

echo "WebLogic domain created"

#--------------------------------------------------------------------------------
# Create boot.properties

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/createBootProperties.sh ${AIA_WEBLOGIC_DOMAIN_HOME_DIR} AdminServer ${WEBLOGIC_ADMIN_USER} ${WEBLOGIC_ADMIN_USER_PASSWORD} "

#-------------------------------------------------------------------------------
# Start Admin Server

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/startAdminServer.sh"

#--------------------------------------------------------------------------------
# Configure and start NodeManager on ADMINHOST

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureNodeManager.sh ${WEBLOGIC_HOST} ADMINHOST ${AIA_WEBLOGIC_DOMAIN_HOME_DIR} 5556 "

#--------------------------------------------------------------------------------
# Disabling Host Name Verification for the Oracle WebLogic Administration Server

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/disableHostnameVerification.py AdminServer"

#--------------------------------------------------------------------------------
# Create OHS Instance

# echo "Creating OHS Instance"

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
	/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $WEBLOGIC_MIDDLEWARE_HOME_DIR/ohs/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/createOHSInstance.py"
fi
# echo "OHS Instance created"

#--------------------------------------------------------------------------------
# Pack Domain

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
   /bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; rm -rf ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/soadomaintemplate.jar; ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/pack.sh -managed=true -domain=${AIA_WEBLOGIC_DOMAIN_HOME_DIR} -template=${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/soadomaintemplate.jar -template_name=soa_domain_template -log=$APPLICATIONS_HOME_DIR/logs/pack_domain.log"
fi

#--------------------------------------------------------------------------------
# Restart Admin Server

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh  $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/stopServer.py --adminserver true --soacluster false"
sleep 15
/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/startAdminServer.sh"

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
#----------------------------------------
# create list of all host names
#----------------------------------------
for serverType in SOA; do
        SERVER_COUNT=0
        SERVER_TYPE=$serverType
        serverCountString=$serverType"_SERVER_COUNT"
        eval SERVER_COUNT='${'$serverCountString'}'
        if [ ${SERVER_COUNT} -gt 0 ];then
           for (( c=1; c<=${SERVER_COUNT}; c++ )); do
                hostKey="MSERVER_"$SERVER_TYPE"_HOSTNAME_"$c
                eval hostVal='${'$hostKey'}'
                mhostList=$mhostList','$hostVal
           done
           mhostList=$(echo $mhostList|sed -e 's/,/ /g')
           mhostList=($mhostList)
           #echo "Found ${#mhostList[@]} hosts, ${mhostList[@]} for serverType $serverType"
        fi
done

#----------------------------------------
# create list of unique host names passing allHostList
#----------------------------------------
declare -a uniqHostNames=`echo ${mhostList[@]}|awk '{for(i=1;i<NF+1;i++) printf "%s\n",$i}'|sort|uniq`
uniqHostNames=$(echo ${uniqHostNames[@]}|sed -e 's/\n/ /g')
uniqHostNames=(${uniqHostNames[@]})

echo "Found ${#uniqHostNames[@]} unique hosts, ${uniqHostNames[@]}"

#----------------------------------------
# Disabling Host Name Verification for ALL Managed Servers
#----------------------------------------
mserverList=""
for serverType in SOA; do

        SERVER_COUNT=0
        SERVER_TYPE=$serverType
        serverCountString=$serverType"_SERVER_COUNT"
        eval SERVER_COUNT='${'$serverCountString'}'
  if [ ${SERVER_COUNT} -gt 0 ];then
     for (( c=1; c<=${SERVER_COUNT}; c++ )); do
        serverNameKey="MSERVER_"$SERVER_TYPE"_NAME_"$c
        eval serverNameVal='${'$serverNameKey'}'
        mserverList=$mserverList','$serverNameVal
     done
  fi
done
mserverList=$(echo $mserverList|sed -e 's/,//')
echo $mserverList
/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/disableHostnameVerification.py $mserverList"

#----------------------------------------
# Propagating the Domain Configuration
# to remote hosts Using the unpack Utility
#----------------------------------------
for currentHost in "${uniqHostNames[@]}"; do
   #check if it is local host or remote

   if [ "$currentHost" != "${WEBLOGIC_HOST}" ]; then
      echo "Found remote host $currentHost ..."
      echo "scp template file  ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/soadomaintemplate.jar to $currentHost..."
      /bin/bash -c "export MIK_ASKPASS_HOST=${currentHost} ; export MIK_ASKPASS_USER=${WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/soadomaintemplate.jar ${WEBLOGIC_HOST_OS_USER_NAME}@$currentHost:${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin"
      echo "create directories on host $currentHost..."
      echo "Unpack on host $currentHost ..."
      echo "mkdir -p ${AIA_WEBLOGIC_DOMAIN_HOME_DIR}" > test.sh
      echo "${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/unpack.sh -domain=${AIA_WEBLOGIC_DOMAIN_HOME_DIR} -overwrite_domain=true -template=${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/soadomaintemplate.jar -log=$APPLICATIONS_HOME_DIR/logs/unpack_domain.log" >> test.sh
     /bin/bash -c "export MIK_ASKPASS_HOST=${currentHost} ; export MIK_ASKPASS_USER=${WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -t -o StrictHostKeyChecking=no ${WEBLOGIC_HOST_OS_USER_NAME}@$currentHost /bin/bash -s < test.sh"
      rm -rf test.sh

      echo "Copying SCEApp to $currentHost and running SCEApp.sh on $currentHost.."
      /bin/bash -c "export MIK_ASKPASS_HOST=${currentHost} ; export MIK_ASKPASS_USER=${WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no /private/downloads/temp_install/comms_home/src/SCEApp/SCEApp.zip ${WEBLOGIC_HOST_OS_USER_NAME}@$currentHost:/private/downloads/SCEApp.zip"
      /bin/bash -c "export MIK_ASKPASS_HOST=${currentHost} ; export MIK_ASKPASS_USER=${WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no /private/downloads/temp_install/comms_home/src/SCEApp/SCEApp.sh ${WEBLOGIC_HOST_OS_USER_NAME}@$currentHost:/private/downloads/SCEApp.sh"
      echo "Running /private/downloads/SCEApp.sh $WEBLOGIC_MIDDLEWARE_HOME_DIR on $currentHost"
      mik_run_remote $currentHost ${WEBLOGIC_HOST_OS_USER_NAME} "../SCEApp.sh $WEBLOGIC_MIDDLEWARE_HOME_DIR"
   fi
done
rm -rf /private/downloads/temp_install
fi

#----------------------------------------
# create boot.properties and startup.properties for ALL Managed Servers
#----------------------------------------
for serverType in SOA; do
        SERVER_COUNT=0
        SERVER_TYPE=$serverType
        serverCountString=$serverType"_SERVER_COUNT"
        eval SERVER_COUNT='${'$serverCountString'}'
   for (( c=1; c<=${SERVER_COUNT}; c++ )); do
        hostNameKey="MSERVER_"$SERVER_TYPE"_HOSTNAME_"$c
        eval hostNameVal='${'$hostNameKey'}'
        machineName="MSERVER_"$SERVER_TYPE"_MACHINE_NAME_"$c
        eval machineNameVal='${'$machineName'}'
        serverNameKey="MSERVER_"$SERVER_TYPE"_NAME_"$c
        eval serverNameVal='${'$serverNameKey'}'

        if [ "$hostNameVal" != "${WEBLOGIC_HOST}" ] ; then
           mik_run_remote $hostNameVal ${WEBLOGIC_HOST_OS_USER_NAME} "$AIA_SCRIPT_MODULE_NAME/aiafp/createBootProperties.sh ${AIA_WEBLOGIC_DOMAIN_HOME_DIR} $serverNameVal ${WEBLOGIC_ADMIN_USER} ${WEBLOGIC_ADMIN_USER_PASSWORD}" $MANAGEABLE_INSTALL_TOOL_DIR
           mik_run_remote $hostNameVal ${WEBLOGIC_HOST_OS_USER_NAME} "$AIA_SCRIPT_MODULE_NAME/aiafp/createStartupProperties.sh ${AIA_WEBLOGIC_DOMAIN_HOME_DIR} $serverNameVal ${WEBLOGIC_HOST} ${WEBLOGIC_PORT}" $MANAGEABLE_INSTALL_TOOL_DIR
        else
          /bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/createBootProperties.sh ${AIA_WEBLOGIC_DOMAIN_HOME_DIR} $serverNameVal ${WEBLOGIC_ADMIN_USER} ${WEBLOGIC_ADMIN_USER_PASSWORD} "
          /bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/createStartupProperties.sh ${AIA_WEBLOGIC_DOMAIN_HOME_DIR} $serverNameVal ${WEBLOGIC_HOST} ${WEBLOGIC_PORT} "
        fi
   done

done

#----------------------------------------
# Configure and start NodeManager for remote hosts - SOA
# have already done for localhost
#----------------------------------------
for (( c=1; c<=${SOA_SERVER_COUNT}; c++ )); do
     hostNameKey="MSERVER_SOA_HOSTNAME_"$c
     eval hostNameVal='${'$hostNameKey'}'
     machineNameKey="MSERVER_SOA_MACHINE_NAME_"$c
     eval machineNameVal='${'$machineNameKey'}'
     for i in ${uniqHostNames[@]}; do
       if [ "$i" == "$hostNameVal" ] && [ "$i" != "${WEBLOGIC_HOST}" ] ; then
          /bin/bash -c "export MIK_ASKPASS_HOST=${hostNameVal} ; export MIK_ASKPASS_USER=${WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -t -o StrictHostKeyChecking=no ${WEBLOGIC_HOST_OS_USER_NAME}@$hostNameVal $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureNodeManager.sh ${hostNameVal} ${machineNameVal} ${AIA_WEBLOGIC_DOMAIN_HOME_DIR} 5556"
       fi
     done
done

#----------------------------------------
# Configure SOA and Coherence
#----------------------------------------
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
   /bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureSOA.py"
   /bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/configureCoherence.py"
fi

#----------------------------------------
# mounting cluster shared location
#----------------------------------------
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then

echo "Mounting Cluster Shared Location on node 1 "
/bin/mkdir -p $CLUSTER_SHARED_LOCATION
if grep -Fxq "${CLUSTER_SHARED_LOCATION} *(rw)" /etc/exports ; then
	echo "cluster shared location already exported. Export skipped"
else
	/bin/bash -c "SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /bin/bash -c 'echo -e \"\n${CLUSTER_SHARED_LOCATION} *(rw)\" >> /etc/exports' ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /usr/sbin/exportfs -r"
fi
	
#mouting the cluster shared location to remote hosts
for currentHost in "${uniqHostNames[@]}"; do
   if [ "$currentHost" != "${WEBLOGIC_HOST}" ]; then
   mik_run_remote $currentHost $WEBLOGIC_HOST_OS_USER_NAME $AIA_SCRIPT_MODULE_NAME/aiafp/mountClusterSharedLoc.sh $WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR
   fi
done
fi

#----------------------------------------
# Starting and Validating the SOA Managed Server
#----------------------------------------
# for serverType in SOA; do

        # SERVER_COUNT=0
        # SERVER_TYPE=$serverType
        # serverCountString=$serverType"_SERVER_COUNT"
        # eval SERVER_COUNT='${'$serverCountString'}'

   # for (( c=1; c<=${SERVER_COUNT}; c++ )); do
        # serverNameKey="MSERVER_"$SERVER_TYPE"_NAME_"$c
        # eval serverNameVal='${'$serverNameKey'}'
        # vhostKey="MSERVER_"$SERVER_TYPE"_HOSTNAME_"$c
        # eval vhostVal='${'$vhostKey'}'

        # echo "Starting $SERVER_TYPE server:$serverNameVal"

        # /bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/startServer.py $serverNameVal $vhostVal"

   # done
# done

#--------------------------------------------------------------------------------
# Deploy WebProxyApp to WebProxy Managed Server - COMMENTED WebProxyAPP as OHS support added
#if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
#   echo "Startup ${WEBPROXY_SERVER_NAME} and Deploy WebProxyApp to ${WEBPROXY_SERVER_NAME}"
#   /bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/startServer.py ${WEBPROXY_SERVER_NAME} $WEBLOGIC_HOST"
#   mik_run_remote $WEBPROXY_SERVER_HOSTNAME ${WEBLOGIC_HOST_OS_USER_NAME} "$AIA_SCRIPT_MODULE_NAME/aiafp/deployWebProxyApp.sh" $MANAGEABLE_INSTALL_TOOL_DIR
#   echo "Deployed WebProxyApp to ${WEBPROXY_SERVER_NAME}"
#fi

#--------------------------------------------------------------------------------
# Deploy Oracle HTTP Server
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then

   #Append mod_wl_ohs.conf file with AIA/SOA urls
   echo "scp mod_wl_ohs.conf file $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/mod_wl_ohs.conf.aia_middleware to $OHS_HOST ..."
   /bin/bash -c "export MIK_ASKPASS_HOST=${OHS_HOST} ; export MIK_ASKPASS_USER=${OHS_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/mod_wl_ohs.conf.aia_middleware ${OHS_HOST_OS_USER_NAME}@$OHS_HOST:$AIA_WEBLOGIC_DOMAIN_HOME_DIR/config/fmwconfig/components/OHS/ohs1"
   echo "cp $AIA_WEBLOGIC_DOMAIN_HOME_DIR/config/fmwconfig/components/OHS/ohs1/mod_wl_ohs.conf $AIA_WEBLOGIC_DOMAIN_HOME_DIR/config/fmwconfig/components/OHS/ohs1/mod_wl_ohs.conf.original" > test.sh
   echo "cat $AIA_WEBLOGIC_DOMAIN_HOME_DIR/config/fmwconfig/components/OHS/ohs1/mod_wl_ohs.conf.aia_middleware >> $AIA_WEBLOGIC_DOMAIN_HOME_DIR/config/fmwconfig/components/OHS/ohs1/mod_wl_ohs.conf" >> test.sh
   /bin/bash -c "export MIK_ASKPASS_HOST=${OHS_HOST} ; export MIK_ASKPASS_USER=${OHS_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$LOCAL_MIK/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -t -o StrictHostKeyChecking=no ${OHS_HOST_OS_USER_NAME}@$OHS_HOST /bin/bash -s < test.sh"
   rm -rf test.sh
fi

#--------------------------------------------------------------------------------
# applyJRF and restart SOA Managed Servers

# echo "Retarting SOA Servers"

# /bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py stop ${MSERVER_SOA_NAME_LIST#?}"
# /bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; /usr/bin/nohup ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/admin/admin_managedserver.py start ${MSERVER_SOA_NAME_LIST#?}"

# echo "SOA Servers restarted"

#--------------------------------------------------------------------------------
# applyJRF template and restart Servers

#echo "Apply JRF Template ......"

#/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/oracle_common/common/bin/wlst.sh #$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/apply_jrf.py"

#echo "JRF Template Applied"

echo "Restarting AIA servers"

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME//admin/do_stop_aiamw.sh"

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME//admin/do_start_aiamw.sh"

if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
	mik_run_remote $OHS_HOST ${OHS_HOST_OS_USER_NAME} $OHS_SCRIPT_MODULE_NAME/admin/start_ohs.sh $OHS_HOST_MANAGEABLE_INSTALL_TOOL_DIR
fi

echo "Installation Finished"
