#!/bin/sh
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

#--------------------------------------------------------------------------------
# Generate Install Tool Driver Files

echo "Generating installation driver files"

echo SOA_HOME_DIR=$SOA_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo JAVA_HOME=$JAVA_HOME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties
echo OHS_SCRIPT_MODULE_NAME=$OHS_SCRIPT_MODULE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.xml

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/soa_cfg.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/soa_cfg.rsp

/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/map.properties

echo "Installation driver files generated"

#-------------------------------------------------------------------------------
# Collect media

echo "Collecting media"

mik_collect_media FMW
mik_collect_media SOA
# mik_collect_media P20163149_121300_GENERIC


echo "Media collected"

#--------------------------------------------------------------------------------
# TODO database client pre-reqs

#--------------------------------------------------------------------------------
# Install WebLogic

/bin/mkdir -p $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR

echo "Installing WebLogic"
echo "inventory_loc=$WEBLOGIC_HOST_APPLICATIONS_HOME_DIR" >> $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR/oraInst.loc
/usr/bin/unzip -o -q -d $WEBLOGIC_MEDIA_DOWNLOAD_DIR $WEBLOGIC_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_FMW

$JAVA_HOME/bin/java -d64 -jar $WEBLOGIC_MEDIA_DOWNLOAD_DIR/fmw_12.2.1.2.0_infrastructure.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/wls_cfg.rsp -invPtrLoc $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR/oraInst.loc

echo "WebLogic installed"

#--------------------------------------------------------------------------------
# Install SOA Suite

echo "Installing SOA Suite"

/usr/bin/unzip -o -q -d $SOA_MEDIA_DOWNLOAD_DIR/soa $SOA_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_SOA
$JAVA_HOME/bin/java -d64 -jar $SOA_MEDIA_DOWNLOAD_DIR/soa/fmw_12.2.1.2.0_soa.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/soa_cfg.rsp -invPtrLoc $DEFAULT_APPLICATIONS_HOME_DIR/oraInst.loc

echo "SOA Suite installed"

echo "Patching SOA Suite"

/bin/bash -c "$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/apply_soa_patches.sh"

echo "SOA Suite patched"

#--------------------------------------------------------------------------------
# Install Oracle http server

echo "installing ohs"

/bin/bash -c "export MIK_KNOBS_PATH=$OHS_SCRIPT_MODULE_NAME/common/knobs_aia_middleware ; $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/install_ohs.sh"

echo "binaries installed on the other node"
