#!/bin/bash
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



echo "Reading configuration"

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`
source $THIS_DIR/../common/knobs

echo "Configuration read"

# (1) Specify the filename to update (do not include directory)
#
#FILENAME=bpel/system/j2ee/orabpel-console.url

#
# (2) Specify the log file (enter '/dev/null' for no logging)
#
LOGFILE=./update_config_log.txt

#
# (3) Specify comment for documentation logging (optional)
#
COMMENT="Update Config"

#
# (4) Choose ONLY one of the following replacement actions
#

#
# Replace an exact string
#
#ACTION=replaceexactstring
#FINDSTRING="/u01/app"
#NEWSTRING="/u01/app/oracle"

#
# Change parameter value of the format PARAMETER=VALUE, PARAMETER="VALUE", PARAMETER = VALUE, PARAMETER = "VALUE"
#
#ACTION=changeparametervalue
#PARAMETERNAME="port"
#NEWVALUE="8888"

#
# Replace an entire line
#
#ACTION=replaceline
#FINDLINE="<Property NAME=\"HTTPPort\""
#NEWLINE="port=\"8888\""

#
# Insert a line before FINDLINE
#
#ACTION=insertbefore
#FINDLINE="</notification-server"
#NEWLINE="port=\"8888\""

#
# Insert a line after FINDLINE
#
#ACTION=insertafter
#FINDLINE="<notification-server"
#NEWLINE="port=\"8888\""

#
# Insert a line at the beginning of the file
#
#ACTION=insertfirst
#NEWLINE="port=\"8888\""

#
# Insert a line at the end of the file
#
#ACTION=insertlast
#NEWLINE="port=\"8888\""

#
# Insert a file before FINDLINE
#
#ACTION=insertfilebefore
#FINDLINE="port=\"7777\""
#NEWFILENAME="/tmp/jndiconfig.txt"

#
# Insert a file after FINDLINE
#
#ACTION=insertfileafter
#FINDLINE="port=\"7777\""
#NEWFILENAME="/tmp/jndiconfig.txt"

#
# Insert a file at the beginning of the file
#
#ACTION=insertfilefirst
#NEWFILENAME="/tmp/jndiconfig.txt"

#
# Insert a file at the end of the file
#
#ACTION=insertfilelast
#NEWFILENAME="/tmp/jndiconfig.txt"

#
# (5) Rename this script to a unique name (e.g., patch_updatejgroups.sh)
#

#
# (6) Run script on any server (e.g., updateconfig.sh /u01/app/oracle/product/10.1.3/soa_1)
#

# ---------------------------------
#                END 
# ---------------------------------


# =======================================
# Escape the input strings
# =======================================
NEWVALUEDISPLAY=${NEWVALUE}
NEWVALUE=`echo ${NEWVALUE//\\\/\\\\\\\\}`
NEWVALUE=`echo ${NEWVALUE// /\\\ }`
NEWVALUE=`echo ${NEWVALUE//'/\\\'}`
NEWVALUE=`echo ${NEWVALUE//\//\\\\/}`
NEWVALUE=`echo ${NEWVALUE//\"/\\\\\"}`
TIMESTAMP=`date +"%Y-%m-%d|%H:%M:%S"`
TIMESTAMPFILE=`date +"%Y%m%d_%H%M%S"`


# =======================================
# Basic checks
# =======================================
if [ $# -gt 0 ]; then
  ACTION=$1
fi
if [ $# -gt 1 ]; then
  FILENAME=$2
fi
if [ $# -gt 2 ]; then
  ORACLE_HOME=$3
  FILENAME="${ORACLE_HOME}/${FILENAME}"
fi
if [ $# -gt 3 ]; then
  NEWLINE=$4
  NEWVALUE=$4
  NEWFILENAME=$4
  NEWSTRING=$4
fi
if [ $# -gt 4 ]; then
  FINDLINE=$5
  FINDSTRING=$5
  PARAMETERNAME=$5
fi
if [ ! -f ${FILENAME} ]; then
  echo ""
  echo "ERROR: ${FILENAME} not found."
  echo ""
  exit
fi


# =======================================
# Backup the original configuration file
# =======================================
cp ${FILENAME} ${FILENAME}.bak.${TIMESTAMPFILE}


# =======================================
# Replace an exact string in entire file
# =======================================
if [ "${ACTION}" = "replaceexactstring" ]; then
  cat ${FILENAME} | sed -e "s^${FINDSTRING}^${NEWSTRING}^g" > ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Replaced string [${FINDSTRING}] with string [${NEWSTRING}]" >> ${LOGFILE}
fi


# =======================================
# Replace entire line starting with FINDLINE
# =======================================
if [ "${ACTION}" = "replaceline" ]; then
  cat ${FILENAME} | sed -e "s^${FINDLINE}.*$^${NEWLINE}^g" > ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Replaced line [${FINDLINE}] with line [${NEWLINE}]" >> ${LOGFILE}
fi


# =======================================
# Replace parameter value
# =======================================
# LIMITATION: Only replaces the first occurence
# LIMITATION: Delimiter is ^

if [ "${ACTION}" = "changeparametervalue" ]; then

  #
  # Format: paramater="value"
  #
  ORIGINALVALUE=`cat ${FILENAME} | grep ${PARAMETERNAME}= | head -1 | awk -F"${PARAMETERNAME}=" '{print $2}' | cut -d'"' -f2`
  ORIGINALVALUE1=${ORIGINALVALUE}
  ORIGINALVALUE=`echo ${ORIGINALVALUE//\\\/\\\\\\\\}`
  ORIGINALVALUE=`echo ${ORIGINALVALUE// /\\\ }`
  ORIGINALVALUE=`echo ${ORIGINALVALUE//'/\\\'}`
  ORIGINALVALUE=`echo ${ORIGINALVALUE//\//\\\\/}`
  ORIGINALVALUE=`echo ${ORIGINALVALUE//\"/\\\\\"}`
  sed -e "s^${PARAMETERNAME}=\\\"${ORIGINALVALUE}\\\"^${PARAMETERNAME}=\\\"${NEWVALUE}\\\"^g" ${FILENAME} > ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  if [ "${ORIGINALVALUE}" = "" ]; then
    #
    # Format: paramater=value
    #
    ORIGINALVALUE=`cat ${FILENAME} | grep "${PARAMETERNAME}=" | head -1 | awk -F"${PARAMETERNAME}=" '{print $2}' | cut -d' ' -f1`
    ORIGINALVALUE3=${ORIGINALVALUE}
    ORIGINALVALUE=`echo ${ORIGINALVALUE//\\\/\\\\\\\\}`
    ORIGINALVALUE=`echo ${ORIGINALVALUE// /\\\ }`
    ORIGINALVALUE=`echo ${ORIGINALVALUE//'/\\\'}`
    ORIGINALVALUE=`echo ${ORIGINALVALUE//\//\\\\/}`
    ORIGINALVALUE=`echo ${ORIGINALVALUE//\"/\\\\\"}`
    sed -e "s^${PARAMETERNAME}=${ORIGINALVALUE}^${PARAMETERNAME}=${NEWVALUE}^g" ${FILENAME} > ${FILENAME}.tmp
    mv ${FILENAME}.tmp ${FILENAME}
  fi

  #
  # Format: paramater = "value"
  #
  ORIGINALVALUE=`cat ${FILENAME} | grep "${PARAMETERNAME} = " | head -1 | awk -F"${PARAMETERNAME} = " '{print $2}' | cut -d'"' -f2`
  ORIGINALVALUE2=${ORIGINALVALUE}
  ORIGINALVALUE=`echo ${ORIGINALVALUE//\\\/\\\\\\\\}`
  ORIGINALVALUE=`echo ${ORIGINALVALUE// /\\\ }`
  ORIGINALVALUE=`echo ${ORIGINALVALUE//'/\\\'}`
  ORIGINALVALUE=`echo ${ORIGINALVALUE//\//\\\\/}`
  ORIGINALVALUE=`echo ${ORIGINALVALUE//\"/\\\\\"}`
  sed -e "s^${PARAMETERNAME} = \\\"${ORIGINALVALUE}\\\"^${PARAMETERNAME} = \\\"${NEWVALUE}\\\"^g" ${FILENAME} > ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  if [ "${ORIGINALVALUE}" = "" ]; then
    #
    # Format: paramater = value
    #
    ORIGINALVALUE=`cat ${FILENAME} | grep "${PARAMETERNAME} = " | grep -v '${PARAMETERNAME = \"' | head -1 | awk -F"${PARAMETERNAME} = " '{print $2}' | cut -d' ' -f1`
    ORIGINALVALUE4=${ORIGINALVALUE}
    ORIGINALVALUE=`echo ${ORIGINALVALUE//\\\/\\\\\\\\}`
    ORIGINALVALUE=`echo ${ORIGINALVALUE// /\\\ }`
    ORIGINALVALUE=`echo ${ORIGINALVALUE//'/\\\'}`
    ORIGINALVALUE=`echo ${ORIGINALVALUE//\//\\\\/}`
    ORIGINALVALUE=`echo ${ORIGINALVALUE//\"/\\\\\"}`
    sed -e "s^${PARAMETERNAME} = ${ORIGINALVALUE}^${PARAMETERNAME} = ${NEWVALUE}^g" ${FILENAME} > ${FILENAME}.tmp
    mv ${FILENAME}.tmp ${FILENAME}
  fi

  if [ "${ORIGINALVALUE1}" != "" ]; then
    ORIGINALVALUE=${ORIGINALVALUE1}
  elif [ "${ORIGINALVALUE2}" != "" ]; then
    ORIGINALVALUE=${ORIGINALVALUE2}
  elif [ "${ORIGINALVALUE3}" != "" ]; then
    ORIGINALVALUE=${ORIGINALVALUE3}
  elif [ "${ORIGINALVALUE4}" != "" ]; then
    ORIGINALVALUE=${ORIGINALVALUE4}
  fi

  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Replaced parameter [${PARAMETERNAME}] value [${ORIGINALVALUE}] with [${NEWVALUEDISPLAY}]" >> ${LOGFILE}

fi


# =======================================
# Insert before
# =======================================
if [ "${ACTION}" = "insertbefore" ]; then
  LINE_NUMBER=`nl -b a ${FILENAME} | grep "${FINDLINE}" | head -1 | awk '{print $1}'`
  LINE_NUMBER_BEFORE=`expr ${LINE_NUMBER} - 1`
  LINE_NUMBER_LAST=`cat ${FILENAME} | wc -l`

  sed -n 1,${LINE_NUMBER_BEFORE}p ${FILENAME} > ${FILENAME}.tmp
  echo ${NEWLINE} >> ${FILENAME}.tmp
  sed -n ${LINE_NUMBER},${LINE_NUMBER_LAST}p ${FILENAME} >> ${FILENAME}.tmp

  mv ${FILENAME}.tmp ${FILENAME}

  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted line [${NEWLINE}] before line [${FINDLINE}]" >> ${LOGFILE}
fi


# =======================================
# Insert after
# =======================================
if [ "${ACTION}" = "insertafter" ]; then
  LINE_NUMBER=`nl -b a ${FILENAME} | grep "${FINDLINE}" | head -1 | awk '{print $1}'`
  LINE_NUMBER_AFTER=`expr ${LINE_NUMBER} + 1`
  LINE_NUMBER_LAST=`cat ${FILENAME} | wc -l`

  sed -n 1,${LINE_NUMBER}p ${FILENAME} > ${FILENAME}.tmp
  echo ${NEWLINE} >> ${FILENAME}.tmp
  sed -n ${LINE_NUMBER_AFTER},${LINE_NUMBER_LAST}p ${FILENAME} >> ${FILENAME}.tmp

  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted line [${NEWLINE}] after line [${FINDLINE}]" >> ${LOGFILE}
fi


# =======================================
# Insert file before
# =======================================
if [ "${ACTION}" = "insertfilebefore" ]; then
  if [ ! -f ${NEWFILENAME} ]; then
    echo ""
    echo "ERROR: '${NEWFILENAME}' not found."
    echo ""
    exit
  fi
  LINE_NUMBER=`nl -b a ${FILENAME} | grep "${FINDLINE}" | head -1 | awk '{print $1}'`
  LINE_NUMBER_BEFORE=`expr ${LINE_NUMBER} - 1`
  LINE_NUMBER_LAST=`cat ${FILENAME} | wc -l`

  sed -n 1,${LINE_NUMBER_BEFORE}p ${FILENAME} > ${FILENAME}.tmp
  cat ${NEWFILENAME} >> ${FILENAME}.tmp
  sed -n ${LINE_NUMBER},${LINE_NUMBER_LAST}p ${FILENAME} >> ${FILENAME}.tmp

  mv ${FILENAME}.tmp ${FILENAME}

  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted file [${NEWFILENAME}] before line [${FINDLINE}]" >> ${LOGFILE}
fi


# =======================================
# Insert file after
# =======================================
if [ "${ACTION}" = "insertfileafter" ]; then
  if [ ! -f ${NEWFILENAME} ]; then
    echo ""
    echo "ERROR: '${NEWFILENAME}' not found."
    echo ""
    exit
  fi
  LINE_NUMBER=`nl -b a ${FILENAME} | grep "${FINDLINE}" | head -1 | awk '{print $1}'`
  LINE_NUMBER_AFTER=`expr ${LINE_NUMBER} + 1`
  LINE_NUMBER_LAST=`cat ${FILENAME} | wc -l`

  sed -n 1,${LINE_NUMBER}p ${FILENAME} > ${FILENAME}.tmp
  cat ${NEWFILENAME} >> ${FILENAME}.tmp
  sed -n ${LINE_NUMBER_AFTER},${LINE_NUMBER_LAST}p ${FILENAME} >> ${FILENAME}.tmp

  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted file [${NEWFILENAME}] after line [${FINDLINE}]" >> ${LOGFILE}
fi


# =======================================
# Insert first
# =======================================
if [ "${ACTION}" = "insertfirst" ]; then
  echo ${NEWLINE} > ${FILENAME}.tmp
  cat ${FILENAME} >> ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted line [${NEWLINE}] as first line" >> ${LOGFILE}
fi


# =======================================
# Insert last
# =======================================
if [ "${ACTION}" = "insertlast" ]; then
  cat ${FILENAME} > ${FILENAME}.tmp
  echo ${NEWLINE} >> ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted line [${NEWLINE}] as last line" >> ${LOGFILE}
fi


# =======================================
# Insert file first
# =======================================
if [ "${ACTION}" = "insertfilefirst" ]; then
  if [ ! -f ${NEWFILENAME} ]; then
    echo ""
    echo "ERROR: '${NEWFILENAME}' not found."
    echo ""
    exit
  fi
  cat ${NEWFILENAME} > ${FILENAME}.tmp
  cat ${FILENAME} >> ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted file [${NEWFILENAME}] at beginning" >> ${LOGFILE}
fi


# =======================================
# Insert file last
# =======================================
if [ "${ACTION}" = "insertfilelast" ]; then
  if [ ! -f ${NEWFILENAME} ]; then
    echo ""
    echo "ERROR: '${NEWFILENAME}' not found."
    echo ""
    exit
  fi
  cat ${FILENAME} > ${FILENAME}.tmp
  cat ${NEWFILENAME} >> ${FILENAME}.tmp
  mv ${FILENAME}.tmp ${FILENAME}
  echo "${TIMESTAMP}|${FILENAME}|${COMMENT}|Inserted file [${NEWFILENAME}] at end" >> ${LOGFILE}
fi

