#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#


# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo CONFIGURATION FAILED" ERR
set -e
set -E
set -o pipefail

MIK_INSTALL_JAVA=1
source $THIS_DIR/../common/knobs
MIK_INSTALL_JAVA=

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

#echo "Generate media map entries for SOA AIA patches"
#/bin/bash -c "$THIS_DIR/../common/generate_mediamap_entries.sh"
#echo "Appended media map entries for SOA AIA patches"

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

#--------------------------------------------------------------------------------
# Configure access

MEDIA_MAP="${MANAGEABLE_INSTALL_TOOL_DIR}/common/media_map" 

/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/knobs.template $MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/knobs_aia_middleware
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common config_knobs -file=$MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/knobs_aia_middleware -DDATABASE_MEDIA_DOWNLOAD_DIR=$DATABASE_MEDIA_DOWNLOAD_DIR -DDATABASE_HOST_MANAGEABLE_INSTALL_TOOL_DIR=$DATABASE_HOST_MANAGEABLE_INSTALL_TOOL_DIR -DDATABASE_HOST_APPLICATIONS_HOME_DIR=$DATABASE_HOST_APPLICATIONS_HOME_DIR -DDATABASE_HOST=$DATABASE_HOST -DDATABASE_HOST_NAME=$DATABASE_HOST_NAME -DDATABASE_HOST_OS_USER_NAME=$DATABASE_HOST_OS_USER_NAME -DDATABASE_HOST_OS_GROUP_NAME=$DATABASE_HOST_OS_GROUP_NAME -DDATABASE_HOST_MEDIA_DOWNLOAD_DIR=$DATABASE_HOST_MEDIA_DOWNLOAD_DIR -DDATABASE_HOME_DIR=$DATABASE_HOME_DIR -DDATABASE_ORACLE_HOME_DIR=$DATABASE_ORACLE_HOME_DIR -DDATABASE_SID=$DATABASE_SID -DDATABASE_SID_UPPERCASE=$DATABASE_SID_UPPERCASE -DDATABASE_FILESYSTEM_DIR=$DATABASE_FILESYSTEM_DIR -DDATABASE_DATA_DIR=$DATABASE_DATA_DIR -DDATABASE_SYS_USER_NAME=$DATABASE_SYS_USER_NAME -DDATABASE_SYS_USER_PASSWORD=$DATABASE_SYS_USER_PASSWORD -DDATABASE_SYSTEM_USER_NAME=$DATABASE_SYSTEM_USER_NAME -DDATABASE_SYSTEM_USER_PASSWORD=$DATABASE_SYSTEM_USER_PASSWORD -DDATABASE_PORT=$DATABASE_PORT -DDATABASE_GLOBAL_NAME=$DATABASE_GLOBAL_NAME

/bin/bash -c "export MIK_KNOBS_PATH=${DATABASE_SCRIPT_MODULE_NAME}/common/knobs_aia_middleware ; $MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/config_access.sh"
mik_create_access $DATABASE_HOST $DATABASE_HOST_OS_USER_NAME
mik_create_su_access $WEBLOGIC_HOST $WEBLOGIC_HOST_OS_USER_NAME
mik_create_access $WEBLOGIC_HOST $WEBLOGIC_HOST_OS_USER_NAME
mik_create_media_access DB_CLIENT_64
mik_create_media_access FMW
mik_create_media_access SOA
mik_create_media_access DATABASE
#mik_create_media_access DATABASE_12c_LINUX_X86_64_2of2

COUNTER=0
for name in "${AIA_SOA_PATCHSET_NAME[@]}"
do
    file=${AIA_SOA_PATCHSET_FILE[$COUNTER]}
    NAME_COUNT=`cat ${MEDIA_MAP} | grep -i ${name} | wc -l` 
    if [ ${NAME_COUNT} > 0 ]
	then
           mik_create_media_access ${name}
    fi
    COUNTER=`expr $COUNTER + 1`
done


if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
 
echo "Configuring OHS"
/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/common/knobs.template $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/common/knobs_aia_middleware
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common config_knobs -file=$MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/common/knobs_aia_middleware -DOHS_HOST=$OHS_HOST -DOHS_HOST_OS_USER_NAME=$OHS_HOST_OS_USER_NAME -DOHS_HOST_MANAGEABLE_INSTALL_TOOL_DIR=$OHS_HOST_MANAGEABLE_INSTALL_TOOL_DIR -DOHS_HOST_APPLICATIONS_HOME_DIR=$OHS_HOST_APPLICATIONS_HOME_DIR -DOHS_PORT=$OHS_PORT -DOHS_HOST_MEDIA_DOWNLOAD_DIR=$OHS_HOST_MEDIA_DOWNLOAD_DIR -DWEBTIER_MIDDLEWARE_HOME_DIR=$WEBTIER_MIDDLEWARE_HOME_DIR -DWEBTIER_OHS_INSTANCE_NAME=$WEBTIER_OHS_INSTANCE_NAME
/bin/bash -c "export MIK_KNOBS_PATH=$OHS_SCRIPT_MODULE_NAME/common/knobs_aia_middleware ; $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/common/config_access.sh"

#---------------------------------------------
# create list of unique host names in cluster
#---------------------------------------------
declare -a mhostList
if [ ${SOA_SERVER_COUNT} -gt 0 ];then
   for (( c=1; c<=${SOA_SERVER_COUNT}; c++ )); do
      hostKey="MSERVER_SOA_HOSTNAME_"$c
      eval hostVal='${'$hostKey'}'
      mhostList=$mhostList','$hostVal
   done
   mhostList=$(echo $mhostList|sed -e 's/,/ /g')
   mhostList=($mhostList)
fi
declare -a uniqHostNames=`echo ${mhostList[@]}|awk '{for(i=1;i<NF+1;i++) printf "%s\n",$i}'|sort|uniq`
uniqHostNames=$(echo ${uniqHostNames[@]}|sed -e 's/\n/ /g')
uniqHostNames=(${uniqHostNames[@]})
echo "Found ${#uniqHostNames[@]} unique hosts, ${uniqHostNames[@]}"

for currentHost in "${uniqHostNames[@]}"; do
   #check if it is local host or remote
   if [ "$currentHost" != "${WEBLOGIC_HOST}" ]; then
      mik_create_su_access $currentHost $WEBLOGIC_HOST_OS_USER_NAME
      mik_create_access $currentHost $WEBLOGIC_HOST_OS_USER_NAME
   fi
done

for currentHost in "${uniqHostNames[@]}"; do
   #check if it is local host or remote
   if [ "$currentHost" != "${WEBLOGIC_HOST}" ]; then
      mik_run_remote $currentHost $WEBLOGIC_HOST_OS_USER_NAME $AIA_SCRIPT_MODULE_NAME/common/prevalidate.sh $WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR
   fi
done
fi


mik_run_remote $WEBLOGIC_HOST $WEBLOGIC_HOST_OS_USER_NAME $AIA_SCRIPT_MODULE_NAME/common/prevalidate.sh $WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR

echo Access configured
