#!/bin/sh
#
# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

#--------------------------------------------------------------------------------
# Generate Install Tool Driver Files

echo "Generating installation driver files"

echo SOA_HOME_DIR=$SOA_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo SOA_DATABASE_SCHEMA_PREFIX=$SOA_DATABASE_SCHEMA_PREFIX >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties

#New ODI Home Variables
echo ODI_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR=$ODI_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_HOME_DIR_NEW=$ODI_HOME_DIR_NEW >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_WEBLOGIC_DOMAIN_HOME_DIR=$ODI_WEBLOGIC_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties

echo ODI_DATABASE_SCHEMA_PREFIX=$ODI_DATABASE_SCHEMA_PREFIX >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_DATABASE_SCHEMA_NAME=$ODI_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_DATABASE_SCHEMA_PASSWORD=$ODI_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_DATABASE_SYS_USER_NAME=$AIA_MIDDLEWARE_DATABASE_SYS_USER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_DATABASE_SYS_USER_PASSWORD=$AIA_MIDDLEWARE_DATABASE_SYS_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR=$AIA_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_WEBLOGIC_DOMAIN_NAME=$AIA_WEBLOGIC_DOMAIN_NAME  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_WEBLOGIC_DOMAIN_HOME_DIR=$AIA_WEBLOGIC_DOMAIN_HOME_DIR  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_ACCESS_USER=$ODI_ACCESS_USER  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_HOST=$AIA_MIDDLEWARE_HOST  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_DATABASE_HOST=$ODI_DATABASE_HOST>> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_DATABASE_PORT=$ODI_DATABASE_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_DATABASE_GLOBAL_NAME=$AIA_MIDDLEWARE_DATABASE_GLOBAL_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_DATABASE_SID=$ODI_DATABASE_SID >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_DATABASE_SID_UPPERCASE=$AIA_MIDDLEWARE_DATABASE_SID_UPPERCASE >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo CONNECT_STRING=$ODI_DATABASE_HOST:$ODI_DATABASE_PORT:$AIA_MIDDLEWARE_DATABASE_GLOBAL_NAME  >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_MASTER_DB_USER=$ODI_MASTER_DB_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_MASTER_DB_PASSWORD=$ODI_MASTER_DB_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_ACCESS_PASSWORD=$ODI_ACCESS_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_HOME_DIR=$ODI_HOME_DIR>> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_MASTER_REPOSITORY_ID=$ODI_MASTER_REPOSITORY_ID >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_WORK_REPOSITORY_TYPE=$ODI_WORK_REPOSITORY_TYPE >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_WORK_REPOSITORY_ID=$ODI_WORK_REPOSITORY_ID >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_WORK_REPOSITORY_NAME=$ODI_WORK_REPOSITORY_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_WORK_REPOSITORY_PASSWORD=$ODI_WORK_REPOSITORY_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_AGENT_APP_NAME=$ODI_AGENT_APP_NAME >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_AGENT_PORT=$ODI_AGENT_PORT >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo STANDALONE_AGENT=$STANDALONE_AGENT >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_SDK=$ODI_SDK >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_STUDIO=$ODI_STUDIO >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ORACLE_DATA_INTEGRATOR_J2EE_AGENT=$ORACLE_DATA_INTEGRATOR_J2EE_AGENT >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ORACLE_DATA_INTEGRATOR_CONSOLE=$ORACLE_DATA_INTEGRATOR_CONSOLE >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ORACLE_DATA_INTEGRATOR_PUBLIC_WEB_SERVICE=$ORACLE_DATA_INTEGRATOR_PUBLIC_WEB_SERVICE >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo ODI_ENCRYPTION_TYPE=$ODI_ENCRYPTION_TYPE >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties
echo AIA_MIDDLEWARE_DATABASE_HOST=$AIA_MIDDLEWARE_DATABASE_HOST >>  $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties


$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/wls_cfg_odi.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/wls_cfg_odi.rsp

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/odi_enterpriseInstall.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/odi_enterpriseInstall.rsp

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/rcu_input.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/rcu_input

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/configure_odi_agent.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/configure_odi_agent.py


/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/map.properties

echo "Installation driver files generated"

#-------------------------------------------------------------------------------
# Collect media

echo "Collecting media"

#mik_collect_media V138469_01
mik_collect_media ODI_1of2
mik_collect_media ODI_2of2

echo "Media collected"

# Install ODI

echo "Installing ODI"

/bin/mkdir -p $ODI_MEDIA_DOWNLOAD_DIR
/bin/chmod u+w -R $ODI_MEDIA_DOWNLOAD_DIR
/usr/bin/unzip -o -q -d $ODI_MEDIA_DOWNLOAD_DIR $ODI_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_ODI_1of2
/usr/bin/unzip -o -q -d $ODI_MEDIA_DOWNLOAD_DIR $ODI_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_ODI_2of2

cd $ODI_MEDIA_DOWNLOAD_DIR
ODI_INSTALLER_FILENAME=`ls fmw*odi.jar`
echo "ODI Installer filename is $ODI_INSTALLER_FILENAME"
cd $THIS_DIR
$JAVA_HOME/bin/java -jar $ODI_MEDIA_DOWNLOAD_DIR/$ODI_INSTALLER_FILENAME -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/odi_enterpriseInstall.rsp
echo "ODI installed"

#--------------------------------------------------------------------------------
# Install RCU

echo "Creating Schemas"

$AIA_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/bin/rcu -silent -createRepository -connectString $ODI_DATABASE_HOST:$ODI_DATABASE_PORT:$AIA_MIDDLEWARE_DATABASE_GLOBAL_NAME -dbUser $DATABASE_SYS_USER_NAME -dbRole sysdba -useSamePasswordForAllSchemaUsers true -schemaPrefix $ODI_DATABASE_SCHEMA_PREFIX -component ODI -f < $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/rcu_input

echo "Schemas Created"

#--------------------------------------------------------------------------------
# Configure ODI Agent

echo "Configure ODI Agent"

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ;$COMMON_ORACLE_HOME_DIR/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_aabc/aiapip_aabc/configure_odi_agent.py"

echo "Domain Configured for ODI agent"
echo "restarting AIA Middleware"
$DEFAULT_MANAGEABLE_INSTALL_TOOL_DIR/${DEFAULT_AIA_MIDDLEWARE_SCRIPT_MODULE_NAME}/admin/restart_aiamw.sh
echo "AIA Middleware restarted"
echo "Installation Finished"
