#!/bin/sh

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

echo "Configuration read"

#-------------------------------------------------------------------------------
# Collect media

echo "Collecting media"

echo "Media collected"

#-------------------------------------------------------------------------------
# Prepare BRM

echo "Configuring BRM queuing database"

# TODO support queueing database different than BRM DB (consider multi-schema as well)
# TODO database linking

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo '# empty' >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/brm_aq_db_cfg.sql.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/brm_aq_db_cfg.sql
# /bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/brm_phonenum_update.sql.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/brm_phonenum_update.sql
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; \${DATABASE_CLIENT_ORACLE_HOME_DIR_1}/bin/sqlplus \${DATABASE_SYS_USER_NAME_1}/\${DATABASE_SYS_USER_PASSWORD_1}@//\${DATABASE_HOST_1}:\${DATABASE_PORT_1}/\${DATABASE_GLOBAL_NAME_1} as sysdba @${MANAGEABLE_INSTALL_TOOL_DIR}/aiapip_o2c/aiapip_o2c/brm_aq_db_cfg.sql"

echo "BRM queuing database configured"

## removing validation for BRM phone number. Bug #22697666
echo "Updating BRM phone number validation format in db"

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; \${DATABASE_CLIENT_ORACLE_HOME_DIR_1}/bin/sqlplus \${PIPELINE_SCHEMA_USER}/\${PIPELINE_SCHEMA_PASSWORD}@//\${DATABASE_HOST_1}:\${DATABASE_PORT_1}/\${DATABASE_GLOBAL_NAME_1}  @${MANAGEABLE_INSTALL_TOOL_DIR}/aiapip_o2c/aiapip_o2c/brm_phonenum_update.sql"

echo "BRM phone number format validation updated in db"


# TODO verify DM_AQ installed in BRM (and pin_setup run for it)

echo "Stopping BRM DM AQ"

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; pin_ctl stop dm_aq"

echo "BRM DM AQ stopped"

echo "Configuring EAI payload"

# TODO merge payloadconfig_X.xml file named in infranet.eai.configFile property in BRM_HOME/sys/eai_js/Infranet.properties with BRM_HOME/sys/eai_js/payloadconfig_crm_sync.xml.  Other payload_X.xml files in BRM_HOME/sys/eai_js/ may also need to be considered for merging (e.g. payloadconfig_collections.xml). payloadconfig_MergedWithCRMSync.xml is a merge attempt, but it is wrong due to conflicts.  For now we just grab BRM_HOME/sys/eai_js/payloadconfig_crm_sync.xml.

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo BRM_HOME_DIR=$BRM_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/Infranet.properties.template > $BRM_HOME_DIR/portal/7.5/sys/eai_js/Infranet.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties

# TODO verify that the database number for dm_aq in pin.conf is the one in the PublisherDefs:Publisher:DB entry in the payloadconfig file.  Defaults to 0.0.9.7 which is what we use

echo "EAI payload configured"

echo "Configuring event notification"

# TODO merge existing activated notifications and those in BRM_HOME/sys/data/config/pin_notify_crm_sync. For now we just use BRM_HOME/sys/data/config/pin_notify_crm_sync

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; cd $BRM_HOME_DIR/portal/7.5/sys/data/config ; load_pin_notify -dv $BRM_HOME_DIR/portal/7.5/sys/data/config/pin_notify_crm_sync"

echo "Event notification configured"

echo "Restarting BRM CM"

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; pin_ctl restart cm"

echo "BRM CM restarted"

echo "Restarting BRM DM EAI"

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; cd $BRM_HOME_DIR/portal/7.5/bin ; stop_dm_eai ; start_dm_eai"

echo "BRM DM EAI restarted"

echo "Restarting BRM EAI JS"

# TODO Don't use sleep; wait for start
/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; cd $BRM_HOME_DIR/portal/7.5/bin ; pin_ctl stop eai_js ; /bin/sleep 30 ; /usr/bin/nohup start_eai_js"

echo "BRM EAI JS restarted"

# TODO verify that the event notification list was loaded, display the config/notify object: robj command with the testnap utility

echo "Enable BRM CM publish"

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/common brm_cm_enable_publish $BRM_HOME_DIR/portal/7.5/sys/cm/pin.conf
# TODO verfiy dm_aq dm_pointer value

echo "BRM CM publish enabled"

echo "Restarting BRM CM"

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; pin_ctl restart cm"

echo "BRM CM restarted"

echo "Configuring business event mapping"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo '# empty' >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/aq_queuenames.template > $BRM_HOME_DIR/portal/7.5/sys/dm_aq/aq_queuenames
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties

echo "Business event mapping configured"

# TODO validate BRM_HOME/sys/dm_aq/pin.conf 

echo "Starting BRM DM AQ"

/bin/bash -c "shopt -s expand_aliases ; source $MANAGEABLE_INSTALL_TOOL_DIR/${BRM_SCRIPT_MODULE_NAME}/common/.bashrc_brm ; pin_ctl start dm_aq"

echo "BRM DM AQ started"

echo "Installation Finished"
