#!/bin/bash

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

echo "Configuration read"

echo "Prevalidating installation environment"

$JAVA_HOME/bin/java -cp $THIS_DIR/../common:$THIS_DIR/../../common prevalidate_prepare_siebel $THIS_DIR/../..

echo "Installation environment prevalidated"

#-------------------------------------------------------------------------------
# Collect media

echo "Collecting media"

mik_collect_media JDK_8U144_LINUX_X32

echo "Media collected"

#-------------------------------------------------------------------------------
# Prepare Siebel

echo "Stopping Siebel Server"

/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; source $SIEBEL_HOME_DIR/siebsrvr/siebenv.sh ; stop_server ALL"

echo "Siebel Server stopped"
/bin/bash -c "cd ${SIEBEL_HOST_AIAPIP_MEDIA_DOWNLOAD_DIR} ; /bin/tar -zxvf ${MEDIA_NAME_JDK_8U144_LINUX_X32}"
 
#--------------------------------------------------------------------------------
# Install Siebel ACR 474


echo "Acquiring WebLogic client library"

mik_run_remote $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME aiapip_o2c/aiapip_o2c/prepare_wl_client.sh $AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR
/bin/mkdir -p $APPLICATIONS_HOME_DIR/jms
/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$AIA_MIDDLEWARE_HOME_DIR/wlserver/server/lib/wlthint3client.jar $APPLICATIONS_HOME_DIR/jms"

echo "WebLogic client library acquired"

echo "Acquiring Siebel client libraries"

/bin/cp $SIEBEL_HOME_DIR/siebsrvr/classes/Siebel.jar $APPLICATIONS_HOME_DIR/jms
/bin/cp $SIEBEL_HOME_DIR/siebsrvr/classes/SiebelJI_enu.jar $APPLICATIONS_HOME_DIR/jms

echo "Siebel client libraries acquired"

echo "Starting Siebel server"

/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; source $SIEBEL_HOME_DIR/siebsrvr/siebenv.sh ; start_server ALL"

# TODO wait for siebel server to start
/bin/sleep 90

echo "Siebel server started"

echo "Configuring Java Subsystem"

# TODO support AIA MW clusters
echo AIA_MIDDLEWARE_HOST=$AIA_MIDDLEWARE_HOST > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo AIA_MIDDLEWARE_ADMIN_SERVER_WEBLOGIC_PORT=$AIA_MIDDLEWARE_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/jndi.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/jndi.properties1.template
/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aia_topology $SIEBEL_HOST_MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp"
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aia_topology -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/jndi.properties1.template > $APPLICATIONS_HOME_DIR/jms/jndi.properties
/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/jndi.properties1.template

/bin/mkdir -p $APPLICATIONS_HOME_DIR/jms/log

# TODO assumes exactly one enterprise
SIEBEL_ENTERPRISE_NAME=`/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; source $SIEBEL_HOME_DIR/siebsrvr/siebenv.sh ; srvrlist -u SADMIN -p sadmin123 -g $SIEBEL_HOST -l enterprises"`

/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; source $SIEBEL_HOME_DIR/siebsrvr/siebenv.sh ; $SIEBEL_HOME_DIR/siebsrvr/bin/srvrmgr /g $SIEBEL_HOST /e $SIEBEL_ENTERPRISE_NAME /u SADMIN /p sadmin123 /c \"delete named subsystem JAVA\" | true"
/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; source $SIEBEL_HOME_DIR/siebsrvr/siebenv.sh ; $SIEBEL_HOME_DIR/siebsrvr/bin/srvrmgr /g $SIEBEL_HOST /e $SIEBEL_ENTERPRISE_NAME /u SADMIN /p sadmin123 /c \"create named subsystem JAVA for subsystem JVMSubSys with DLL=$SIEBEL_HOST_AIAPIP_MEDIA_DOWNLOAD_DIR/jdk1.8.0_144/jre/lib/i386/client/libjvm.so, CLASSPATH=$APPLICATIONS_HOME_DIR/jms:$APPLICATIONS_HOME_DIR/jms/Siebel.jar:$APPLICATIONS_HOME_DIR/jms/SiebelJI_enu.jar:$APPLICATIONS_HOME_DIR/jms/wlthint3client.jar:., VMOPTIONS='-Djms.log=$APPLICATIONS_HOME_DIR/jms/log/jms.log'\""

echo "Java Subsystem configured"

echo "Configuring Siebel web services"

source $SIEBEL_HOST_MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aia_topology

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo SIEBEL_HOST=$SIEBEL_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo AIA_MIDDLEWARE_HOST=$AIA_HTTPFRONTEND_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo AIA_MIDDLEWARE_PORT=$AIA_HTTPFRONTEND_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/update_siebel_ws.sql.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/update_siebel_ws.sql
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties

/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/knobs ; source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; $SIEBEL_DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus SADMIN/sadmin123@//$SIEBEL_DATABASE_HOST:$SIEBEL_DATABASE_PORT/$SIEBEL_DATABASE_GLOBAL_NAME @$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/update_siebel_ws.sql"

echo "Siebel web services configured"

echo "Configuring Siebel repository"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
echo SIEBEL_HOME_DIR=$SIEBEL_HOME_DIR > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/update_siebel_repository.sql.template > $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/update_siebel_repository.sql
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/map.properties

/bin/mkdir -p $SIEBEL_HOME_DIR/siebsrvr/temp/OrderBackup
/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/knobs ; source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; $SIEBEL_DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus SADMIN/sadmin123@//$SIEBEL_DATABASE_HOST:$SIEBEL_DATABASE_PORT/$SIEBEL_DATABASE_GLOBAL_NAME @$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/update_siebel_repository.sql"

# Apply technote 20033168. May have to remove this code with Siebel 
# upgrade to a later patchset that resolves the siebel bug 20033168

# echo "Applying Siebel technical note for bug 20033168"

# /bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/knobs ; source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; $SIEBEL_DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus SADMIN/SADMIN@//$SIEBEL_DATABASE_HOST:$SIEBEL_DATABASE_PORT/$SIEBEL_DATABASE_GLOBAL_NAME @$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/tech_note_20033168.sql"

# echo "Siebel technical note for bug 20033168 applied"

# access control issue at support.oracle.com [ID 1542583.1]

/bin/bash -c "source ${MANAGEABLE_INSTALL_TOOL_DIR}/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; source ${SIEBEL_HOME_DIR}/siebsrvr/siebenv.sh ; ${SIEBEL_HOME_DIR}/siebsrvr/bin/srvrmgr /g ${SIEBEL_HOST} /e ${SIEBEL_ENTERPRISE_NAME} /u SADMIN /p sadmin123 /c \"change ent param EAIFileTransportFolders=${SIEBEL_HOME_DIR}/siebsrvr/temp/OrderBackup\""
/bin/bash -c "source ${MANAGEABLE_INSTALL_TOOL_DIR}/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel ; source ${SIEBEL_HOME_DIR}/siebsrvr/siebenv.sh ; ${SIEBEL_HOME_DIR}/siebsrvr/bin/srvrmgr /g ${SIEBEL_HOST} /e ${SIEBEL_ENTERPRISE_NAME} /u SADMIN /p sadmin123 /c \"change param EAIFileTransportFolders=${SIEBEL_HOME_DIR}/siebsrvr/temp/OrderBackup for server ${SIEBEL_SERVER_NAME}\""

echo "Siebel repository configured"

echo "Configuring Workflows"

/bin/mkdir -p $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/build/classes
$JAVA_HOME/bin/javac -d $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/build/classes -classpath $SIEBEL_HOME_DIR/siebsrvr/classes/Siebel.jar -sourcepath $MANAGEABLE_INSTALL_TOOL_DIR/common/src-apis $MANAGEABLE_INSTALL_TOOL_DIR/common/src-apis/SiebelUtil.java

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/build/classes:$SIEBEL_HOME_DIR/siebsrvr/classes/Siebel.jar:$SIEBEL_HOME_DIR/siebsrvr/classes/SiebelJI_enu.jar SiebelUtil $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME "CMU*"
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/build/classes:$SIEBEL_HOME_DIR/siebsrvr/classes/Siebel.jar:$SIEBEL_HOME_DIR/siebsrvr/classes/SiebelJI_enu.jar SiebelUtil $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME "SIA External Integration Process"

echo "Workflows configured"

# echo "Creating Siebel Addresses"

# Status of the Http request -w '%{http_code}'
# status_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"document/http://siebel.com/SelfService/Common/Address:SelfServiceAddressInsert\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/siebel_addresses.xml http://$SIEBEL_HOST:8080/eai_enu/start.swe?SWEExtSource=WebService\&SWEExtCmd=Execute\&UserName=SADMIN\&Password=SADMIN\&WSSOAP=1 -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/aiapip_o2c/aiapip_o2c/siebel_addresses_response.xml)
# Status of 200 is a succesfull request
# if [ $status_code -ne "200" ] 
# then
	# echo "http request to create Siebel addresses failed with code=$status_code"
# else
	# echo "Siebel Address Creation Finished"
# fi

echo "Installation Finished"
