#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo CONFIGURATION FAILED" ERR
set -e
set -E
set -o pipefail

MIK_INSTALL_JAVA=1
source $THIS_DIR/../common/knobs
MIK_INSTALL_JAVA=

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

#--------------------------------------------------------------------------------
# Configure access for remote hosts

mik_create_access $OSM_HOST $OSM_HOST_OS_USER_NAME
mik_create_access $BRM_HOST $BRM_HOST_OS_USER_NAME
#mik_create_access $PDC_WEBLOGIC_HOST $PDC_WEBLOGIC_HOST_OS_USER_NAME

if [ $RODOD_TOPOLOGY == 1 -o $RODOD_TOPOLOGY == 2 ]
then
mik_create_access $SIEBEL_HOST $SIEBEL_HOST_OS_USER_NAME
mik_create_access $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME $SIEBEL_HOST
fi

mik_create_access $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME
 
if [ "$IS_SOA_CLUSTERED" -eq "1" ] ; then
mik_create_access $AIA_MIDDLEWARE_CLUSTER_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME
fi

mik_create_media_access AIA_PIPS
mik_create_media_access P16483496_113_GENERIC

/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_O2A_INSTALL_SCRIPT_NAME}/common/knobs.template $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_O2A_INSTALL_SCRIPT_NAME}/common/knobs_o2c
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common config_knobs -file=$MANAGEABLE_INSTALL_TOOL_DIR/${OSM_O2A_INSTALL_SCRIPT_NAME}/common/knobs_o2c -DOSM_HOST=${OSM_HOST} -DOSM_HOST_OS_USER_NAME=${OSM_HOST_OS_USER_NAME} -DOSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR=${OSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR} -DOSM_HOST_MEDIA_DOWNLOAD_DIR=${OSM_HOST_MEDIA_DOWNLOAD_DIR} -DOSM_HOST_APPLICATIONS_HOME_DIR=${OSM_HOST_APPLICATIONS_HOME_DIR} -DOSM_DATABASE_HOST=${OSM_DATABASE_HOST} -DAIA_MIDDLEWARE_HOST=${AIA_MIDDLEWARE_HOST} -DAIA_MIDDLEWARE_HOST_OS_USER_NAME=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} -DAIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR=${AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR} -DOSM_WEBLOGIC_ADMIN_USER_PASSWORD=${OSM_WEBLOGIC_ADMIN_USER_PASSWORD} -DAIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD=${AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD} -DOSM_DATABASE_HOST=${OSM_DATABASE_HOST} -DOSM_DATABASE_SID=${OSM_DATABASE_SID} -DOSM_DATABASE_GLOBAL_NAME=${OSM_DATABASE_GLOBAL_NAME} -DOSM_DATABASE_PORT=${OSM_DATABASE_PORT} -DDATABASE_SYSTEM_USER_NAME=${DATABASE_SYSTEM_USER_NAME} -DDATABASE_SYSTEM_USER_PASSWORD=${DATABASE_SYSTEM_USER_PASSWORD} -DDATABASE_SYS_USER_NAME=${DATABASE_SYS_USER_NAME} -DDATABASE_SYS_USER_PASSWORD=${DATABASE_SYS_USER_PASSWORD} -DDESIGN_STUDIO_COM_WORKSPACE_NAME=${DESIGN_STUDIO_COM_WORKSPACE_NAME} -DDESIGN_STUDIO_SOM_WORKSPACE_NAME=${DESIGN_STUDIO_SOM_WORKSPACE_NAME} -DOSM_PASSWORD=$OSM_PASSWORD -DUIM_USERNAME=$UIM_USERNAME -DUIM_PASSWORD=$UIM_PASSWORD -DTOM_USERNAME=$TOM_USERNAME -DTOM_PASSWORD=$TOM_PASSWORD -DAIAPIP_MEDIA_DOWNLOAD_DIR=${OSM_HOST_AIAPIP_MEDIA_DOWNLOAD_DIR} -DSUITE_DOMAIN_NAME=${SUITE_DOMAIN_NAME}
/bin/bash -c "export MIK_KNOBS_PATH=${OSM_O2A_INSTALL_SCRIPT_NAME}/common/knobs_o2c ; $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_O2A_INSTALL_SCRIPT_NAME}/common/config_access.sh"


#/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_MODULE_NAME}/common/knobs.template $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_MODULE_NAME}/common/knobs_importrefdata
#$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common config_knobs -file=$MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_MODULE_NAME}/common/knobs_importrefdata -DBRM_HOST=${BRM_HOST} -BRM_HOST_OS_USER_NAME=${BRM_HOST_OS_USER_NAME} -DBRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR=${BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR}  -DBRM_HOST_APPLICATIONS_HOME_DIR=${BRM_HOST_APPLICATIONS_HOME_DIR} -DIMPORT_REFERENCE_DATA=${IMPORT_REFERENCE_DATA} -DIMPORT_CUSTOM_DATA=0 -DPDC_WEBLOGIC_HOST=${PDC_WEBLOGIC_HOST} -PDC_WEBLOGIC_HOST_OS_USER_NAME=${PDC_WEBLOGIC_HOST_OS_USER_NAME} -DPDC_WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR=${PDC_WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR}

#/bin/bash -c "export MIK_KNOBS_PATH=${IMPORT_REFERENCE_SCRIPT_MODULE_NAME}/common/knobs_importrefdata ; $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_MODULE_NAME}/common/config_access.sh"

mik_create_media_access JDK_6U37_LINUX_I586_BIN
mik_create_media_access JDK_8U144_LINUX_X32
mik_create_media_access AIA_PIPS
# echo "Create Media Access for ODI software"
# mik_create_media_access V44425_01

mik_create_su_access $OSM_HOST $OSM_HOST_OS_USER_NAME

echo Access configured
