
# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


import os
import subprocess

def set_kernel_param_perm(pname, pvalue):
  f = open('/etc/sysctl.conf', 'r')
  df = open('/etc/sysctl.conf.new', 'w')
  found = False
  for line in f:
    dline = line.strip()
    if dline == '' or dline.startswith('#') or dline.startswith(';'):
      df.write(line)
      continue
    x = dline.find('=')
    if x == -1:
      df.write(line)
      continue
    token = dline[:x].strip()
    value = dline[x+1:].strip()
    if token != pname:
      df.write(line)
      continue
    found = True
    if pvalue != None:
      df.write(token + ' = ' + pvalue + '\n')
  f.close()
  if not found and pvalue != None:
    df.write(pname + ' = ' + pvalue + '\n')    
  df.close()
  os.rename(df.name, f.name)

def get_kernel_param_perm(pname):
  f = open('/etc/sysctl.conf', 'r')
  for line in f:
    dline = line.strip()
    if dline == '' or dline.startswith('#') or dline.startswith(';'):
      continue
    x = dline.find('=')
    if x == -1:
      continue
    token = dline[:x].strip()
    value = dline[x+1:].strip()
    if token != pname:
      continue
    return value
  f.close()

def get_kernel_param(pname):
  proc = subprocess.Popen(['/sbin/sysctl', '-n', pname], stdout = subprocess.PIPE, stderr = subprocess.PIPE)
  o, e = proc.communicate()
  if proc.returncode != 0:
    return None
  o = o.strip()
  return o

def set_kernel_param(pname, pvalue):
  proc = subprocess.Popen(['/sbin/sysctl', '-n', '-w', pname + '=' + pvalue], stdout = subprocess.PIPE, stderr = subprocess.PIPE)
  o, e = proc.communicate()
  if proc.returncode != 0:
    raise Exception('No such kernel parameter: ' + pname)

def set_min_kernel_param(pname, pvalue):
  permvalue = get_kernel_param_perm(pname)
  if permvalue == None or int(permvalue) < pvalue:
    set_kernel_param_perm(pname, str(pvalue))
  value = get_kernel_param(pname)
  if value == None or int(value) < pvalue:
    set_kernel_param(pname, str(pvalue))

def set_min_kernel_param_mult(pname, pvalues):
  permvalue = get_kernel_param_perm(pname)
  if permvalue == None:
    dvalues = ''
    for pvalue in pvalues:
      dvalues = dvalues + ' ' + str(pvalue)
    set_kernel_param_perm(pname, dvalues.strip())
  else:
    permvalues = permvalue.split()
    dvalues = ''
    x = 0
    for pvalue in pvalues:
      if int(permvalues[x]) < pvalue:
        dvalues = dvalues + ' ' + str(pvalue)
      else:
        dvalues = dvalues + ' ' + permvalues[x]
      x = x + 1
    set_kernel_param_perm(pname, dvalues.strip())
  value = get_kernel_param(pname)
  if value == None:
    dvalues = ''
    for pvalue in pvalues:
      dvalues = dvalues + ' ' + str(pvalue)
    set_kernel_param(pname, dvalues.strip())
  else:
    values = value.split()
    dvalues = ''
    x = 0
    for pvalue in pvalues:
      if int(values[x]) < pvalue:
        dvalues = dvalues + ' ' + str(pvalue)
      else:
        dvalues = dvalues + ' ' + values[x]
      x = x + 1
    set_kernel_param(pname, dvalues.strip())

def set_db_client_kernel_params():
  set_min_kernel_param_mult('kernel.sem', [250, 32000, 100, 128])
  set_min_kernel_param('kernel.shmall', 2097152)
  set_min_kernel_param('kernel.shmmax', 536870912)
  set_min_kernel_param('kernel.shmmni', 4096)
  set_min_kernel_param('fs.file-max', 6815744)
  set_kernel_param_perm('net.ipv4.ip_local_port_range', '9000 65500')
  set_kernel_param('net.ipv4.ip_local_port_range', '9000 65500')
  set_min_kernel_param('net.core.rmem_default', 262144)
  set_min_kernel_param('net.core.rmem_max', 4194304)
  set_min_kernel_param('net.core.wmem_default', 262144)
  set_min_kernel_param('net.core.wmem_max', 1048576)
  set_min_kernel_param('fs.aio-max-nr', 1048576)
