/*

 Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

 The MIT License (MIT)

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/
import java.math.BigDecimal;
import java.util.Properties;

import com.portal.pcm.FList;
import com.portal.pcm.Poid;
import com.portal.pcm.PortalContext;
import com.portal.pcm.PortalOp;
import com.portal.pcm.fields.FldBalImpacts;
import com.portal.pcm.fields.FldCode;
import com.portal.pcm.fields.FldCurrency;
import com.portal.pcm.fields.FldDescr;
import com.portal.pcm.fields.FldElementId;
import com.portal.pcm.fields.FldEventType;
import com.portal.pcm.fields.FldFixedAmount;
import com.portal.pcm.fields.FldFlags;
import com.portal.pcm.fields.FldGlId;
import com.portal.pcm.fields.FldName;
import com.portal.pcm.fields.FldPermitted;
import com.portal.pcm.fields.FldPoid;
import com.portal.pcm.fields.FldProducts;
import com.portal.pcm.fields.FldProgramName;
import com.portal.pcm.fields.FldQuantityTiers;
import com.portal.pcm.fields.FldRateIndex;
import com.portal.pcm.fields.FldRatePlanName;
import com.portal.pcm.fields.FldRatePlans;
import com.portal.pcm.fields.FldRateTiers;
import com.portal.pcm.fields.FldRates;
import com.portal.pcm.fields.FldRumName;
import com.portal.pcm.fields.FldScaledAmount;
import com.portal.pcm.fields.FldScaledUnit;
import com.portal.pcm.fields.FldStepMax;
import com.portal.pcm.fields.FldStepMin;
import com.portal.pcm.fields.FldStepResourceId;
import com.portal.pcm.fields.FldType;
import com.portal.pcm.fields.FldUsageMap;

public class BrmUtil {

	public static void createProduct(String userName, String password, String host, int port, BrmProduct product) throws Throwable {
    FList inFL = new FList();
    inFL.set(FldPoid.getInst(), new Poid(1));
		inFL.set(FldProgramName.getInst(), "MIK Tests");
    FList productFL = new FList();
    productFL.set(FldCode.getInst(), product.name);
    productFL.set(FldName.getInst(), product.name);
    productFL.set(FldType.getInst(), 602);
    productFL.set(FldDescr.getInst(), product.name);
    productFL.set(FldPermitted.getInst(), "/service/content");
    FList usageMappingFL = new FList();
    usageMappingFL.set(FldEventType.getInst(), "/event/billing/product/fee/cycle/cycle_forward_monthly");
    usageMappingFL.set(FldRatePlanName.getInst(), "Monthly Cycle Forward Event");
    usageMappingFL.set(FldRumName.getInst(), "Occurrence");
    productFL.setElement(FldUsageMap.getInst(), 0, usageMappingFL);
    FList ratePlanFL = new FList();
    ratePlanFL.set(FldName.getInst(), "Monthly Cycle Forward Event");
    ratePlanFL.set(FldCurrency.getInst(), 840);
    ratePlanFL.set(FldEventType.getInst(), "/event/billing/product/fee/cycle/cycle_forward_monthly");
    FList rateTierFL = new FList();
    rateTierFL.set(FldName.getInst(), "Tier 1");
    rateTierFL.set(FldRateIndex.getInst(), 0);
    ratePlanFL.setElement(FldRateTiers.getInst(), 0, rateTierFL);
		FList rateFL = new FList();
		rateFL.set(FldType.getInst(), 740);
		rateFL.set(FldStepResourceId.getInst(), 840);
		FList quantityTierFL = new FList();
		quantityTierFL.set(FldStepMin.getInst(), BigDecimal.ONE);
		quantityTierFL.set(FldStepMax.getInst(), BigDecimal.ONE);
		FList balanceImpactFL = new FList();
		balanceImpactFL.set(FldFixedAmount.getInst(), BigDecimal.ZERO);
		balanceImpactFL.set(FldScaledAmount.getInst(), new BigDecimal(product.amount));
		balanceImpactFL.set(FldScaledUnit.getInst(), 0);
		balanceImpactFL.set(FldGlId.getInst(), 0);
		balanceImpactFL.set(FldElementId.getInst(), 0);
		balanceImpactFL.set(FldFlags.getInst(), 0);
		quantityTierFL.setElement(FldBalImpacts.getInst(), 0, balanceImpactFL);
    rateFL.setElement(FldQuantityTiers.getInst(), 0, quantityTierFL);
    ratePlanFL.setElement(FldRates.getInst(), 0, rateFL);
    productFL.setElement(FldRatePlans.getInst(), 0, ratePlanFL);
    inFL.setElement(FldProducts.getInst(), 0, productFL);
    PortalContext ctx = new PortalContext();
    Properties props = new Properties();
    props.setProperty("infranet.connection", "pcp://" + userName + ":" + password + "@" + host + ":" + port + "/service/admin_client 1");
    props.setProperty("infranet.login.type", "1");
    ctx.connect(props);
    // FList outFL =
    ctx.opcode(PortalOp.PRICE_COMMIT_PRODUCT, inFL);
    ctx.close(true);
	}
}
