/*

 Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

 The MIT License (MIT)

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/
import com.siebel.data.SiebelBusComp;
import com.siebel.data.SiebelBusObject;
import com.siebel.data.SiebelDataBean;
import com.siebel.data.SiebelException;


public class SiebelEstablishBundleCommand {

  public static void main(String[] args) throws Throwable {
    String siebelServerHost = args[0];
    int siebelServerPort = Integer.parseInt(args[1]);
    String siebelEnterpriseName = args[2];
    String siebelUser = args[3];
    String siebelUserPassword = args[4];
    SiebelBundle bundle = new SiebelBundle();
    bundle.name = args[5];
    bundle.fulfillmentItemCode = args[6];
    for (int i = 7; i < args.length; i++) {
      String arg = args[i];
      String[] tokens = arg.split("\\u007c", -1);
      SiebelBundle.ProductRel rel = new SiebelBundle.ProductRel();
      rel.productName = tokens[0];
      rel.minCardinality = Integer.parseInt(tokens[1]);
      rel.maxCardinality = Integer.parseInt(tokens[2]);
      rel.defaultCardinality = Integer.parseInt(tokens[3]);
      bundle.rels.add(rel);
    }
    
    establishBundle(siebelServerHost, siebelServerPort, siebelEnterpriseName, siebelUser, siebelUserPassword, bundle);
  }

  public static void establishBundle(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, SiebelBundle bundle) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
    System.setProperty("file.encoding", "utf8");
    dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    
    // Create product bundle
    
    SiebelBusObject productSBO = dataBean.getBusObject("Admin ISS Product Definition");
    SiebelBusComp productSBC = productSBO.getBusComp("Internal Product - ISS Admin");
    productSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productSBC.setViewMode(3);
    productSBC.activateField("Name");
    productSBC.clearToQuery();
    productSBC.setSearchSpec("Name", bundle.name);
    productSBC.executeQuery(true);
    
    if (productSBC.firstRecord()) {
      productSBC.setFieldValue("Name", bundle.name + " " + System.currentTimeMillis());
      productSBC.writeRecord();
    }
    
    productSBC.newRecord(false);
    productSBC.setFieldValue("Name", bundle.name);
    productSBC.setFieldValue("Description", bundle.name);
    SiebelBusComp productTypeSBC = productSBC.getPicklistBusComp("Product Type Code");
    productTypeSBC.clearToQuery();
    productTypeSBC.setSearchSpec("Value", "Commercial Bundle");
    productTypeSBC.executeQuery(true);
    if (productTypeSBC.firstRecord()) {
      productTypeSBC.pick();
    }
    SiebelBusComp structureTypeSBC = productSBC.getPicklistBusComp("Product Def Type Code");
    structureTypeSBC.clearToQuery();
    structureTypeSBC.setSearchSpec("Value", "Customizable");
    structureTypeSBC.executeQuery(true);
    if (structureTypeSBC.firstRecord()) {
      structureTypeSBC.pick();
    }
    
    /* TODO set this stuff?
    SiebelBusComp billingTypeSBC = productSBC.getPicklistBusComp("Billing Type");
    billingTypeSBC.clearToQuery();
    billingTypeSBC.setSearchSpec("Value", "Service Bundle");
    billingTypeSBC.executeQuery(true);
    if (billingTypeSBC.firstRecord()) {
      billingTypeSBC.pick();
    }
    productSBC.setFieldValue("Billing Service Type", "/account");
    productSBC.writeRecord();
    */
    
    // TODO should be parameterized
    productSBC.setFieldValue("Fulfillment Item Code", bundle.fulfillmentItemCode);
    
    // TODO Set its Status to Active.
    productSBC.setFieldValue("Orderable", "Y");
    productSBC.setFieldValue("Track As Asset Flag", "Y");
    // TODO productSBC.setFieldValue("Compound Flag", "Y");
    // TODO productSBC.setFieldValue("Service Instance", "Y");
    productSBC.setFieldValue("Sales Product Flag", "Y");
    
    // create bundle structure

    productSBC.writeRecord();
    
/* TODO alternate structure creation
    SiebelBusComp productBundleSBC = productSBO.getBusComp("ISS Product Bundle Admin BusComp");
    productBundleSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productBundleSBC.setViewMode(3);
    //productBundleSBC.clearToQuery();
    //productBundleSBC.executeQuery(true);
    productBundleSBC.newRecord(false);
    SiebelBusComp productNameSBC = productBundleSBC.getPicklistBusComp("Product Name");
    productNameSBC.clearToQuery();
    productNameSBC.setSearchSpec("Name", "Smoke Test Primary");
    productNameSBC.executeQuery(true);
    if (productNameSBC.firstRecord()) {
      productNameSBC.pick();
    }
    // TODO wrong field name
    productBundleSBC.setFieldValue("Quantity", "1");
    productBundleSBC.setFieldValue("Sequence", "1");
*/    

    SiebelBusComp productStructureSBC = productSBO.getBusComp("ISS Product Structure Admin BusComp");
    productStructureSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productStructureSBC.setViewMode(3);
    productStructureSBC.clearToQuery();
    productStructureSBC.executeQuery(true);
    
    for (SiebelBundle.ProductRel rel : bundle.rels) {
      productStructureSBC.newRecord(false);
      SiebelBusComp productNameSBC = productStructureSBC.getPicklistBusComp("Product Name");
      productNameSBC.clearToQuery();
      productNameSBC.setSearchSpec("Name", rel.productName);
      productNameSBC.executeQuery(true);
      if (productNameSBC.firstRecord()) {
        productNameSBC.pick();
      }
      productStructureSBC.setFieldValue("Item Name", rel.productName + " Rel");
      productStructureSBC.setFieldValue("Max Cardinality", String.valueOf(rel.maxCardinality));
      productStructureSBC.setFieldValue("Min Cardinality", String.valueOf(rel.minCardinality));
      productStructureSBC.setFieldValue("Default Cardinality", String.valueOf(rel.defaultCardinality));
      productStructureSBC.writeRecord();
    }
   
    productSBC.writeRecord();
    
    productSBC.invokeMethod("Publish", new String[] {});  
    
    dataBean.logoff();
  }
}
