/*

 Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

 The MIT License (MIT)

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/
import com.siebel.data.SiebelBusComp;
import com.siebel.data.SiebelBusObject;
import com.siebel.data.SiebelDataBean;
import com.siebel.data.SiebelException;
import com.siebel.data.SiebelPropertySet;
import com.siebel.data.SiebelService;

public class SiebelUtil {

  public static void establishAccount(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, SiebelAccount account) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    SiebelBusObject accountSBO = dataBean.getBusObject("Account");
    SiebelBusComp accountSBC = accountSBO.getBusComp("Account");
    accountSBC.setViewMode(3);
    accountSBC.clearToQuery();
    accountSBC.setSearchSpec("Name", account.name);
    accountSBC.executeQuery(true);
    if (accountSBC.firstRecord()) {
      accountSBC.setFieldValue("Name", account.name + " " + System.currentTimeMillis());
      accountSBC.writeRecord();
    }
    accountSBC.newRecord(false);
    accountSBC.setFieldValue("Name", account.name);
    SiebelBusComp accountTypeSBC = accountSBC.getPicklistBusComp("Type");
    accountTypeSBC.clearToQuery();
    accountTypeSBC.setSearchSpec("Value", "Residential");
    accountTypeSBC.executeQuery(true);
    if (accountTypeSBC.firstRecord()) {
      accountTypeSBC.pick();
    }
    
    SiebelBusComp addressesSMVGBC = accountSBC.getMVGBusComp("Street Address");
    SiebelBusComp addressesSABC = addressesSMVGBC.getAssocBusComp();
    addressesSABC.clearToQuery();
    addressesSABC.setSearchSpec("Street Address", account.addressStreet);
    addressesSABC.setSearchSpec("City", account.addressCity);
    addressesSABC.setSearchSpec("State", account.addressState);
    addressesSABC.setSearchSpec("Postal Code", account.addressZipCode);
    addressesSABC.setSearchSpec("Country", account.addressCountry);
    addressesSABC.executeQuery(true);
    if (addressesSABC.firstRecord()) {
      addressesSABC.associate(false);
      addressesSABC.writeRecord();
    } else {
      addressesSMVGBC.newRecord(false);
      addressesSMVGBC.setFieldValue("Street Address", account.addressStreet);
      addressesSMVGBC.setFieldValue("City", account.addressCity);
      addressesSMVGBC.setFieldValue("State", account.addressState);
      addressesSMVGBC.setFieldValue("Postal Code", account.addressZipCode);
      addressesSMVGBC.setFieldValue("Country", account.addressCountry);
      addressesSMVGBC.writeRecord();
    }
    
    SiebelBusComp contactsSMVGBC = accountSBC.getMVGBusComp("Primary Contact Last Name");
    SiebelBusComp contactsSABC = contactsSMVGBC.getAssocBusComp();
    contactsSABC.clearToQuery();
    contactsSABC.setSearchSpec("First Name", account.contactFirstName);
    contactsSABC.setSearchSpec("Last Name", account.contactLastName);
    contactsSABC.executeQuery(true);
    if (contactsSABC.firstRecord()) {
      contactsSABC.associate(false);
      contactsSABC.writeRecord();
      contactsSMVGBC.clearToQuery();
      contactsSMVGBC.setSearchSpec("First Name", account.contactFirstName);
      contactsSMVGBC.setSearchSpec("Last Name", account.contactLastName);
      contactsSMVGBC.executeQuery(true);
      if (contactsSMVGBC.firstRecord()) {
        contactsSMVGBC.setFieldValue("SSA Primary Field", "Y");
        contactsSMVGBC.writeRecord();
      }
    } else {
      contactsSMVGBC.newRecord(false);
      contactsSMVGBC.setFieldValue("First Name", account.contactFirstName);
      contactsSMVGBC.setFieldValue("Last Name", account.contactLastName);
      contactsSMVGBC.setFieldValue("SSA Primary Field", "Y");
      contactsSMVGBC.writeRecord();
    }
    	
    SiebelBusComp billingsSMVGBC = accountSBC.getMVGBusComp("Billing Profile Id");
    billingsSMVGBC.newRecord(false);
    billingsSMVGBC.setFieldValue("Payment Method", "Bill Me");
    billingsSMVGBC.setFieldValue("Bill Type", "Detail");
    billingsSMVGBC.setFieldValue("Bill Frequency", "Monthly");
    billingsSMVGBC.setFieldValue("Media Type", "Paper");
    billingsSMVGBC.writeRecord();
    
    accountSBC.writeRecord();
    dataBean.logoff();
  }

  public static boolean checkProductExists(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, String productName) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    
    SiebelBusObject productSBO = dataBean.getBusObject("Admin ISS Product Definition");
    SiebelBusComp productSBC = productSBO.getBusComp("Internal Product - ISS Admin");
    productSBC.setViewMode(3);
    productSBC.activateField("Name");
    productSBC.clearToQuery();
    productSBC.setSearchSpec("Name", productName);
    productSBC.executeQuery(true);
    
    boolean found = false;
    if (productSBC.firstRecord()) {
      found = true;
    }
    
    dataBean.logoff();
    
    return found;
  }

  public static void enrichProduct(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, String productName) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    
    SiebelBusObject productSBO = dataBean.getBusObject("Admin ISS Product Definition");
    SiebelBusComp productSBC = productSBO.getBusComp("Internal Product - ISS Admin");
    productSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productSBC.setViewMode(3);
    productSBC.activateField("Name");
    productSBC.activateField("Fulfillment Item Code");
    productSBC.activateField("VOD Locked Flag");
    productSBC.activateField("Service Instance");
    productSBC.clearToQuery();
    productSBC.setSearchSpec("Name", productName);
    productSBC.executeQuery(true);
    
    if (productSBC.firstRecord()) {
      productSBC.setFieldValue("VOD Locked Flag", "Y");
      productSBC.setFieldValue("Fulfillment Item Code", "Email Service PS");
      productSBC.setFieldValue("Service Instance", "Y");
      productSBC.writeRecord();
      productSBC.invokeMethod("Publish", new String[] {});  
    }
    
    dataBean.logoff();
  }

  public static void enrichProduct(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, String productName, String fic, String productClass, String structureType) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
    System.setProperty("file.encoding", "utf8");
    dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    
    SiebelBusObject productSBO = dataBean.getBusObject("Admin ISS Product Definition");
    SiebelBusComp productSBC = productSBO.getBusComp("Internal Product - ISS Admin");
    productSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productSBC.setViewMode(3);
    productSBC.activateField("Name");
    productSBC.activateField("Fulfillment Item Code");
    productSBC.activateField("XA Class Name");
    productSBC.activateField("VOD Locked Flag");
    productSBC.clearToQuery();
    productSBC.setSearchSpec("Name", productName);
    productSBC.executeQuery(true);
    
    if (productSBC.firstRecord()) {
      productSBC.setFieldValue("VOD Locked Flag", "Y");
      if (productClass != null) {
        SiebelBusComp productClassSBC = productSBC.getPicklistBusComp("XA Class Name");
        productClassSBC.clearToQuery();
        productClassSBC.setSearchSpec("Name", productClass);
        productClassSBC.executeQuery(true);
        if (productClassSBC.firstRecord()) {
          productClassSBC.pick();
        } else {
          throw new Error("Missing Siebel product class: " + productClass);
        }
      }
      productSBC.setFieldValue("Fulfillment Item Code", fic);
      
      if (structureType != null) {
        SiebelBusComp structureTypeSBC = productSBC.getPicklistBusComp("Product Def Type Code");
        structureTypeSBC.clearToQuery();
        structureTypeSBC.setSearchSpec("Value", structureType);
        structureTypeSBC.executeQuery(true);
        if (structureTypeSBC.firstRecord()) {
          structureTypeSBC.pick();
        }
      }
      
      productSBC.writeRecord();
      productSBC.invokeMethod("Publish", new String[] {});  
    }
    
    dataBean.logoff();
  }
  
  public static void createSalesOrder(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, SiebelSalesOrder order) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    
    SiebelBusObject orderSBO = dataBean.getBusObject("Order Entry (Sales)");
    SiebelBusComp orderSBC = orderSBO.getBusComp("Order Entry - Orders");
    orderSBC.newRecord(false);
    SiebelBusComp accountSBC = orderSBC.getPicklistBusComp("Account");
    accountSBC.clearToQuery();
    accountSBC.setSearchSpec("Name", order.accountName);
    accountSBC.executeQuery(true);
    if (accountSBC.firstRecord()) {
      accountSBC.pick();
      accountSBC.writeRecord();
    }
    
    java.text.SimpleDateFormat format = new java.text.SimpleDateFormat("MM/dd/yyyy HH:mm:ss");
    java.util.Calendar cal = java.util.Calendar.getInstance();
    cal.setTime(new java.util.Date());
    cal.roll(java.util.Calendar.DATE, false);
    String requestedShipDate = format.format(cal.getTime());
    orderSBC.setFieldValue("Requested Ship Date", requestedShipDate);
    orderSBC.setFieldValue("Status", "Open");
        
    // Create Line Item(s)
    
    SiebelBusComp itemsSBC = orderSBO.getBusComp("Order Entry - Line Items");
    itemsSBC.newRecord(false);
    String orderDate = orderSBC.getFieldValue("Order Date");
    itemsSBC.setFieldValue("Due Date", orderDate);
    itemsSBC.setFieldValue("Service Id", "SvcId-"+System.currentTimeMillis());
    SiebelBusComp productSBC = itemsSBC.getPicklistBusComp("Product");
    productSBC.clearToQuery();
    productSBC.setSearchSpec("Name", order.productName);
    productSBC.executeQuery(true);
    if (productSBC.firstRecord()) {
      productSBC.pick();
    }
    itemsSBC.writeRecord();
    orderSBC.writeRecord();
    
    /*
    SiebelBusComp itemSBC = orderSBO.getBusComp("Order Item XA");
    itemSBC.clearToQuery();
    itemSBC.setSearchSpec("Name", "Primary Name");
    itemSBC.executeQuery(true);
    if (itemSBC.firstRecord()) {
      itemSBC.setFieldValue("Value", "Glibberschmidt 2");
    }
    itemSBC.writeRecord();
    
    orderSBC.writeRecord();
    */
        
    // Submit Order
    
    SiebelService workflowSS = dataBean.getService("Workflow Process Manager");
    SiebelPropertySet inSPS = new SiebelPropertySet();
    inSPS.setProperty("ProcessName", "SISOMBillingSubmitOrderWebService");
    String rowId = orderSBC.getFieldValue("Id");
    inSPS.setProperty("Object Id", rowId);
    SiebelPropertySet outSPS = new SiebelPropertySet();
    workflowSS.invokeMethod("RunProcess", inSPS, outSPS);
        
    order.number = orderSBC.getFieldValue("Order Number");
    
    dataBean.logoff();
  }

  public static String getOrderStatus(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, SiebelSalesOrder order) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    SiebelBusObject orderSBO = dataBean.getBusObject("Order Entry (Sales)");
    SiebelBusComp orderSBC = orderSBO.getBusComp("Order Entry - Orders");
    orderSBC.clearToQuery();
    orderSBC.setSearchSpec("Order Number", order.number);
    orderSBC.executeQuery(true);
    String status = null;
    if (orderSBC.firstRecord()) {
      status = orderSBC.getFieldValue("Status");
    }
    dataBean.logoff();
    return status;
  }

  public static void establishBundle(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, SiebelBundle bundle) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    
    // Establish Commercial Bundle product type
    
    SiebelBusObject lovSBO = dataBean.getBusObject("List Of Values");
    SiebelBusComp lovSBC = lovSBO.getBusComp("List Of Values");
    lovSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    lovSBC.setViewMode(3);
    lovSBC.activateField("Type");
    lovSBC.activateField("Value");
    lovSBC.activateField("Name");
    lovSBC.activateField("Language Name");
    lovSBC.activateField("Active");
    lovSBC.activateField("Translate");
    lovSBC.activateField("Multilingual");
    lovSBC.clearToQuery();
    lovSBC.setSearchSpec("Type", "PROD_CD");
    lovSBC.setSearchSpec("Name", "Commercial Bundle");
    lovSBC.executeQuery(true);
    if (!lovSBC.firstRecord()) {
      lovSBC.newRecord(false);
      SiebelBusComp pickSBC = lovSBC.getPicklistBusComp("Type");
      pickSBC.clearToQuery();
      pickSBC.setSearchSpec("Value", "PROD_CD");
      pickSBC.executeQuery(true);
      if (pickSBC.firstRecord()) {
        pickSBC.pick();
      }
      lovSBC.setFieldValue("Value", "Commercial Bundle");
      lovSBC.setFieldValue("Name", "Commercial Bundle");
      pickSBC = lovSBC.getPicklistBusComp("Language Name");
      pickSBC.clearToQuery();
      pickSBC.setSearchSpec("Language Code", "ENU");
      pickSBC.executeQuery(true);
      if (pickSBC.firstRecord()) {
        pickSBC.pick();
      }
      lovSBC.setFieldValue("Active", "Y");
      lovSBC.setFieldValue("Translate", "Y");
      lovSBC.setFieldValue("Multilingual", "N");
      lovSBC.writeRecord();
    }
    
    // Create product bundle
    
    SiebelBusObject productSBO = dataBean.getBusObject("Admin ISS Product Definition");
    SiebelBusComp productSBC = productSBO.getBusComp("Internal Product - ISS Admin");
    productSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productSBC.setViewMode(3);
    productSBC.activateField("Name");
    productSBC.clearToQuery();
    productSBC.setSearchSpec("Name", bundle.name);
    productSBC.executeQuery(true);
    
    if (productSBC.firstRecord()) {
      productSBC.setFieldValue("Name", bundle.name + " " + System.currentTimeMillis());
      productSBC.writeRecord();
    }
    
    productSBC.newRecord(false);
    productSBC.setFieldValue("Name", bundle.name);
    productSBC.setFieldValue("Description", bundle.name);
    SiebelBusComp productTypeSBC = productSBC.getPicklistBusComp("Product Type Code");
    productTypeSBC.clearToQuery();
    productTypeSBC.setSearchSpec("Value", "Commercial Bundle");
    productTypeSBC.executeQuery(true);
    if (productTypeSBC.firstRecord()) {
      productTypeSBC.pick();
    }
    SiebelBusComp structureTypeSBC = productSBC.getPicklistBusComp("Product Def Type Code");
    structureTypeSBC.clearToQuery();
    structureTypeSBC.setSearchSpec("Value", "Customizable");
    structureTypeSBC.executeQuery(true);
    if (structureTypeSBC.firstRecord()) {
      structureTypeSBC.pick();
    }
    
    /* TODO set this stuff?
    SiebelBusComp billingTypeSBC = productSBC.getPicklistBusComp("Billing Type");
    billingTypeSBC.clearToQuery();
    billingTypeSBC.setSearchSpec("Value", "Service Bundle");
    billingTypeSBC.executeQuery(true);
    if (billingTypeSBC.firstRecord()) {
      billingTypeSBC.pick();
    }
    productSBC.setFieldValue("Billing Service Type", "/account");
    productSBC.writeRecord();
    */
    
    // TODO should be parameterized
    productSBC.setFieldValue("Fulfillment Item Code", "Smoke Test CFS PS");
    
    // TODO Set its Status to Active.
    productSBC.setFieldValue("Orderable", "Y");
    productSBC.setFieldValue("Track As Asset Flag", "Y");
    productSBC.setFieldValue("Compound Flag", "Y");
    productSBC.setFieldValue("Service Instance", "Y");
    
    // create bundle structure

    productSBC.writeRecord();
    
/* TODO alternate structure creation
    SiebelBusComp productBundleSBC = productSBO.getBusComp("ISS Product Bundle Admin BusComp");
    productBundleSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productBundleSBC.setViewMode(3);
    //productBundleSBC.clearToQuery();
    //productBundleSBC.executeQuery(true);
    productBundleSBC.newRecord(false);
    SiebelBusComp productNameSBC = productBundleSBC.getPicklistBusComp("Product Name");
    productNameSBC.clearToQuery();
    productNameSBC.setSearchSpec("Name", "Smoke Test Primary");
    productNameSBC.executeQuery(true);
    if (productNameSBC.firstRecord()) {
      productNameSBC.pick();
    }
    // TODO wrong field name
    productBundleSBC.setFieldValue("Quantity", "1");
    productBundleSBC.setFieldValue("Sequence", "1");
*/    

    SiebelBusComp productStructureSBC = productSBO.getBusComp("ISS Product Structure Admin BusComp");
    productStructureSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    productStructureSBC.setViewMode(3);
    productStructureSBC.clearToQuery();
    productStructureSBC.executeQuery(true);
    
    // TODO create rels according to structure in bundle parameter
    
    productStructureSBC.newRecord(false);
    SiebelBusComp productNameSBC = productStructureSBC.getPicklistBusComp("Product Name");
    productNameSBC.clearToQuery();
    productNameSBC.setSearchSpec("Name", "Smoke Test Primary Product");
    productNameSBC.executeQuery(true);
    if (productNameSBC.firstRecord()) {
      productNameSBC.pick();
    }
    productStructureSBC.setFieldValue("Item Name", "Smoke Test Primary" + " Rel");
    productStructureSBC.setFieldValue("Max Cardinality", "1");
    productStructureSBC.setFieldValue("Min Cardinality", "1");
    productStructureSBC.setFieldValue("Default Cardinality", "1");
    
    productStructureSBC.newRecord(false);
    productNameSBC = productStructureSBC.getPicklistBusComp("Product Name");
    productNameSBC.clearToQuery();
    productNameSBC.setSearchSpec("Name", "Smoke Test Secondary Product");
    productNameSBC.executeQuery(true);
    if (productNameSBC.firstRecord()) {
      productNameSBC.pick();
    }
    productStructureSBC.setFieldValue("Item Name", "Smoke Test Secondary" + " Rel");
    productStructureSBC.setFieldValue("Max Cardinality", "1");
    productStructureSBC.setFieldValue("Min Cardinality", "1");
    productStructureSBC.setFieldValue("Default Cardinality", "1");

    productStructureSBC.writeRecord();

    productSBC.writeRecord();
    
    productSBC.invokeMethod("Publish", new String[] {});  
    
    dataBean.logoff();
  }
  
  public static void establishProductClass(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, SiebelProductClass clazz) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    SiebelBusObject classesSBO = dataBean.getBusObject("Admin ISS Class Definition");
    SiebelBusComp classesSBC = classesSBO.getBusComp("ISS Class VOD BusComp");
    classesSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    classesSBC.setViewMode(3);
    classesSBC.activateField("VOD Name");
    classesSBC.clearToQuery();
    classesSBC.setSearchSpec("VOD Name", clazz.name);
    classesSBC.executeQuery(true);
    
    if (classesSBC.firstRecord()) {
      classesSBC.deleteRecord();
    }
    
    classesSBC.newRecord(false);
    classesSBC.setFieldValue("VOD Name", clazz.name);
    classesSBC.setFieldValue("Description", clazz.name);
    
    classesSBC.writeRecord();

    SiebelBusComp attrsSBC = classesSBO.getBusComp("ISS Product Attribute VBC");
    attrsSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    attrsSBC.setViewMode(3);
    attrsSBC.activateField("Name");
    attrsSBC.clearToQuery();
    attrsSBC.executeQuery(true);

    for (SiebelProductClassAttributeItem attri : clazz.attrs) {
      attrsSBC.newRecord(false);
      attrsSBC.setFieldValue("Name", attri.name);
      SiebelBusComp attrNameSBC = attrsSBC.getPicklistBusComp("Attribute Name");
      attrNameSBC.clearToQuery();
      attrNameSBC.setSearchSpec("Name", attri.attrname);
      attrNameSBC.executeQuery(true);
      if (attrNameSBC.firstRecord()) {
        attrNameSBC.pick();
      }
      attrsSBC.setFieldValue("Required Flag", attri.required ? "Y" : "N");
      if (attri.defaultValue != null) {
        attrsSBC.setFieldValue("Default Value", attri.defaultValue);
      }
      attrsSBC.writeRecord();
    }

    classesSBC.writeRecord();
    classesSBC.invokeMethod("ReleaseActive", new String[] {});  
    
    dataBean.logoff();
  }
  
  public static void establishProductClassAttribute(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, SiebelProductClassAttribute attr) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
		System.setProperty("file.encoding", "utf8");
		dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    SiebelBusObject attrsSBO = dataBean.getBusObject("Admin Attribute VOD Definition");
    SiebelBusComp attrsSBC = attrsSBO.getBusComp("Attribute VOD BusComp");
    attrsSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    attrsSBC.setViewMode(3);
    attrsSBC.activateField("VOD Name");
    attrsSBC.clearToQuery();
    attrsSBC.setSearchSpec("VOD Name", attr.name);
    attrsSBC.executeQuery(true);
    
    if (attrsSBC.firstRecord()) {
      attrsSBC.deleteRecord();
    }
    
    attrsSBC.newRecord(false);
    attrsSBC.setFieldValue("VOD Name", attr.name);
    attrsSBC.setFieldValue("Description", attr.name);
    
    // set type
    
    attrsSBC.writeRecord();
    
    SiebelBusComp attrsdSBC = attrsSBO.getBusComp("Attribute Details BusComp");
    attrsdSBC.invokeMethod("SetAdminMode", new String[] {"true"});
    attrsdSBC.setViewMode(3);
    attrsdSBC.activateField("Data Type");
    attrsdSBC.activateField("Domain Type");
    attrsdSBC.clearToQuery();
    attrsdSBC.executeQuery(true);
    
    if (attrsdSBC.firstRecord()) {
      SiebelProductClassAttribute.SiebelProductClassAttributeType type = attr.type;
      if (type instanceof SiebelProductClassAttribute.EnumSiebelProductClassAttributeType) {
        SiebelProductClassAttribute.EnumSiebelProductClassAttributeType dtype = SiebelProductClassAttribute.EnumSiebelProductClassAttributeType.class.cast(type);
        attrsdSBC.setFieldValue("Data Type", "Text");
        attrsdSBC.setFieldValue("Domain Type", "Enumerated");
        attrsdSBC.writeRecord();
        
        SiebelBusComp attrsvSBC = attrsSBO.getBusComp("Attribute Values BusComp");
        attrsvSBC.invokeMethod("SetAdminMode", new String[] {"true"});
        attrsvSBC.setViewMode(3);
        attrsvSBC.activateField("Value");
        attrsvSBC.activateField("Sequence");
        attrsvSBC.clearToQuery();
        attrsvSBC.executeQuery(true);
        for (int i = 0; i < dtype.values.size(); i++) {
          String val = dtype.values.get(i);
          attrsvSBC.newRecord(false);
          attrsvSBC.setFieldValue("Value", val);
          attrsvSBC.setFieldValue("Sequence", String.valueOf(i));
          attrsvSBC.writeRecord();
        }        
      } else {
        attrsdSBC.setFieldValue("Data Type", "Text");
        attrsdSBC.setFieldValue("Domain Type", "FreeForm");
      }
      attrsdSBC.writeRecord();
    }
    
    attrsSBC.writeRecord();
    attrsSBC.invokeMethod("ReleaseActive", new String[] {});  
    
    dataBean.logoff();
  }

  public static void activateWorkflow(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, String workflowName) throws SiebelException {
    SiebelDataBean dataBean = new SiebelDataBean();
    System.setProperty("file.encoding", "utf8");
    dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
            
    // Activate Workflow
    
    SiebelService workflowSS = dataBean.getService("Workflow Admin Service");
    SiebelPropertySet inSPS = new SiebelPropertySet();
    inSPS.setProperty("FlowSearchSpec", "Process Name like '" + workflowName + "'");
    SiebelPropertySet outSPS = new SiebelPropertySet();
    workflowSS.invokeMethod("Activate", inSPS, outSPS);
    String ret = outSPS.getProperty("NumFlowActivated");
    System.out.println(ret);
    dataBean.logoff();
  }

  public static void main(String[] args) throws SiebelException {
    activateWorkflow(args[0], 2321, args[1], "SADMIN", "sadmin123", args[2]);
  }
  
}
