/*

 Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

 The MIT License (MIT)

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/
import java.io.File;

import com.siebel.data.SiebelDataBean;
import com.siebel.data.SiebelException;
import com.siebel.data.SiebelPropertySet;
import com.siebel.data.SiebelService;

public class SiebelWorkspaceProject {
  
  public static void importWorkspaceProject(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, File exportFile, boolean reportOnly, String rootObjectName, boolean noTargetNameChange, boolean noSourceNameChange, boolean autoProceed, boolean useNamesAsKeys) throws SiebelException {

    SiebelPropertySet structure = new SiebelPropertySet();
    convertExportXmlToPropertySet(siebelServerHost, siebelServerPort, siebelEnterpriseName, siebelUser, siebelUserPassword, exportFile, structure);
    
    structure.setProperty("ReportOnly", reportOnly ? "Y" : "N");
    structure.setProperty("RootObjectName", rootObjectName);
    structure.setProperty("RootObjectType", "ISS_JWS");
    structure.setProperty("NoTargNameChange", noTargetNameChange ? "Y" : "N");
    structure.setProperty("NoSrcNameChange", noSourceNameChange ? "Y" : "N");
    structure.setProperty("AutoProceed", autoProceed ? "Y" : "N");
    structure.setProperty("UseNamesAsKeys", useNamesAsKeys ? "Y" : "N");
    
    SiebelDataBean dataBean = new SiebelDataBean();
    System.setProperty("file.encoding", "utf8");
    dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    SiebelService service = dataBean.getService("ISS Authoring Import Export Service");
    SiebelPropertySet outputs = new SiebelPropertySet();
    service.invokeMethod("ImportVOD", structure, outputs);
    service.release();
    dataBean.logoff();
    
    dataBean = new SiebelDataBean();
    System.setProperty("file.encoding", "utf8");
    dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    service = dataBean.getService("ISS Authoring Import Export Service");
    structure = new SiebelPropertySet();
    structure.setProperty("RootObjectName", rootObjectName);
    structure.setProperty("RootObjectType", "ISS_JWS");
    outputs = new SiebelPropertySet();
    service.invokeMethod("ReleaseJwsObjects", structure, outputs);
    service.release();
    dataBean.logoff();
  }
  
  private static void convertExportXmlToPropertySet(String siebelServerHost, int siebelServerPort, String siebelEnterpriseName, String siebelUser, String siebelUserPassword, File exportFile, SiebelPropertySet outputs) throws SiebelException
  {
    SiebelPropertySet readerInputs = new SiebelPropertySet(); 
    readerInputs.setProperty("FileName", exportFile.getAbsolutePath());
    readerInputs.setProperty("FileType", "xml");
    
    SiebelDataBean dataBean = new SiebelDataBean();
    System.setProperty("file.encoding", "utf8");
    dataBean.login("siebel.TCPIP.None.None://" + siebelServerHost + ":" + siebelServerPort + "/" + siebelEnterpriseName + "/eCommunicationsObjMgr_enu", siebelUser, siebelUserPassword);
    SiebelService service = dataBean.getService("EAI XML Read from File");
    service.invokeMethod("ReadPropSet", readerInputs, outputs);
    service.release();
    dataBean.logoff();
  }
  
  public static void main(String[] args) throws Throwable {
    importWorkspaceProject(args[0], 2321, args[1], "SADMIN", "sadmin123", new File(args[2]), false, args[3], false, false, true, true);
  }

}
