#!/bin/bash

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

# args
#   UIM_SDK_HOME
#   UIM_SDK_WL_HOME
#   UIM_WEBLOGIC_MIDDLEWARE_HOME
#   WEBLOGIC_MEDIA_DOWNLOAD_DIR
#   UIM_SDK_MEDIA_DOWNLOAD_DIR
#   JAVA_HOME

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )
MANAGEABLE_INSTALL_TOOL_DIR=${THIS_DIR}/../..
UIM_SDK_HOME=${1}
if [ -z "${UIM_SDK_HOME}" ]
then
  echo "First argument should be UIM_SDK_HOME"
  false
fi
UIM_SDK_WL_HOME=${2}
if [ -z "${UIM_SDK_WL_HOME}" ]
then
  echo "Second argument should be UIM_SDK_WL_HOME"
  false
fi
UIM_WEBLOGIC_MIDDLEWARE_HOME=${3}
if [ -z "${UIM_WEBLOGIC_MIDDLEWARE_HOME}" ]
then
  echo "Third argument should be UIM_WEBLOGIC_MIDDLEWARE_HOME"
  false
fi
WEBLOGIC_MEDIA_DOWNLOAD_DIR=${4}
if [ -z "${WEBLOGIC_MEDIA_DOWNLOAD_DIR}" ]
then
  echo "Fourth argument should be WEBLOGIC_MEDIA_DOWNLOAD_DIR"
  false
fi
UIM_SDK_MEDIA_DOWNLOAD_DIR=${5}
if [ -z "${UIM_SDK_MEDIA_DOWNLOAD_DIR}" ]
then
  echo "Fifth argument should be UIM_SDK_MEDIA_DOWNLOAD_DIR"
  false
fi
JAVA_HOME=${6}
if [ -z "${JAVA_HOME}" ]
then
  echo "Sixth argument should be JAVA_HOME"
  false
fi

source ${MANAGEABLE_INSTALL_TOOL_DIR}/common/mik_lib
source ${MANAGEABLE_INSTALL_TOOL_DIR}/common/media_map

#--------------------------------------------------------------------------------
# Install UIM SDK

echo "Installing UIM SDK"

mik_collect_media UIM_SDK_7_2_4_0_0

/usr/bin/unzip -q -o -d ${UIM_SDK_MEDIA_DOWNLOAD_DIR} ${MEDIA_LOC_UIM_SDK_7_2_4_0_0}
/bin/mkdir -p ${UIM_SDK_HOME}
/bin/cp -rf ${UIM_SDK_MEDIA_DOWNLOAD_DIR}/UIM_SDK/* ${UIM_SDK_HOME}

#--------------------------------------------------------------------------------
# Install UIM WebLogic (SDK)

if [ ! -d ${UIM_SDK_WL_HOME} ]
then
  echo "Installing UIM WebLogic (SDK)"

  mik_collect_media V29856_01
  /usr/bin/unzip -o -q -d ${WEBLOGIC_MEDIA_DOWNLOAD_DIR} ${MEDIA_LOC_V29856_01}
  /bin/rm -f ${THIS_DIR}/map.properties
  echo WEBLOGIC_MIDDLEWARE_HOME_DIR=${UIM_WEBLOGIC_MIDDLEWARE_HOME} >> ${THIS_DIR}/map.properties
  echo WEBLOGIC_HOME_DIR=${UIM_WEBLOGIC_MIDDLEWARE_HOME}/wlserver_10.3 >> ${THIS_DIR}/map.properties
  echo JAVA_HOME=${JAVA_HOME} >> ${THIS_DIR}/map.properties
  ${JAVA_HOME}/bin/java -cp ${MANAGEABLE_INSTALL_TOOL_DIR}/common template -map=${THIS_DIR}/map.properties -in=${THIS_DIR}/wls_cfg.xml.template > ${THIS_DIR}/wls_cfg.xml
  /bin/rm -f ${THIS_DIR}/map.properties
  ${JAVA_HOME}/bin/java -d64 -Duser.home=${UIM_SDK_HOME} -jar ${WEBLOGIC_MEDIA_DOWNLOAD_DIR}/wls1036_generic.jar -mode=silent -silent_xml=${THIS_DIR}/wls_cfg.xml -Djava.security.egd=file:/dev/./urandom -log=${UIM_SDK_HOME}/wls.log

  /bin/mkdir -p ${UIM_SDK_WL_HOME}/lib
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/wlserver_10.3/server/lib/weblogic.jar ${UIM_SDK_WL_HOME}/lib
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/wlserver_10.3/server/lib/webservices.jar ${UIM_SDK_WL_HOME}/lib
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/wlserver_10.3/server/lib/wlclient.jar ${UIM_SDK_WL_HOME}/lib
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/modules/com.bea.core.xml.beaxmlbeans_2.5.0.0_2-5-1.jar ${UIM_SDK_WL_HOME}/lib
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/modules/com.bea.core.xml.xmlbeans_2.2.0.0_2-5-1.jar ${UIM_SDK_WL_HOME}/lib/xbean.jar
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/modules/com.bea.core.xml.xmlbeans_2.2.0.0_2-5-1.jar ${UIM_SDK_HOME}/lib/xbean.jar
  # TODO UIM SDK guide specifies log4j 1.2.16
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/modules/com.bea.core.apache.log4j_1.2.13.jar ${UIM_SDK_WL_HOME}/lib
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/modules/com.bea.core.apache.log4j_1.2.13.jar ${UIM_SDK_WL_HOME}/lib/log4j.jar
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/modules/com.bea.core.apache.log4j_1.2.13.jar ${UIM_SDK_WL_HOME}/lib/log4j_1.2.16.jar
  /bin/cp ${UIM_WEBLOGIC_MIDDLEWARE_HOME}/modules/com.bea.core.apache.log4j_1.2.13.jar ${UIM_SDK_HOME}/lib/log4j-1.2.16.jar

  echo "UIM WebLogic (SDK) installed"
fi

echo "UIM SDK installed"

