#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH
fi

source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

#--------------------------------------------------------------------------------
# Get the Default pricelist (NA Pricelist) Id from Siebel

source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel
DEFAULT_PLID=`$SIEBEL_DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus -silent SADMIN/sadmin123@//$SIEBEL_DATABASE_HOST:$SIEBEL_DATABASE_PORT/$SIEBEL_DATABASE_GLOBAL_NAME <<END
set pagesize 0 feedback off verify off heading off echo off
select row_id from s_pri_lst where name='NA Pricelist';
exit;
END`

if [ -z "$DEFAULT_PLID" ]; then
    echo "No row_id returned from Siebel database for NA Pricelist"
    exit 0
else
    echo "NA Pricelist ID: $DEFAULT_PLID"
fi

# Getting it from dump, as the dump already has these price lists configured.
#--------------------------------------------------------------------------------
# Get the Consumer pricelist Id from Siebel

source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel
CONSUMER_PLID=`$SIEBEL_DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus -silent SADMIN/sadmin123@//$SIEBEL_DATABASE_HOST:$SIEBEL_DATABASE_PORT/$SIEBEL_DATABASE_GLOBAL_NAME <<END
set pagesize 0 feedback off verify off heading off echo off
select row_id from s_pri_lst where name='Consumer Pricelist';
exit;
END`

if [ -z "$CONSUMER_PLID" ]; then
   
SEARCH="PRICELIST_NAME"
REPLACE="Consumer Pricelist"
cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_pricelist_payload.xml.template | sed -e "s/$SEARCH/$REPLACE/" > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_consumer_pricelist_request.xml

consumer_status_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"document/http://siebel.com/asi/:SWIPriceList_Insert\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_consumer_pricelist_request.xml  http://$SIEBEL_HOST:8080/eai_enu/start.swe?SWEExtSource=WebService\&SWEExtCmd=Execute\&UserName=SADMIN\&Password=sadmin123\&WSSOAP=1 -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_consumer_pricelist_response.xml)

if [ $consumer_status_code -eq "200" ]
then  
   CONSUMER_PLID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_consumer_pricelist_response.xml '/SOAP-ENV:Envelope/SOAP-ENV:Body/ns:SWIPriceList_Insert_Output/ListOfSWIPriceListIO/ListOfPriceList/PriceList/Id/text()')
else
   echo "http request to create CONSUMER Pricelist failed with code=$consumer_status_code"
fi
   
fi

 echo "Consumer Price List ID: $CONSUMER_PLID"

# Getting it from dump, as the dump already has these price lists configured.
#--------------------------------------------------------------------------------
# Get the Business pricelist Id from Siebel

source $MANAGEABLE_INSTALL_TOOL_DIR/${SIEBEL_SCRIPT_MODULE_NAME}/common/.bashrc_siebel
BUSINESS_PLID=`$SIEBEL_DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus -silent SADMIN/sadmin123@//$SIEBEL_DATABASE_HOST:$SIEBEL_DATABASE_PORT/$SIEBEL_DATABASE_GLOBAL_NAME <<END
set pagesize 0 feedback off verify off heading off echo off
select row_id from s_pri_lst where name='Business Pricelist';
exit;
END`

if [ -z "$BUSINESS_PLID" ]; then
SEARCH="PRICELIST_NAME"
REPLACE="Business Pricelist"
cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_pricelist_payload.xml.template | sed -e "s/$SEARCH/$REPLACE/" > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_business_pricelist_request.xml

business_status_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"document/http://siebel.com/asi/:SWIPriceList_Insert\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_business_pricelist_request.xml  http://$SIEBEL_HOST:8080/eai_enu/start.swe?SWEExtSource=WebService\&SWEExtCmd=Execute\&UserName=SADMIN\&Password=sadmin123\&WSSOAP=1 -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_business_pricelist_response.xml)

if [ $business_status_code -eq "200" ]
then   
   BUSINESS_PLID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_business_pricelist_response.xml '/SOAP-ENV:Envelope/SOAP-ENV:Body/ns:SWIPriceList_Insert_Output/ListOfSWIPriceListIO/ListOfPriceList/PriceList/Id/text()')
else
   echo "http request to create BUSINESS Pricelist failed with code=$business_status_code"
fi
fi

 echo "Business Price List ID: $BUSINESS_PLID"
#-------------------------------------------------------------------------------
# Configure Pricelists in AIA DVM

echo "Configuring price lists in AIA Configuration"

SEARCH="CONSUMER_PLID"
REPLACE=$CONSUMER_PLID
cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm.template | sed -e "s/$SEARCH/$REPLACE/" > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm1

SEARCH="BUSINESS_PLID"
REPLACE=$BUSINESS_PLID
cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm1 | sed -e "s/$SEARCH/$REPLACE/" > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm2

SEARCH="DEFAULT_PLID"
REPLACE=$DEFAULT_PLID
cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm2 | sed -e "s/$SEARCH/$REPLACE/" > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm

/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm1 
/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/PRICELIST.dvm2 

mik_run_remote $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/go_update_aiadvm.sh $AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR

echo "Price lists configured in AIA Configuration"

