#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH  
fi

source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

echo "Configuration read"

#-------------------------------------------------------------------------------
#This section will create pricelist data in Siebel and AIA system
if [ $RODOD_TOPOLOGY == 1 -o $RODOD_TOPOLOGY == 2 ]
   then 
	$MANAGEABLE_INSTALL_TOOL_DIR/importreferencedata/importrefdata/go_create_pricelists.sh 
fi
#-------------------------------------------------------------------------------
# Restart BRM wireless (BRE/RTP) services 
if [ ${USE_RMS_RI} == "0" ]
then
  mik_run_remote $BRM_HOST $BRM_HOST_OS_USER_NAME ${BRM_SCRIPT_MODULE_NAME}/admin/do_restart_wireless.sh $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR
fi


#-------------------------------------------------------------------------------
# Import reference data for BRM when RMS-RI is integrated
if [ $RODOD_TOPOLOGY == 1 -o $RODOD_TOPOLOGY == 2 ]
   then
	if [ ${USE_RMS_RI} == "1" ]
	then
	  mik_run_remote $BRM_HOST $BRM_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/go_import_rmsri_brm.sh $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR
	  mik_run_remote $BRM_HOST $BRM_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/go_import_rmsri_pdc.sh $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR
	else 
	  mik_run_remote $PDC_WEBLOGIC_HOST $PDC_WEBLOGIC_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/go_import_pdc.sh $PDC_WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR
	fi
fi
#-------------------------------------------------------------------------------
#Validating the Siebel Data
#Commenting it temporarily till import is automated
#sleep 60
#mik_run_remote $SIEBEL_HOST $SIEBEL_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/ValidateProductList.sh

#-------------------------------------------------------------------------------
# Enrich reference data for Siebel
# This code is being used as workaround to release product in siebel for continuous integration process  
if [ $RODOD_TOPOLOGY == 1 -o $RODOD_TOPOLOGY == 2 ]
   then 
	mik_run_remote $SIEBEL_HOST $SIEBEL_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/go_import_siebel.sh $SIEBEL_HOST_MANAGEABLE_INSTALL_TOOL_DIR
	#custom Siebel Account data using webservices
	if [ $IMPORT_SIEBEL_ACCOUNT_DATA == 1 ]
	then
	    # Import Siebel account data
	    $MANAGEABLE_INSTALL_TOOL_DIR/importreferencedata/importrefdata/go_import_siebel_accounts.sh 
	fi
fi

#--------------------------------------------------------------------------------
# Load CPQ Data
if [ $RODOD_TOPOLOGY == 2 -o $RODOD_TOPOLOGY == 3 ]
then
   sleep 90
   mik_run_remote $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/go_update_aiaconf.sh
   mik_run_remote $PDC_WEBLOGIC_HOST $PDC_WEBLOGIC_HOST_OS_USER_NAME $IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/go_import_cpq_pdc.sh $PDC_WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR
   sleep 300
   $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/load_cpq_reference_data.sh
fi
