#!/bin/sh

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs
#source $THIS_DIR/../$DEFAULT_PDC_SCRIPT_MODULE_NAME/common/knobs

source $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"
#--------------------------------------------------------------------------------
# Restart RRE and BRE transformer engines
mik_run_remote $BRM_HOST $BRM_HOST_OS_USER_NAME ${PDC_SCRIPT_MODULE_NAME}/admin/do_stop_bip.sh $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR
sleep 10
mik_run_remote $BRM_HOST $BRM_HOST_OS_USER_NAME ${PDC_SCRIPT_MODULE_NAME}/admin/do_start_bip.sh $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR

# 90 second sleep is needed becaue BRE & RRE engine take time to load seed data
sleep 90
echo "...RRETransformer and BRETransformer started"


#--------------------------------------------------------------------------------
# Start SyncPDC

echo "Preparing SYNCPDC..."

mik_run_remote $BRM_HOST $BRM_HOST_OS_USER_NAME ${PDC_SCRIPT_MODULE_NAME}/admin/do_stop_syncpdc.sh $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR
sleep 10
mik_run_remote $BRM_HOST $BRM_HOST_OS_USER_NAME ${PDC_SCRIPT_MODULE_NAME}/admin/do_start_syncpdc.sh $BRM_HOST_MANAGEABLE_INSTALL_TOOL_DIR
# 60 second sleep time is recomended by PDC team to syncPDC work properly before loading any config  data
sleep 90
echo "SYNCPDC started..."

#--------------------------------------------------------------------------------
#Import PDC sample reference data files using utilities

/bin/bash -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; export JAVA_HOME=$JAVA_HOME; export PIN_HOME=$BRM_APP_HOME_DIR; export IFW_HOME=$BRM_PIPELINE_HOME_DIR; export PATH=$PATH:$BRM_PIPELINE_HOME_DIR/bin; export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$BRM_PIPELINE_HOME_DIR/lib64:$BRM_PIPELINE_HOME_DIR/lib:$DATABASE_ORACLE_HOME_DIR/lib; export TNS_ADMIN=$DATABASE_ORACLE_HOME_DIR/network/admin; OSTYPE=linux ; source $BRM_APP_HOME_DIR/source.me.sh; export ORACLE_HOME=$DATABASE_ORACLE_HOME_DIR; export NLS_LANG=American_America.AL32UTF8; export PATH=$PATH:$DATABASE_ORACLE_HOME_DIR/bin:$LD_LIBRARY_PATH; export ORACLE_BASE=$DATABASE_ORACLE_HOME_DIR; export ORACLE_LIB=$DATABASE_ORACLE_HOME_DIR/lib; export ORACLE_BIN=$DATABASE_ORACLE_HOME_DIR/bin; cd $PDC_HOME_DIR/apps/bin"

cd $PDC_HOME_DIR/apps/bin

echo "Importing seed data"
export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED| ./ImportExportPricing -import -config $PDC_HOME_DIR/apps/Samples/Examples/PDCSampleRum.xml -ow
sleep 30
export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED| ./ImportExportPricing -import -config $PDC_HOME_DIR/apps/Samples/Examples/PDCSampleBE.xml -ow
sleep 30
export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED| ./ImportExportPricing -import -config $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/data/RI_Rum_Overwrite.xml -ow
sleep 30

echo "Importing the Attribute spec map"
export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED| ./ImportExportPricing -import -config $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/data/ATTRIBUTE_SPEC_CPQ.xml -ow
 
echo "Importing the PDC-CPQ products "
export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED| ./ImportExportPricing -import -pricing $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/data/ImportreferenceData_CPQ.xml -ow
sleep 30

echo "Completed CPQ reference data files import using ImportExportPricing utilities...."
