#!/bin/sh

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

#--------------------------------------------------------------------------------

echo "Building tools for product data enrich"

  /bin/mkdir -p $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib

  /bin/bash -c "export MIK_ASKPASS_HOST=${SIEBEL_HOST} ; export MIK_ASKPASS_USER=${SIEBEL_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${SIEBEL_HOST_OS_USER_NAME}@${SIEBEL_HOST}:${SIEBEL_HOST_APPLICATIONS_HOME_DIR}/siebel/siebsrvr/classes/Siebel.jar $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib"
  /bin/bash -c "export MIK_ASKPASS_HOST=${SIEBEL_HOST} ; export MIK_ASKPASS_USER=${SIEBEL_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${SIEBEL_HOST_OS_USER_NAME}@${SIEBEL_HOST}:${SIEBEL_HOST_APPLICATIONS_HOME_DIR}/siebel/siebsrvr/classes/SiebelJI_enu.jar $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib"

  /bin/mkdir -p $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/build/classes
  $JAVA_HOME/bin/javac -d $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/build/classes -classpath $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib/Siebel.jar -sourcepath $MANAGEABLE_INSTALL_TOOL_DIR/common/src-apis $MANAGEABLE_INSTALL_TOOL_DIR/common/src-apis/Siebel*.java

echo "Tools built"
#--------------------------------------------------------------------------------

if [ $IMPORT_DEFAULT_PRODUCT_DATA == 1 ]
then

  echo "Enriching Siebel reference data products started"

#  $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/build/classes:$MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib/Siebel.jar:$MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib/SiebelJI_enu.jar SiebelWorkspaceProject $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/data/default_siebel_workspace.xml "MIK ${IMPORT_REFERENCE_SCRIPT_NAME}"

  $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/build/classes:$MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib/Siebel.jar:$MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib/SiebelJI_enu.jar SiebelWorkspaceProject $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/data/siebel_product_release.xml "Demo Workspace"
 
 echo "Enriching Siebel reference data product completed"
fi

#--------------------------------------------------------------------------------
#Enrich custom Siebel reference data files using utilities

if [ $IMPORT_CUSTOM_PRODUCT_DATA == 1 ]
then

echo "Enriching Siebel custom reference data started"

for DATA_FILE in $(echo $SIEBEL_REFERENCE_DATA_FILES | tr "," "\n")
do

  echo "Enriching Siebel custom data file $DATA_FILE started"
  $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/build/classes:$MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib/Siebel.jar:$MANAGEABLE_INSTALL_TOOL_DIR/${IMPORT_REFERENCE_SCRIPT_NAME}/siebel/lib/SiebelJI_enu.jar SiebelWorkspaceProject $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME $DATA_FILE "MIK ${IMPORT_REFERENCE_SCRIPT_NAME}"
  echo "Enriching Siebel custom data file $DATA_FILE completed"

done
  
fi


