#!/bin/sh

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

#--------------------------------------------------------------------------------
#custom Siebel Account data using webservices


	echo "Creating Siebel Accounts"

	#Status of the Http request -w '%{http_code}'
	status_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"document/http://siebel.com/SelfService/Common/Account:SelfServiceAccountExecute\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_siebel_accounts.xml  http://$SIEBEL_HOST:8080/eai_enu/start.swe?SWEExtSource=WebService\&SWEExtCmd=Execute\&UserName=SADMIN\&Password=sadmin123\&WSSOAP=1 -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/cust_acct_response.xml)

	# Status of 200 is a succesfull request
	if [ $status_code -eq "200" ]
	then
		array[0]="='AirComm_IT_Proc'"
		array[1]="='AirComm_Logistic_Proc'"
		array[2]="='AirComm_Retail_Proc'"
		array[3]="='WC_NY_Fin'"
		array[4]="='WC_OR_Fin'"
		array[5]="='Andrew Bennett'"
		array[6]="='Paula Bennett'"
		array[7]="='Amanda Walsh'"
		array[8]="='Jennifer Walsh'"
		array[9]="='John Harris'"

		for i in "${!array[@]}"

		do

			ACCOUNT_NAME=${array[$i]}
			SEARCH="ACCOUNT_NAME"
			REPLACE=${array[$i]}
			echo $ACCOUNT_NAME
			cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/query_siebel_accounts.xml.template | sed -e "s/$SEARCH/$REPLACE/" > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/query_siebel_accounts.xml

			/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"document/http://siebel.com/SelfService/Common/Account:SelfServiceAccountQueryPage\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/query_siebel_accounts.xml  http://$SIEBEL_HOST:8080/eai_enu/start.swe?SWEExtSource=WebService\&SWEExtCmd=Execute\&UserName=SADMIN\&Password=sadmin123\&WSSOAP=1 -o $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/response.xml
			PRIMARYBILLINGPROFILEID="Y"
			#Account Id
			ACCOUNTID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/response.xml '/SOAP-ENV:Envelope/SOAP-ENV:Body/ns:SelfServiceAccountQueryPage_Output/ListOfSSAccount/Account/Id/text()')

			#Address Id
			ADDRESSID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/response.xml '/SOAP-ENV:Envelope/SOAP-ENV:Body/ns:SelfServiceAccountQueryPage_Output/ListOfSSAccount/Account/PrimaryAddressId/text()')

			#Address Name
			ADDRESSNAME=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/response.xml '/SOAP-ENV:Envelope/SOAP-ENV:Body/ns:SelfServiceAccountQueryPage_Output/ListOfSSAccount/Account/PrimaryAccountStreetAddress/text()')

			#Contact First Name
			CONTFIRSTNAME=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/response.xml '/SOAP-ENV:Envelope/SOAP-ENV:Body/ns:SelfServiceAccountQueryPage_Output/ListOfSSAccount/Account/ListOfContact/Contact/FirstName/text()')

			#Contact Last Name
			CONTLASTNAME=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/response.xml '/SOAP-ENV:Envelope/SOAP-ENV:Body/ns:SelfServiceAccountQueryPage_Output/ListOfSSAccount/Account/ListOfContact/Contact/LastName/text()')

			cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_siebel_accountbillingprofile.xml.template | sed -e "s/ACCOUNTID/$ACCOUNTID/" -e "s/ADDRESSID/$ADDRESSID/" -e "s/ADDRESSNAME/$ADDRESSNAME/" -e "s/PRIMARYBILLINGPROFILEID/$PRIMARYBILLINGPROFILEID/" -e "s/CONTFIRSTNAME/$CONTFIRSTNAME/" -e "s/CONTLASTNAME/$CONTLASTNAME/"> $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_siebel_accountbillingprofile.xml
	
			echo "Creating Siebel Account Billing Profile"

			/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"document/http://www.siebel.com/SelfService/Common/AccountBillingProfile:SelfServiceAccountBillingProfileInsertAndSetPrimary\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_siebel_accountbillingprofile.xml  http://$SIEBEL_HOST:8080/eai_enu/start.swe?SWEExtSource=WebService\&SWEExtCmd=Execute\&UserName=SADMIN\&Password=sadmin123\&WSSOAP=1 -o $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/billing_response.xml

			#John Harris requires an additional 2 billing profiles in the same account.
			if [ "$ACCOUNT_NAME" == "='John Harris'" ]; then
 	 		  PRIMARYBILLINGPROFILEID="N"
			  cat $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_siebel_accountbillingprofile.xml.template | sed -e "s/ACCOUNTID/$ACCOUNTID/" -e "s/ADDRESSID/$ADDRESSID/" -e "s/ADDRESSNAME/$ADDRESSNAME/" -e "s/PRIMARYBILLINGPROFILEID/$PRIMARYBILLINGPROFILEID/" -e "s/CONTFIRSTNAME/$CONTFIRSTNAME/" -e "s/CONTLASTNAME/$CONTLASTNAME/"> $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_siebel_accountbillingprofile.xml
 			  for create in {1..2}
			  do
				/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"document/http://www.siebel.com/SelfService/Common/AccountBillingProfile:SelfServiceAccountBillingProfileInsertAndSetPrimary\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/create_siebel_accountbillingprofile.xml  http://$SIEBEL_HOST:8080/eai_enu/start.swe?SWEExtSource=WebService\&SWEExtCmd=Execute\&UserName=SADMIN\&Password=sadmin123\&WSSOAP=1 -o $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/billing_response.xml
			  done
			fi

		done
	else
		echo "http request to create Siebel accounts failed with code=$status_code"
	fi




