/*

 Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

 The MIT License (MIT)

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/

/*
   DESCRIPTION
    <short description of component this file declares/defines>

   PRIVATE CLASSES
    <list of private classes defined - with one-line descriptions>

   NOTES
    <other useful comments, qualifications, etc.>

   MODIFIED    (MM/DD/YY)
    vidatta     01/19/15 - Creation
 */

/**
 *  @version $Header: commsplatform/managementpack/scripts/importreferencedata/src/CompareProductList.java /cgbuams_main/3 2015/03/12 20:55:02 anirana Exp $
 *  @author  vidatta 
 *  @since   release specific (what release of product did this appear in)
 */
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Scanner;

public class CompareProductList {

	public static void main(String[] args) throws IOException {
		String view_home = args[0];
		String path = view_home + "importreferencedata/data/";
		File file1 = new File(path + "default_pdc_pricing.txt");
		File file2 = new File(path + "siebel_product_list.txt");
		List<String> content1 = getContent(file1);
		List<String> content2 = getContent(file2);
		List<String> content3 = new ArrayList<String>();

		for (String str1 : content1) {
			if (!content2.contains(str1))
				content3.add(str1);
		}

		List<String> errorList = new ArrayList<String>(new LinkedHashSet<String>(content3));
		if (errorList.isEmpty()) {
			System.out.println("Validation Complete");
		} else {
			System.out.println("Product that are not available in Siebel");
			for (String str3 : errorList) {
				System.out.println(str3);
			}

		}
	}

	static List<String> getContent(File file) throws FileNotFoundException {

		List<String> contentFile = new ArrayList<String>();
		Scanner fileScanner = new Scanner(file);
		while (fileScanner.hasNextLine()) {
			String data = fileScanner.nextLine();
			contentFile.add(data.trim());
		}
		fileScanner.close();
		return contentFile;
	}

	static void sortingFile(String path) throws IOException {
		FileReader fileReader = new FileReader(path);
		BufferedReader bufferedReader = new BufferedReader(fileReader);
		String inputLine;
		List<String> lineList = new ArrayList<String>();
		while ((inputLine = bufferedReader.readLine()) != null) {
			if (inputLine.contains("SQL"))
				continue;
			lineList.add(inputLine);
		}
		fileReader.close();

		Collections.sort(lineList);
		FileWriter fileWriter = new FileWriter(path);
		PrintWriter out = new PrintWriter(fileWriter);
		for (String outputLine : lineList) {
			out.println(outputLine);
		}
		out.flush();
		out.close();
		fileWriter.close();
	}

}

