#!/bin/bash

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH
fi

source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

MEDIA_MAP="${MANAGEABLE_INSTALL_TOOL_DIR}/common/media_map"

echo "Configuration read"

#-------------------------------------------------------------------------------
# Collect media

echo "Staging the Oracle HTTP server media"

NAME_COUNT=`cat ${MEDIA_MAP} | grep -i ${MEDIA_NAME_OHS} | wc -l`
echo "Number of instances of ${MEDIA_NAME_OHS} found in MEDIA MAP file = "${NAME_COUNT}
if [ ${NAME_COUNT} > 0 ]
    then
      mik_collect_media ${MEDIA_NAME_OHS}
	  /usr/bin/unzip -o -q -d $WEBTIER_MEDIA_DOWNLOAD_DIR $WEBTIER_MEDIA_DOWNLOAD_DIR/${MEDIA_FILE_OHS}
fi

echo "Oracle HTTP server media staged"

#-------------------------------------------------------------------------------
# Install OHS

echo "Installing the Oracle HTTP server"

echo "OHS_SCRIPT_MODULE_NAME $OHS_SCRIPT_MODULE_NAME"
/bin/rm -rf $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/map.properties
echo WEBTIER_MIDDLEWARE_HOME_DIR=$WEBTIER_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/map.properties
echo DEFAULT_APPLICATIONS_HOME_DIR=$DEFAULT_APPLICATIONS_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/aia_middleware_scripts/aiafp/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/ohs_install.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/ohs_install.rsp

/bin/rm -rf $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/map.properties
unset DISPLAY

echo "$WEBTIER_MEDIA_DOWNLOAD_DIR/$OHS_INSTALLER -silent -invPtrLoc $DEFAULT_APPLICATIONS_HOME_DIR/oraInst.loc -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/ohs_install.rsp -waitforcompletion"
$WEBTIER_MEDIA_DOWNLOAD_DIR/$OHS_INSTALLER -silent -invPtrLoc $DEFAULT_APPLICATIONS_HOME_DIR/oraInst.loc -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$OHS_SCRIPT_MODULE_NAME/ohs/ohs_install.rsp -waitforcompletion

echo "Oracle HTTP server installed"

