#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo CONFIGURATION FAILED" ERR
set -e
set -E
set -o pipefail

if [ -z "${MIK_KNOBS_PATH}" ]
then
  MIK_KNOBS_FILE=${THIS_DIR}/../common/knobs
  MIK_KNOBS_RELATIVE_PATH=osm_o2a_scripts/common/knobs
else
  MIK_KNOBS_FILE=${THIS_DIR}/../../${MIK_KNOBS_PATH}  
  MIK_KNOBS_RELATIVE_PATH=${MIK_KNOBS_PATH}
fi


MIK_INSTALL_JAVA=1
source ${MIK_KNOBS_FILE}
## OSM uses JDK 1.7, O2A uses JDK 1.8 This config_access needs to be ran to get JDK 1.8, this has to be set again MIK_INSTALL_JAVA=1!!!
## if at later time, OSM and O2A all use the same JDK version, this MIK_INSTALL_JAVA=   should leave it blank
MIK_INSTALL_JAVA=1

source ${MANAGEABLE_INSTALL_TOOL_DIR}/common/mik_lib

source ${MANAGEABLE_INSTALL_TOOL_DIR}/common/media_map

#--------------------------------------------------------------------------------
# Configure

mik_create_access ${OSM_HOST} ${OSM_HOST_OS_USER_NAME}
mik_create_su_access ${OSM_HOST} ${OSM_HOST_OS_USER_NAME}

mik_run_remote ${OSM_HOST} ${OSM_HOST_OS_USER_NAME} ${OSM_SCRIPT_MODULE_NAME}/osm/go_prepare_osm_topology.sh ${OSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR} ${MIK_KNOBS_RELATIVE_PATH}
/bin/bash -c "export MIK_ASKPASS_HOST=${OSM_HOST} ; export MIK_ASKPASS_USER=${OSM_HOST_OS_USER_NAME} ; export SSH_ASKPASS=${MANAGEABLE_INSTALL_TOOL_DIR}/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${OSM_HOST_OS_USER_NAME}@${OSM_HOST}:${OSM_HOST_MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/osm/osm_topology ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/osm/osm_topology"
source ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/osm/osm_topology
source ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/common/osm_lib
populate_osm_servers
for i in `/usr/bin/seq 1 ${#servers[*]}`;
do
  mik_create_access ${servers[i]} ${users[i]}
done

if [ ${OSM_ONLY_COM_DOWN} != "1" ]
then
  mik_create_access ${AIA_MIDDLEWARE_HOST} ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}
fi

/bin/cp ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSMO2ADEV_SCRIPT_MODULE_NAME}/common/knobs.template ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSMO2ADEV_SCRIPT_MODULE_NAME}/common/knobs_osmo2a
${JAVA_HOME}/bin/java -cp ${MANAGEABLE_INSTALL_TOOL_DIR}/common config_knobs -file=${MANAGEABLE_INSTALL_TOOL_DIR}/${OSMO2ADEV_SCRIPT_MODULE_NAME}/common/knobs_osmo2a -DDEV_HOST=${DEV_HOST} -DDEV_HOST_OS_USER_NAME=${DEV_HOST_OS_USER_NAME} -DDEV_HOST_MANAGEABLE_INSTALL_TOOL_DIR=${DEV_HOST_MANAGEABLE_INSTALL_TOOL_DIR} -DDEV_HOST_MEDIA_DOWNLOAD_DIR=${DEV_HOST_MEDIA_DOWNLOAD_DIR} -DDEV_HOST_APPLICATIONS_HOME_DIR=${DEV_HOST_APPLICATIONS_HOME_DIR} -DDESIGN_STUDIO_COM_WORKSPACE_NAME=${DESIGN_STUDIO_COM_WORKSPACE_NAME} -DDESIGN_STUDIO_SOM_WORKSPACE_NAME=${DESIGN_STUDIO_SOM_WORKSPACE_NAME}
/bin/bash -c "export MIK_KNOBS_PATH=${OSMO2ADEV_SCRIPT_MODULE_NAME}/common/knobs_osmo2a ; ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSMO2ADEV_SCRIPT_MODULE_NAME}/common/config_access.sh"

/bin/bash -c "${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/common/config_access.sh"
echo Access configured
