#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"
echo "---------------------------------------------------------------------------------------------------------------------------------------"
echo "MIK_KNOBS_PATH = ${MIK_KNOBS_PATH}"
echo "---------------------------------------------------------------------------------------------------------------------------------------"
echo "THIS_DIR = ${THIS_DIR}"
echo "---------------------------------------------------------------------------------------------------------------------------------------"
if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH  
fi
echo "---------------------------------------------------------------------------------------------------------------------------------------"
echo "MIK_KNOBS_FILE = ${MIK_KNOBS_FILE}"
echo "---------------------------------------------------------------------------------------------------------------------------------------"
source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"
echo "Establishing XServer"
/bin/bash -c "SUDO_ASKPASS=${MANAGEABLE_INSTALL_TOOL_DIR}/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /bin/kill Xvfb ; ${SUDO_PROGRAM} -A -k -E -b -p '%H:%p' /usr/bin/Xvfb :6046"
export DISPLAY=:6046
echo "XServer established"

#-------------------------------------------------------------------------------
# Generate Install Tool Driver Files
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_WEBLOGIC_ADMIN_USER=$OSM_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_WEBLOGIC_ADMIN_USER_PASSWORD=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_ADMIN_SERVER_WEBLOGIC_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_HOST=$OSM_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIAPIP_MEDIA_DOWNLOAD_DIR=$AIAPIP_MEDIA_DOWNLOAD_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_MIDDLEWARE_HOST=$AIA_MIDDLEWARE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_MIDDLEWARE_ADMIN_SERVER_WEBLOGIC_PORT=$AIA_MIDDLEWARE_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo MANAGEABLE_INSTALL_TOOL_DIR=$MANAGEABLE_INSTALL_TOOL_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_O2A_INSTALL_SCRIPT_NAME=$OSM_O2A_INSTALL_SCRIPT_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/osm_security_config.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/osm_security_config.py
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/aia_security_config.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/aia_security_config.py
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo JAVA_HOME=$JAVA_HOME >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo PASSWORDS_ENCRYPTED=$PASSWORDS_ENCRYPTED >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_HOME_DIR=$OSM_WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SUITE_DOMAIN_NAME=$SUITE_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SUITE_DOMAIN_HOME_DIR=$SUITE_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo MANAGEABLE_INSTALL_TOOL_DIR=$MANAGEABLE_INSTALL_TOOL_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_HOST=$OSM_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_ADMIN_USER=$OSM_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
# TODO only needed to get java home in serverstate.pl
echo UIM_HOME_DIR=$UIM_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo ASAP_MEDIA_DOWNLOAD_DIR=$ASAP_MEDIA_DOWNLOAD_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo UIM_MEDIA_DOWNLOAD_DIR=$UIM_MEDIA_DOWNLOAD_DIR>> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo RCU_MEDIA_DOWNLOAD_DIR=$RCU_MEDIA_DOWNLOAD_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo DATABASE_CLIENT_ORACLE_HOME_DIR=$DATABASE_CLIENT_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/commoninfo.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/commoninfo.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties

$MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/prepare_osm_topology.sh ${WEBLOGIC_HOST} ${WEBLOGIC_PORT} ${WEBLOGIC_ADMIN_USER} ${WEBLOGIC_ADMIN_USER_PASSWORD} ${WEBLOGIC_HOME_DIR}
echo -e "\n" >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/commoninfo.properties
/bin/bash -c "set -a ; source $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/osm_topology ; $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/common generate_topology >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/commoninfo.properties"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo JAVA_HOME=$JAVA_HOME>> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_HOME_DIR=$OSM_WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SUITE_DOMAIN_NAME=$SUITE_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SUITE_DOMAIN_HOME_DIR=$SUITE_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo MANAGEABLE_INSTALL_TOOL_DIR=$MANAGEABLE_INSTALL_TOOL_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_HOST=$OSM_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_ADMIN_USER=$OSM_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
# TODO only needed to get java home in serverstate.pl
echo UIM_HOME_DIR=$UIM_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/suite_install.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/suite_install.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties

echo -e "\n1;" >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/commoninfo.properties
/bin/sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/commoninfo.properties'\";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/prePWLCInit.pl
/bin/sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/${OSM_SCRIPT_MODULE_NAME}/osm/commoninfo.properties'\";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/postPWLCInit.pl
/bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/init_steps.sh"

#-------------------------------------------------------------------------------
# Install development environment

echo "Configuring Accounts SAF Agent"

/bin/bash -c "${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/accounts_config/go.sh"

echo "Accounts SAF Agent configured"

echo "Installing development environment"

/bin/bash -c "MIK_KNOBS_PATH=${OSMO2ADEV_SCRIPT_MODULE_NAME}/common/knobs_osmo2a ; export MIK_KNOBS_PATH ; ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/go.sh"

echo "Development environment installed"

###/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -Dhost=$OSM_HOST -Dport=$OSM_ADMIN_SERVER_WEBLOGIC_PORT -Dtarget=${CARTRIDGE_TARGET} -Dusername=$OSM_WEBLOGIC_ADMIN_USER -Dpassword=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD -DcartridgeType=OSM -DfileLocation=$AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/OSM.PIP_COM/OracleComms_OSM_O2A_COM_CSO_Solution/cartridgeBin/OracleComms_OSM_O2A_COM_CSO_Solution.par -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml headless.build.deploy"

source $SUITE_DOMAIN_HOME_DIR/bin/setDomainEnv.sh
SOLUTION_SAF_PASSWORD=`$JAVA_HOME/bin/java weblogic.security.Encrypt $OSM_WEBLOGIC_ADMIN_USER_PASSWORD`
SOLUTION_UIM_SAF_PASSWORD=`$JAVA_HOME/bin/java weblogic.security.Encrypt $OSM_WEBLOGIC_ADMIN_USER_PASSWORD`
SOLUTION_TOM_SAF_PASSWORD=`$JAVA_HOME/bin/java weblogic.security.Encrypt $OSM_WEBLOGIC_ADMIN_USER_PASSWORD`
cd -

/bin/sh -c "export CONFIG_JVM_ARGS=\"-Djava.security.egd=file:/dev/./urandom -Dweblogic.management.confirmKeyfileCreation=true\" ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/osm_security_config.py"
/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_O2A_INSTALL_SCRIPT_NAME/osm_o2a/aia_security_config.py ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_O2A_INSTALL_SCRIPT_NAME/osm_o2a/aia_security_config.py"
/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; export CONFIG_JVM_ARGS=\\\"-Djava.security.egd=file:/dev/./urandom -Dweblogic.management.confirmKeyfileCreation=true\\\"  ; $AIA_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_O2A_INSTALL_SCRIPT_NAME/osm_o2a/aia_security_config.py'\""
/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR/$OSM_O2A_INSTALL_SCRIPT_NAME/osm_o2a/aiaConfigFile.secure $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a"
/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR/$OSM_O2A_INSTALL_SCRIPT_NAME/osm_o2a/aiaKeyFile.secure $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a"

SOLUTION_COM_SAF_PASSWORD=`/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; source $AIA_WEBLOGIC_DOMAIN_HOME_DIR/bin/setDomainEnv.sh > /dev/null; $JAVA_HOME/bin/java weblogic.security.Encrypt $OSM_WEBLOGIC_ADMIN_USER_PASSWORD'\""`
SOLUTION_SOM_SAF_PASSWORD=`/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; source $AIA_WEBLOGIC_DOMAIN_HOME_DIR/bin/setDomainEnv.sh > /dev/null; $JAVA_HOME/bin/java weblogic.security.Encrypt $OSM_WEBLOGIC_ADMIN_USER_PASSWORD'\""`
/bin/bash -c "cp $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/aiaConfigFile.secure $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/aiaConfigFile.secure "
/bin/bash -c "cp $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/aiaKeyFile.secure $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/aiaKeyFile.secure "


/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST}:$AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aia_topology $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a"
source $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/aia_topology

source ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/osm/osm_topology

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_SDK_HOME_DIR=$OSM_SDK_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo JAVA_HOME=$JAVA_HOME >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_WEBLOGIC_HOME_DIR=$OSM_WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo DESIGN_STUDIO_HOME_DIR=$DESIGN_STUDIO_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_HOST=$OSM_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo OSM_ADMIN_SERVER_WEBLOGIC_PORT=$OSM_ADMIN_SERVER_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties

### if cluster using Proxy port, if no cluster using managed server port. cluster server name should be cluster
if [ ${OSM_CLUSTER} == "1" ]
then
  echo OSM_SERVER_NAME=$CLUSTER_NAME_OSM >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties  
else
  echo OSM_SERVER_NAME=$MSERVER_OSM_NAME_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties  
fi

if [ ${OSM_CLUSTER} == "1" ]
then  
  echo OSM_SERVER_PORT=$PSERVER_OSM_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
else 
  echo OSM_SERVER_PORT=$MSERVER_OSM_PORT_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
fi

#echo OSM_SERVER_NAME=$MSERVER_OSM_NAME_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
#echo OSM_SERVER_PORT=$MSERVER_OSM_PORT_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_MIDDLEWARE_HOST=$AIA_MIDDLEWARE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_MIDDLEWARE_PORT=$RODOD_AIA_WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_MIDDLEWARE_SOA_PORT=$RODOD_AIA_MSERVER_SOA_PORT_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo AIA_SERVER_NAME=$MSERVER_SOA_NAME_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SOLUTION_SAF_PASSWORD=$SOLUTION_SAF_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SOLUTION_COM_SAF_PASSWORD=$SOLUTION_COM_SAF_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SOLUTION_SOM_SAF_PASSWORD=$SOLUTION_SOM_SAF_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SOLUTION_UIM_SAF_PASSWORD=$SOLUTION_UIM_SAF_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo SOLUTION_TOM_SAF_PASSWORD=$SOLUTION_TOM_SAF_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties
echo O2A_AIA_SAF_SERVERURLS=$O2A_AIA_SAF_SERVERURLS >> $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/build.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/build.properties

/bin/bash -c "cp $MANAGEABLE_INSTALL_TOOL_DIR/osm_o2a_scripts/osm_o2a/build.properties $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.properties ; cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; rm -rf security ; mkdir security"

/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -Dwlsadmin.user=$OSM_WEBLOGIC_ADMIN_USER -Dwlsadmin.password=$OSM_WEBLOGIC_ADMIN_USER_PASSWORD -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml create-osm-admin-server-xmlie-encrypted-password-properties-file"

/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -Dosm.password=$OSM_PASSWORD -Dosmoe.password=$OSM_PASSWORD -Dosmde.password=$OSM_PASSWORD -Dosmfallout.password=$OSM_PASSWORD -Dosmlf.password=$OSM_PASSWORD -Dosmoelf.password=$OSM_PASSWORD -Dosmlfaop.password=$OSM_PASSWORD -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml create-comsom-encrypted-password-properties-file"

/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -Duim.username=$UIM_USERNAME -Duim.password=$UIM_PASSWORD -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml create-uim-encrypted-password-properties-file"

/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -Dtom.username=$TOM_USERNAME -Dtom.password=$TOM_PASSWORD -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml create-tom-encrypted-password-properties-file"

/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -Dcmt.admin.user=$DEPLOY_ADMIN_USER -Dcmt.admin.password=$OSM_PASSWORD  -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml create-cmt-encrypted-password-properties-file"


/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml headless.build.resource.deploy"

/bin/bash -c "cd $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild ; export ANT_HOME=$OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8 ; $OSM_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -f $AIAPIP_MEDIA_DOWNLOAD_DIR/cartridges/headlessBuild/build.xml headless.deploy"


echo "OSM O2A Cartridges deployed"
# Bug 26364847
#echo "Assigning Account workgroups"
#/bin/bash -c "export MIK_KNOBS_PATH= ; $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/accounts_workgroup.sh o2a"
#echo "Workgroups Assigned"
