#!/bin/bash

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH  
fi

source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

echo "Configuration read"

#-------------------------------------------------------------------------------
# Install Design Studio

if [ ! -d ${DESIGN_STUDIO_HOME_DIR} ]
then
  echo "Installing Design Studio"

  /bin/bash -c "MIK_KNOBS_PATH=${DESIGNSTUDIO_SCRIPT_MODULE_NAME}/common/knobs_o2c ; export MIK_KNOBS_PATH ; $MANAGEABLE_INSTALL_TOOL_DIR/${DESIGNSTUDIO_SCRIPT_MODULE_NAME}/designstudio/go.sh"
    
  /bin/mkdir -p ${DESIGN_STUDIO_HOME_DIR}/configuration/.settings 
  /bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo HTTP_PROXY_HOST=$HTTP_PROXY_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo HTTP_PROXY_PORT=$HTTP_PROXY_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo HTTPS_PROXY_HOST=$HTTPS_PROXY_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo HTTPS_PROXY_PORT=$HTTPS_PROXY_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  #$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/org.eclipse.core.net.prefs.template > ${DESIGN_STUDIO_HOME_DIR}/configuration/.settings/org.eclipse.core.net.prefs
  /bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties

  /bin/mkdir -p ${DESIGN_STUDIO_HOME_DIR}/template/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings
  /bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo OSM_SDK_HOME_DIR=$OSM_SDK_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo JDK_HOME_DIR=$JDK_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo WEBLOGIC_HOME_DIR=$WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/com.mslv.studio.provisioning.prefs.template > ${DESIGN_STUDIO_HOME_DIR}/template/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings/com.mslv.studio.provisioning.prefs
  /bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties

  /bin/mkdir -p ${DESIGN_STUDIO_HOME_DIR}/template/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings
  /bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties
  $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/oracle.communications.sce.osm.orchestration.aia.prefs.template > ${DESIGN_STUDIO_HOME_DIR}/template/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings/oracle.communications.sce.osm.orchestration.aia.prefs
  /bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/map.properties

  /bin/mkdir -p ${DESIGN_STUDIO_HOME_DIR}/template/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings
  /bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/${OSMO2ADEV_SCRIPT_MODULE_NAME}/osm_o2adev/org.eclipse.core.resources.prefs ${DESIGN_STUDIO_HOME_DIR}/template/workspace/.metadata/.plugins/org.eclipse.core.runtime/.settings/org.eclipse.core.resources.prefs

  echo "Design Studio installed"
fi
