#!/bin/bash

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

echo "Configuration read"

#--------------------------------------------------------------------------------
# Stopping OSM

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo JAVA_HOME=$JAVA_HOME>> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo PASSWORDS_ENCRYPTED=$PASSWORDS_ENCRYPTED >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOME_DIR=$WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo SUITE_DOMAIN_NAME=$SUITE_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo SUITE_DOMAIN_HOME_DIR=$SUITE_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo MANAGEABLE_INSTALL_TOOL_DIR=$MANAGEABLE_INSTALL_TOOL_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_CLIENT_ORACLE_HOME_DIR=$DATABASE_CLIENT_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo -e "\n" >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties
/bin/bash -c "set -a ; source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/knobs ; $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common generate_topology >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo JAVA_HOME=$JAVA_HOME>> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_CLIENT_ORACLE_HOME_DIR=$DATABASE_CLIENT_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_ADMIN_USER=$WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOME_DIR=$WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo SUITE_DOMAIN_NAME=$SUITE_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_HOST=$DATABASE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_PORT=$DATABASE_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SID=$DATABASE_SID >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYSTEM_USER_NAME=$DATABASE_SYSTEM_USER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYSTEM_USER_PASSWORD=$DATABASE_SYSTEM_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_MEDIA_DOWNLOAD_DIR=$OSM_MEDIA_DOWNLOAD_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_HOME_DIR=$OSM_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_GLOBAL_NAME=$DATABASE_GLOBAL_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYS_USER_NAME=$DATABASE_SYS_USER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYS_USER_PASSWORD=$DATABASE_SYS_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/suite_install.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/suite_install.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

echo -e "\n1;" >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties
/bin/sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties'\";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/prePWLCInit.pl
/bin/sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties'\";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/postPWLCInit.pl
/bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/init_steps.sh"

echo "Stopping WebLogic servers"

/bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh stopManagedServers,pollManagedServerStop"


if [ $OSM_CLUSTER -eq 1 ] && [ ! -z "$PSERVER_OSM_NAME" ]
then
  echo "Stopping OSM proxy"
  /bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh stopManagedServers $PSERVER_OSM_NAME ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh pollManagedServerStop $PSERVER_OSM_NAME"
  echo "OSM proxy stopped"
fi

/bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh stopAdminServer,pollAdminServerStop"

echo "WebLogic servers stopped"
