#!/bin/bash

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

# -----------------------------------------------------------------------------
# Generate Tear Sheet

echo "-------------------------------------------------------------------------------"
echo "OSM"
echo "-------------------------------------------------------------------------------"
  echo
  echo "OSM $OSM_SCRIPT_MODULE_NAME"
  echo "  URLs:"
  if [ $OSM_CLUSTER -eq 1 ] && [ ! -z "$PSERVER_OSM_NAME" ]
  then
    echo "    http://${PSERVER_OSM_HOSTNAME}:${PSERVER_OSM_PORT}/osm (osmadmin/Oracle123)"
  else
    echo "    http://${MSERVER_OSM_HOSTNAME_1}:${MSERVER_OSM_PORT_1}/osm (osmadmin/Oracle123)"
  fi
  echo "    http://${WEBLOGIC_HOST}:${WEBLOGIC_PORT}/console (${WEBLOGIC_ADMIN_USER}/${WEBLOGIC_ADMIN_USER_PASSWORD})"
  echo "  Host: ${WEBLOGIC_HOST} (${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`)"
  echo "  Logs:"
  for i in `/usr/bin/seq 1 ${OSM_SERVER_COUNT}`;
  do
    eval MANAGED_SERVER_NAME=\$MSERVER_OSM_NAME_${i}   
	echo "    ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBLOGIC_HOST}:${SUITE_DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/logs/${MANAGED_SERVER_NAME}.log"


  done
  echo "  Admin:"
  echo "    ${MANAGEABLE_INSTALL_TOOL_DIR}/$OSM_SCRIPT_MODULE_NAME/admin/start_osm.sh"
  echo "    ${MANAGEABLE_INSTALL_TOOL_DIR}/$OSM_SCRIPT_MODULE_NAME/admin/stop_osm.sh"
  echo "  OSM home: ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBLOGIC_HOST}:${OSM_HOME_DIR}"
  echo "  OSM domain homes:"
  for i in `/usr/bin/seq 1 ${OSM_SERVER_COUNT}`;
  do
    eval MANAGED_SERVER_NAME=\$MSERVER_OSM_NAME_${i}   
	echo "    ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBLOGIC_HOST}:${SUITE_DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/"

  done
# TODO get from remote host
#  echo "    {`/bin/more /etc/oracle-release` (`/bin/uname -m`)}"
# TODO DB schemas and passwords
echo
echo "Oracle Database 12.1.0.2.0"
echo "  ${DATABASE_HOST}:${DATABASE_PORT}:${DATABASE_GLOBAL_NAME}"
echo "  EM DB:"
echo "    https://${DATABASE_HOST}:1158/em (sys/${DATABASE_SYS_USER_PASSWORD} as sysdba)"
echo "  Host: ${DATABASE_HOST} (${DATABASE_HOST_OS_USER_NAME}/`mik_getsec ${DATABASE_HOST} ${DATABASE_HOST_OS_USER_NAME}`)"
echo "  SYS user: sys/${DATABASE_SYS_USER_PASSWORD}"
echo "  SYSTEM user: system/${DATABASE_SYSTEM_USER_PASSWORD}"
echo "  Oracle home: ${DATABASE_HOST_OS_USER_NAME}/`mik_getsec ${DATABASE_HOST} ${DATABASE_HOST_OS_USER_NAME}`@${DATABASE_HOST}:${DATABASE_ORACLE_HOME_DIR}/"
# TODO get from remote host
#  echo "    {`/bin/more /etc/oracle-release` (`/bin/uname -m`)}"
echo
echo "RODOD Install Kit"
echo "  Working MIK home: `/usr/bin/id -un`@`/bin/hostname -f`:${MANAGEABLE_INSTALL_TOOL_DIR}/"
echo "  WebLogic MIK home: ${WEBLOGIC_HOST_OS_USER_NAME}/`mik_getsec ${WEBLOGIC_HOST} ${WEBLOGIC_HOST_OS_USER_NAME}`@${WEBLOGIC_HOST}:${WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR}/"
echo "  DB MIK home: ${DATABASE_HOST_OS_USER_NAME}/`mik_getsec ${DATABASE_HOST} ${DATABASE_HOST_OS_USER_NAME}`@${DATABASE_HOST}:${DATABASE_HOST_MANAGEABLE_INSTALL_TOOL_DIR}/"
echo "-------------------------------------------------------------------------------"
