#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo CONFIGURATION FAILED" ERR
set -e
set -E
set -o pipefail

MIK_INSTALL_JAVA=1
source $THIS_DIR/../common/knobs
MIK_INSTALL_JAVA=

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

#--------------------------------------------------------------------------------
# Configure access for hosts
set -x
/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/knobs.template $MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/knobs_osm
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common config_knobs -file=$MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/knobs_osm -DDATABASE_MEDIA_DOWNLOAD_DIR=$DATABASE_MEDIA_DOWNLOAD_DIR -DDATABASE_HOST_MANAGEABLE_INSTALL_TOOL_DIR=$DATABASE_HOST_MANAGEABLE_INSTALL_TOOL_DIR -DDATABASE_HOST_APPLICATIONS_HOME_DIR=$DATABASE_HOST_APPLICATIONS_HOME_DIR -DDATABASE_HOST=$DATABASE_HOST -DDATABASE_HOST_NAME=$DATABASE_HOST_NAME -DDATABASE_HOST_OS_USER_NAME=$DATABASE_HOST_OS_USER_NAME -DDATABASE_HOST_OS_GROUP_NAME=$DATABASE_HOST_OS_GROUP_NAME -DDATABASE_HOST_MEDIA_DOWNLOAD_DIR=$DATABASE_HOST_MEDIA_DOWNLOAD_DIR -DDATABASE_HOME_DIR=$DATABASE_HOME_DIR -DDATABASE_ORACLE_HOME_DIR=$DATABASE_ORACLE_HOME_DIR -DDATABASE_SID=$DATABASE_SID -DDATABASE_SID_UPPERCASE=$DATABASE_SID_UPPERCASE -DDATABASE_FILESYSTEM_DIR=$DATABASE_FILESYSTEM_DIR -DDATABASE_DATA_DIR=$DATABASE_DATA_DIR -DDATABASE_SYS_USER_NAME=$DATABASE_SYS_USER_NAME -DDATABASE_SYS_USER_PASSWORD=$DATABASE_SYS_USER_PASSWORD -DDATABASE_SYSTEM_USER_NAME=$DATABASE_SYSTEM_USER_NAME -DDATABASE_SYSTEM_USER_PASSWORD=$DATABASE_SYSTEM_USER_PASSWORD -DDATABASE_PORT=$DATABASE_PORT -DDATABASE_GLOBAL_NAME=$DATABASE_GLOBAL_NAME

/bin/bash -c "export MIK_KNOBS_PATH=${DATABASE_SCRIPT_MODULE_NAME}/common/knobs_osm ; $MANAGEABLE_INSTALL_TOOL_DIR/${DATABASE_SCRIPT_MODULE_NAME}/common/config_access.sh"
mik_create_access $DATABASE_HOST $DATABASE_HOST_OS_USER_NAME

mik_create_su_access $WEBLOGIC_HOST $WEBLOGIC_HOST_OS_USER_NAME

source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/osm_lib
populate_osm_servers
for i in `/usr/bin/seq 1 ${#servers[*]}`;
do
  mik_create_access ${servers[i]} ${users[i]}
done

#################DB, FMW, OSM, JBOSS medias ############
mik_create_media_access DB_CLIENT_64
mik_create_media_access FMW
#mik_create_media_access V138469_02
mik_create_media_access OSM
mik_create_media_access JBOSS_1_4_1_SP13

mik_run_remote $WEBLOGIC_HOST $WEBLOGIC_HOST_OS_USER_NAME $OSM_SCRIPT_MODULE_NAME/common/prevalidate.sh $WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR

/bin/cp ${MANAGEABLE_INSTALL_TOOL_DIR}/${OSM_SCRIPT_MODULE_NAME}/common/knobs_account.template ${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/accounts_config/assign_workgroup/knobs_osm_assign_workgroups
${JAVA_HOME}/bin/java -cp ${MANAGEABLE_INSTALL_TOOL_DIR}/common config_knobs -file=${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/accounts_config/assign_workgroup/knobs_osm_assign_workgroups -DMANAGEABLE_INSTALL_TOOL_DIR=${WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR} -DOSM_SCRIPT_MODULE_NAME=${OSM_SCRIPT_MODULE_NAME} -DOSM_SDK_HOME_DIR=${OSM_HOME_DIR}/SDK -DJAVA_HOME=${JAVA_HOME} -DOSM_DB_USER=osm3032 -DOSM_DB_PASSWORD=${DATABASE_SYS_USER_PASSWORD} -DOSM_WEBLOGIC_ADMIN_USER=${WEBLOGIC_ADMIN_USER} -DOSM_WEBLOGIC_ADMIN_USER_PASSWORD=${WEBLOGIC_ADMIN_USER_PASSWORD} -DOSM_DATABASE_HOST=${DATABASE_HOST} -DOSM_DATABASE_PORT=${DATABASE_PORT} -DOSM_DATABASE_SID=${DATABASE_SID} -DOSM_ADMIN_SERVER_WEBLOGIC_HOST=${WEBLOGIC_HOST} -DOSM_ADMIN_SERVER_WEBLOGIC_PORT=${WEBLOGIC_PORT} -DOSM_WEBLOGIC_MIDDLEWARE_HOME_DIR=${WEBLOGIC_MIDDLEWARE_HOME_DIR}
#/bin/bash -c "export MIK_KNOBS_PATH=accounts_config/accounts_config/assign_workgroup/knobs_osm_assign_workgroups ; ${MANAGEABLE_INSTALL_TOOL_DIR}/accounts_config/common/config_access.sh"


echo Access configured
