#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################

#This script performs the following
	#Stop all Weblogic servers,
	#Remove Weblogic Domain
	#Remove all apps installation directories and  Provisioning Staging location

############################################################

require "commoninfo.properties";
require "decrypt_util.pl";

if($ARGV[0] =~/OSS/) {
	$cmd="perl cluster_shutdownservers.pl";
	system($cmd);
	$cmd="rm -rf $DOMAIN_HOME";
	system($cmd);
	print "removing $DOMAIN_HOME.......\n";
	&osm_cleanup_db();
	&uim_cleanup_db();
	&asap_cleanup_db();
}
if($ARGV[0] =~/OSM/) {
	&osm_cleanup_db();
}
if($ARGV[0] =~/UIM/) {
	&uim_cleanup_db();
}
if($ARGV[0] =~/ASAP/) {
	&asap_cleanup_db();
}

sub osm_cleanup_db {
   open(SUITEPROP,"suite_install.properties");
   while(<SUITEPROP>) {
     chomp($_);
     if($_=~/osm_base.dir/) {
        $osmLocation=(split(/\=/,$_))[1];
     }
     if($_=~/osm.db.host/) {
        $osmdbHost=(split(/\=/,$_))[1];
     }
     if($_=~/osm.db.port/) {
        $osmdbPort=(split(/\=/,$_))[1];
     }
     if($_=~/osm.db.service/) {
        $osmdbService=(split(/\=/,$_))[1];
     }
     if($_=~/osm.db.admin.password/) {
        $enc_osmdbadminPassword=(split(/\=/,$_))[1];
        $osmdbadminPassword=&decryptPassword($enc_osmdbadminPassword,$MIDDLEWARE_HOME,$JAVA_HOME);
     }
     if($_=~/osm.db.user/) {
        $osmSchemaUser=(split(/\=/,$_))[1];
     }
     if($_=~/osm.db.password/) {
        $enc_osmSchemaPassword=(split(/\=/,$_))[1];
        $osmSchemaPassword=&decryptPassword($enc_osmSchemaPassword,$MIDDLEWARE_HOME,$JAVA_HOME);
     }
     if($_=~/osm.ruleEngine.Schema.User/) {
        $osmruleSchemaUser=(split(/\=/,$_))[1];
     }
     if($_=~/osm.ruleEngine.Schema.Password/) {
        $enc_osmruleSchemaPassword=(split(/\=/,$_))[1];
        $osmruleSchemaPassword=&decryptPassword($enc_osmruleSchemaPassword,$MIDDLEWARE_HOME,$JAVA_HOME);
     }
   }
	$cmd="rm -rf $osmLocation";
	system($cmd);

        open(CLEANUP,">osm-cleanup.sql");
        print CLEANUP "DROP USER $osmSchemaUser CASCADE\;\n";
	print CLEANUP "DROP USER $osmruleSchemaUser CASCADE\;\n";
        print CLEANUP "commit;\n";
        print CLEANUP "quit;\n";
        print CLEANUP "\n";
        close(CLEANUP);

	$ENV{'ORACLE_HOME'}="$SQLPLUS_HOME";
	print "########## BEFORE:dropping OSM schema\n";
        $cmd = "$SQLPLUS_HOME/bin/sqlplus sys/$osmdbadminPassword\@$osmdbHost:$osmdbPort/$osmdbService as sysdba \@osm-cleanup.sql";
        system($cmd);
	print "AFTER:dropping OSM schema $cmd \n"

}

sub uim_cleanup_db {
        open(INSTALL_PROP,"suite_install.properties");

        while(<INSTALL_PROP>) {
                chomp($_);
     		if($_=~/uim_base.dir/) {
        		$uimLocation=(split(/\=/,$_))[1];
     		}	 
                if($_ =~ /uim.dbuser.input/) {
                        $uimdb_array= (split("=",$_))[1];
                        $uimdbhost= (split("\"",$uimdb_array))[1];
                        $uimdbUser= (split("\"",$uimdb_array))[5];
                        $enc_uimdbadminPassword= (split("\"",$uimdb_array))[7];
                        $uimdbadminPassword= &decryptPassword($enc_uimdbadminPassword,$MIDDLEWARE_HOME,$JAVA_HOME);
                        $uimdbport= (split("\"",$uimdb_array))[3];
                        $uimdbservice= (split("\"",$uimdb_array))[9];
                }
                if($_ =~ /uim.appschema.input/) {
                        $uim_array= (split("=",$_))[1];
                        $uimappuser= (split("\"",$uim_array))[1];
                        $uimappuser_pass= (split("\"",$uim_array))[3];
                }
                if($_ =~ /uim.mdsdb.input/) {
                        $mds_array= (split("=",$_))[1];
                        $mdsuser= (split("\"",$mds_array))[5];
                        $mdsuser= uc($mdsuser);
                        $uimappuser_pass= (split("\"",$uim_array))[3];
                }
                if($_ =~ /oracle.home.dir/) {
                        $sqlplusHome = (split("=",$_))[1];
                }
        }
        close(INSTALL_PROP);

	$cmd="rm -rf $uimLocation";
	system($cmd);

        open(CLEANUP,">uim-cleanup.sql");
        print CLEANUP "DROP USER $uimappuser CASCADE\;\n";
        print CLEANUP "DROP USER $mdsuser CASCADE\;\n";
        print CLEANUP "delete from SCHEMA_VERSION_REGISTRY where Owner like '$mdsuser%'\;\n";
        print CLEANUP "commit;\n";
        print CLEANUP "quit;\n";
        print CLEANUP "\n";
        close(CLEANUP);

        $ENV{'ORACLE_HOME'}="$SQLPLUS_HOME";
	print "########## BEFORE:dropping UIM schema\n";
        $cmd = "$SQLPLUS_HOME/bin/sqlplus sys/$uimdbadminPassword\@$uimdbhost:$uimdbport/$uimdbservice as sysdba \@uim-cleanup.sql";
	print "$cmd \n";
        system($cmd);
	print "AFTER:dropping UIM schema $cmd \n";	

}

sub asap_cleanup_db {
  open(SUITEPROP,"suite_install.properties");
   while(<SUITEPROP>) {
     chomp($_);
     if($_=~/asap_base.dir/) {
        $asapLocation=(split(/\=/,$_))[1];
     }
     if($_=~/asap.core.nep.user/) {
        $nepuser=(split(/\=/,$_))[1];
     }
     if($_=~/asap.core.sarm.user/) {
        $sarmuser=(split(/\=/,$_))[1];
     }
     if($_=~/asap.core.ctrl.user/) {
        $ctrluser=(split(/\=/,$_))[1];
     }
     if($_=~/asap.core.adm.user/) {
        $admuser=(split(/\=/,$_))[1];
     }
     if($_=~/asap.core.srp.user/) {
        $srpuser=(split(/\=/,$_))[1];
     }
     if($_=~/asap.db.password/) {
        $enc_asapdbadminPassword=(split(/\=/,$_))[1];
		$asapdbadminPassword= &decryptPassword($enc_asapdbadminPassword,$MIDDLEWARE_HOME,$JAVA_HOME);
     }
   }
	$cmd="rm -rf $asapLocation";
	system($cmd);

        open(CLEANUP,">asap-cleanup.sql");
	print CLEANUP "DROP USER $nepuser CASCADE\;\n";
	print CLEANUP "DROP USER $sarmuser CASCADE\;\n";
        print CLEANUP "DROP USER $ctrluser CASCADE\;\n";
        print CLEANUP "DROP USER $admuser CASCADE\;\n";
        print CLEANUP "DROP USER $srpuser CASCADE\;\n";
        print CLEANUP "commit;\n";
        print CLEANUP "quit;\n";
        print CLEANUP "\n";
        close(CLEANUP);

        $ENV{'ORACLE_HOME'}="$SQLPLUS_HOME";
	print "########## BEFORE:dropping ASAP schema\n";
        $cmd = "$SQLPLUS_HOME/bin/sqlplus sys/$asapdbadminPassword\@$uimdbhost:$uimdbport/$uimdbservice as sysdba \@asap-cleanup.sql";
        print "$cmd \n";
        system($cmd);
	print "AFTER:dropping ASAP schema $cmd \n";
}
