#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################

#This script performs the following 
#1. Shuts down all application servers including Admin
# Version 1.0
# Rajesh Prabakarn


############################################################

use File::Copy;
use Getopt::Std;
require "commoninfo.properties";
require "decrypt_util.pl";

$WLST_HOME="$WEBLOGIC_HOME/common/bin";

  if(! -f "$WLST_HOME/wlst.sh") {
     print"Invalid weblogic home location configured in commoninfo.properties. The required files $WLST_HOME/wlst.sh are not found \n";
     exit();
  }

$WL_ADMIN_PASSWORD=&decryptPassword($ADMIN_PASSWORD,$MIDDLEWARE_HOME,$JAVA_HOME);

my %options=();
getopts("f", \%options);
if ($options{f})
{
  $FORCE='true';
} else {
  $FORCE='false';
}



if($#ARGV == 0 ) {
   push(@servList ,"$ARGV[0]");
}
else {
   @arrayList=("OSM","UIM","ASAP","OSMPROXY","UIMPROXY");
   foreach $elem (@arrayList) {
        foreach $app (@$elem) {
                $serv = (split(":",$app))[0];
                push(@servList ,$serv);
        }
   }
   push(@servList ,"AdminServer");

}
   print "servList is |@servList|\n";


#General configurations 

#generate shutdown python script
&gen_shutdownpy();

#Restart all servers
&shutdown_servers();

sub shutdown_servers{
 #print "b4 shutting down";<stdin>;
   $cmd="$WLST_HOME/wlst.sh wlstscripts/shutdown.py";
   &printconsole();
   system($cmd);
   print"$cmd\n";

}

sub gen_shutdownpy {
   #print "shutdown all servers";<stdin>;
   open(SHUTDOWNPY,">wlstscripts/shutdown.py");
   print SHUTDOWNPY "readDomain('$DOMAIN_HOME')\;\n";
   print SHUTDOWNPY "connect('weblogic','$WL_ADMIN_PASSWORD','t3://$ADMIN_HOST:$ADMIN_PORT')\;\n";

   foreach $mngserv (@servList) {
     #Start all Managed servers
     print SHUTDOWNPY "shutdown('$mngserv','Server','true',1200,force='$FORCE')\;\n";
   }
     #print SHUTDOWNPY "shutdown('AdminServer','Server','true',1200,force='$FORCE')\;\n";
   close(SHUTDOWNPY);
}

sub printconsole{
   print"-----------------------------------------------------------------------------\n";
   print"readDomain('$DOMAIN_HOME')\;\n";
   print"connect('weblogic','$WL_ADMIN_PASSWORD','t3://$ADMIN_HOST:$ADMIN_PORT')\;\n";

   foreach $mngserv (@servList) {
     #Start all Managed servers
     print"shutdown('$mngserv','Server','true',1200,force='$FORCE')\;\n";
   }
     #print"shutdown('AdminServer','Server','true',1200,force='$FORCE')\;\n";
   print"-----------------------------------------------------------------------------\n";

}
