#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################

#This script performs the following
  #Creates weblogic domain using domain template jar
  #Exctends domain with ADF and EM applications using domain extension templates

############################################################

use File::Copy;

require "commoninfo.properties";
#require "serverstate.pl";

$WLST_HOME="$WEBLOGIC_HOME/common/bin";
#$DOMAIN_TEMPLATE="$WEBLOGIC_HOME/common/templates/domains/wls.jar";

  if(! -f "$WLST_HOME/wlst.sh") {
     print"Invalid weblogic home location configured in commoninfo.properties. The required files $WLST_HOME/wlst.sh are not found \n";
     exit();
  }


#generate domain creation python script
&gen_domainpy();

#Weblogic domain creation for suite environment
&weblogic_domain();

#Start the Admin server
$cmd = "perl start_Adminserver.pl";
  system($cmd);
   print"$cmd\n";

#To check the admin server status
sleep(20);
&serverstate_wrapper();

#Generate and Run the Python script to configure cluster on weblogic domain
&gen_cluster_setuppy();
$cmd="$WLST_HOME/wlst.sh wlstscripts/cluster_setup.py";
   system($cmd);
   print"$cmd\n";

#Create and Deploy HTTP proxy application
if($#CLUSTERS>=0) {
   &proxyapp();
}

#shutdown the Admin server
$cmd = "perl cluster_shutdownservers.pl AdminServer";
system($cmd);
print"$cmd\n";


sub weblogic_domain {
   $cmd="$WLST_HOME/wlst.sh wlstscripts/createdomain.py";
   &print_console();
   system($cmd);
   print"$cmd\n";
   #print "confirm whether domain is created";<stdin>;
}

sub gen_domainpy {
  open(DOMAINPY,">wlstscripts/createdomain.py");
      print DOMAINPY "readTemplate('$DOMAIN_TEMPLATE')\;\n";
      print DOMAINPY "cd('/Security/base_domain/User/weblogic')\;\n";
      print DOMAINPY "cmo.setPassword('$ADMIN_PASSWORD')\;\n";
      print DOMAINPY "cd('/Servers/AdminServer')\;\n";
      print DOMAINPY "set('ListenPort', $ADMIN_PORT)\;\n";
      print DOMAINPY "set('ListenAddress','$ADMIN_HOST')\;\n";
      print DOMAINPY "writeDomain('$DOMAIN_HOME')\;\n";
      print DOMAINPY "closeTemplate()\;\n";
      print DOMAINPY "exit()\;\n";
   close(DOMAINPY);
}


sub print_console {
      print"readTemplate('$DOMAIN_TEMPLATE')\;\n";
      print"cd('/Security/base_domain/User/weblogic')\;\n";
      print"cmo.setPassword('$ADMIN_PASSWORD')\;\n";
      print"cd('/Servers/AdminServer')\;\n";
      print"set('ListenPort', $ADMIN_PORT)\;\n";
      print"set('ListenAddress','$ADMIN_HOST')\;\n";
      print"writeDomain('$DOMAIN_HOME')\;\n";
      print"closeTemplate()\;\n";
      print"exit()\;\n";
}

sub start_servers {
   $cmd="mkdir -p $DOMAIN_HOME/servers/AdminServer/security";
   system($cmd);
   print"$cmd\n";
   &gen_bootprop();

   #Start Admin server
      $ENV{ANT_HOME}="$ANT_PATH";
      $cmd="$ANT_PATH/bin/ant -f startAdmin.xml -Dstartscript=\"$DOMAIN_HOME/bin/startWebLogic.sh\"";
      system($cmd);
   print"$cmd\n";
}

sub gen_bootprop {
  open(BOOTPROP,">$DOMAIN_HOME/servers/AdminServer/security/boot.properties");
  print BOOTPROP "username=weblogic\n";
  print BOOTPROP "password=$ADMIN_PASSWORD\n";
  close(BOOTPROP);
}

sub gen_cluster_setuppy {
  $cluster="";
 print "@CLUSTERS \n";
  foreach $clust (@CLUSTERS) {
	$cluster = "$cluster,'$clust'";
  }
	$cluster=~s/^\,//;
  print "****clusters = $cluster \n";
  $asapserv="";
  $osmserv="";
  $osmproxyserv="";
  $uimserv="";
  $uimproxyserv="";
  foreach $as (@ASAP) {
		$asname = (split(":",$as))[0];$ashost = (split(":",$as))[1];$asport = (split(":",$as))[2];
		$asapserv = "$asapserv,'$asname:$ashost':$asport";
  }  
      $asapserv=~s/^\,//;$asapserv=~s/^/{/;$asapserv=~s/$/}/;
    print "****asapserv = $asapserv \n";
  foreach $osm (@OSM) {
		$osmname = (split(":",$osm))[0];$osmhost = (split(":",$osm))[1];$osmport = (split(":",$osm))[2];
		$osmserv = "$osmserv,'$osmname:$osmhost':$osmport";
  }  
        $osmserv=~s/^\,//;$osmserv=~s/^/{/;$osmserv=~s/$/}/;
    print "****osmserv = $osmserv \n";
  foreach $uim (@UIM) {
		$uimname = (split(":",$uim))[0];$uimhost = (split(":",$uim))[1];$uimport = (split(":",$uim))[2];
		$uimserv = "$uimserv,'$uimname:$uimhost':$uimport";
  }  
      $uimserv=~s/^\,//;$uimserv=~s/^/{/;$uimserv=~s/$/}/;
    print "****uimserv = $uimserv \n";

  foreach $osmproxy (@OSMPROXY) {
                $osmproxyname = (split(":",$osmproxy))[0];$osmproxyhost = (split(":",$osmproxy))[1];$osmproxyport = (split(":",$osmproxy))[2];
                $osmproxyserv = "$osmproxyserv,'$osmproxyname:$osmproxyhost':$osmproxyport";
  }
        $osmproxyserv=~s/^\,//;$osmproxyserv=~s/^/{/;$osmproxyserv=~s/$/}/;
    print "****osmproxyserv = $osmproxyserv \n";

  foreach $uimproxy (@UIMPROXY) {
                $uimproxyname = (split(":",$uimproxy))[0];$uimproxyhost = (split(":",$uimproxy))[1];$uimproxyport = (split(":",$uimproxy))[2];
                $uimproxyserv = "$uimproxyserv,'$uimproxyname:$uimproxyhost':$uimproxyport";
  }
        $uimproxyserv=~s/^\,//;$uimproxyserv=~s/^/{/;$uimproxyserv=~s/$/}/;
    print "****uimproxyserv = $uimproxyserv \n";

  open(TEMPLATE,"cluster_setup.py");
  open(CLUSTERPY,">wlstscripts/cluster_setup.py");
  while (<TEMPLATE>) {
        chomp($_);
        if($_ =~ /starting the script/ && $#CLUSTERS == -1) {
                $_ = "print 'starting the script ....' \nASAP = $asapserv \nOSM = $osmserv \nUIM = $uimserv\nOSMPROXY = $osmproxyserv\nUIMPROXY = $uimproxyserv\n\nconnect('weblogic','$ADMIN_PASSWORD','t3://$ADMIN_HOST:$ADMIN_PORT')\;\n\n";
        }
        elsif($_ =~ /starting the script/) {
                $_ = "print 'starting the script ....' \nclusters = $cluster\nASAP = $asapserv \nOSM = $osmserv \nUIM = $uimserv\nOSMPROXY = $osmproxyserv\nUIMPROXY = $uimproxyserv\n\nconnect('weblogic','$ADMIN_PASSWORD','t3://$ADMIN_HOST:$ADMIN_PORT')\;\n\n";
        }
        if($#CLUSTERS == -1 && $_ =~ /clus/i){
                $_="#$_";
        }
        print CLUSTERPY "$_\n";
  }
   close(CLUSTERPY);
   close(TEMPLATE);
}

$WLST_HOME="$WEBLOGIC_HOME/common/bin";

sub serverstate_wrapper {
	$flag=0;
	@SERVERLIST =("AdminServer");
	print "adrguments @SERVERLIST\n";
	foreach $server (@SERVERLIST) {
			$count=15;
			chomp($server);
			print "Checking server( $server ) status....\n";
			&admstatus_py();
			do {
					&exec_serverstate();
					&polling();
					#last if($flag);
					$count--;
					sleep(10);
			} while ($count>=1)
	}
	if($count==0) {
			die "Error: The Weblogic server ($SERVERLIST[0]) is in $state state $!";
	}
}

sub admstatus_py {
        open(SERVER_STATE,">wlstscripts/server_state.py");
        print SERVER_STATE "connect('weblogic','$ADMIN_PASSWORD','t3://$ADMIN_HOST:$ADMIN_PORT')\;\n";
        print SERVER_STATE "domainRuntime()\n";
        print SERVER_STATE "slrBean = cmo.lookupServerLifeCycleRuntime('$server')\n";
        print SERVER_STATE "status = slrBean.getState()\n";
        print SERVER_STATE "print '$server='+status\n";
        print SERVER_STATE "exit();\n";
        close(SERVER_STATE)
}

sub exec_serverstate {
        $WL_HOME=$WEBLOGIC_HOME;
        $cmd="$WLST_HOME/wlst.sh wlstscripts/server_state.py > logs/state$server.log";
        print "Getting server status .... \n$cmd\n";
        system($cmd);
}

sub polling {
        open (RESOURCES, "logs/state$server.log") || warn "Unable to open file logs/state$server.log\n";
        while(<RESOURCES>) {
                chomp($_);
                print "$_\n";
                if($_ =~ /^$server/) {
                        $state = (split("=",$_))[1];
                }
        }
        close(RESOURCES);
        if($state =~ /RUNNING/i) {
                $flag=1;
                $count=0;
        }
        else {
                $flag=0;
        }
}


sub proxyapp {
        foreach $clust (@CLUSTERS) {
                $WEBINF="$MIDDLEWARE_HOME/user_projects/applications/$DOMAIN_NAME/apps/OracleProxy4_$clust/WEB-INF";
		$DEPLOYPATH="$MIDDLEWARE_HOME/user_projects/applications/$DOMAIN_NAME/apps/OracleProxy4_$clust";
                $cmd="mkdir -p $WEBINF";
                system($cmd);
                open(TMPWEB,"templates/web.xml");
                open(WEBXML,">$WEBINF/web.xml");
		$tmpclust=(split("_",$clust))[0];
                $clustaddr="";
                #foreach $item (@$clust) {
                foreach $item (@$tmpclust) {
                     $item1=(split(":",$item))[1];
                     $item2=(split(":",$item))[2];
                     $clustaddr="$clustaddr|$item1:$item2";
                }
                #copy weblogic.xml to proxy app location
                $cmd="cp templates/weblogic.xml $WEBINF";
                system($cmd);
                print"$cmd\n";

                $clustaddr=~s/^\|//;
                print"clustaddr=$clustaddr\n";
                        while(<TMPWEB>){
                                chomp($_);
                                $_=~s/REPLACE_CLUSTER_ADDRESS/$clustaddr/;
                        print WEBXML "$_\n";
                        }
			close(TMPWEB);
			close(WEBXML);
                        open(PROXYPY,">wlstscripts/deployproxy_$clust.py");
							print PROXYPY "connect('weblogic','$ADMIN_PASSWORD','t3://$ADMIN_HOST:$ADMIN_PORT')\n";
                            print PROXYPY "edit()\n";
                            print PROXYPY "startEdit()\n";
							if($clust=~/OSM/) {
								print PROXYPY "deploy('OracleProxy4_$clust','$DEPLOYPATH',targets='$osmproxyname')\n";
							}
							if($clust=~/UIM/) {
								print PROXYPY "deploy('OracleProxy4_$clust','$DEPLOYPATH',targets='$uimproxyname')\n";
							}
							print PROXYPY "save()\n";
							print PROXYPY "activate(block=\"true\")\n";
							print PROXYPY "disconnect()\n";
                        close(PROXYPY);
				$cmd="$WLST_HOME/wlst.sh wlstscripts/deployproxy_$clust.py";
				system($cmd);
				print"$cmd\n";
        }
}


