#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

source $THIS_DIR/../common/knobs

#Setup the PWLC tool -START
echo "Initializing PWLC"
echo -e "\n1;" >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties
sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties'";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/prePWLCInit.pl
sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties'";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/postPWLCInit.pl
cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts
/bin/sh $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/init_steps.sh
echo "Initialized PWLC"
#Setup the PWLC tool -END

#--------------------------------------------------------------------------------
# Stop services

for i in `/usr/bin/seq 1 ${OSM_SERVER_COUNT}`;
do
  eval MANAGED_SERVER_NAME=\$MSERVER_OSM_NAME_${i}
  /bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm ; cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh stopManagedServers $MANAGED_SERVER_NAME ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh pollManagedServerStop $MANAGED_SERVER_NAME"
done
if [ ! -z "$PSERVER_OSM_NAME" ]
then
  /bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh stopManagedServers $PSERVER_OSM_NAME ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh pollManagedServerStop $PSERVER_OSM_NAME"
fi
/bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh stopAdminServer"
/bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh pollAdminServerStop"




#--------------------------------------------------------------------------------
# Clean Database

echo "dropping RCU schemas"


/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm ; echo ${DATABASE_SYS_USER_PASSWORD} | $WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/bin/rcu -dropRepository -connectString ${DATABASE_HOST}:${DATABASE_PORT}:${DATABASE_GLOBAL_NAME} -dbUser ${DATABASE_SYS_USER_NAME} -silent -schemaPrefix $MDS_DATABASE_SCHEMA_PREFIX \
  -component MDS\
  -component IAU\
  -component IAU_APPEND\
  -component IAU_VIEWER\
  -component OPSS\
  -component UCSUMS\
  -component WLS\
  -component STB\
  -f"


# Tablespaces will have to be dropped even when DB shared option is used as OSM creates th tablsepaces in all cases, shared or new installed db

#if [ $DATABASE_INSTALL == 1 ] 
#then

echo "dropping table space" 
	/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm ; echo -e \"drop tablespace OSM_DATA including contents and datafiles cascade constraints;\nexit;\" | sqlplus ${DATABASE_SYS_USER_NAME}/${DATABASE_SYS_USER_PASSWORD}@${DATABASE_SID} as sysdba"
	/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm ; echo -e \"drop tablespace OSM_TEMP including contents and datafiles cascade constraints;\nexit;\" | sqlplus ${DATABASE_SYS_USER_NAME}/${DATABASE_SYS_USER_PASSWORD}@${DATABASE_SID} as sysdba"
#fi


echo "dropping OSM schemas" 

	/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm ; echo -e \"drop user OSM3032 cascade;\nexit;\" | sqlplus ${DATABASE_SYS_USER_NAME}/${DATABASE_SYS_USER_PASSWORD}@${DATABASE_SID} as sysdba"
	/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm ; echo -e \"drop user OSMENGG3032 cascade;\nexit;\" | sqlplus ${DATABASE_SYS_USER_NAME}/${DATABASE_SYS_USER_PASSWORD}@${DATABASE_SID} as sysdba"
	/bin/bash -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm ; echo -e \"drop user osmrep3032 cascade;\nexit;\" | sqlplus ${DATABASE_SYS_USER_NAME}/${DATABASE_SYS_USER_PASSWORD}@${DATABASE_SID} as sysdba"



#--------------------------------------------------------------------------------
# Deinstall Database Client

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/map.properties
echo DATABASE_CLIENT_HOME_DIR=$DATABASE_CLIENT_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/map.properties
echo ORACLE_INVENTORY_DIR=$ORACLE_INVENTORY_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/map.properties
echo DATABASE_HOST_NAME=$DATABASE_HOST_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/map.properties
echo DATABASE_CLIENT_ORACLE_HOME_DIR=$DATABASE_CLIENT_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/deinstall_client.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/deinstall_client.rsp
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/map.properties

$DATABASE_CLIENT_ORACLE_HOME_DIR/deinstall/deinstall -silent -paramfile $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/deinstall_client.rsp

$COMMON_ORACLE_HOME_DIR/oui/bin/runInstaller -deinstall -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/deinstall_oh.rsp -invPtrLoc ${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}/oraInst.loc -waitforcompletion -jreloc $JAVA_HOME

#--------------------------------------------------------------------------------
# Deinstall WebLogic and domains

source ${MANAGEABLE_INSTALL_TOOL_DIR}/$OSM_SCRIPT_MODULE_NAME/common/osm_lib
populate_osm_servers
for i in `/usr/bin/seq 1 ${#servers[*]}`;
do
  # skip master
  if [ ${servers[i]} == "${WEBLOGIC_HOST}" ] && [ ${apphomes[i]} == "${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}" ]
  then
    continue
  fi
  /bin/bash -c "export MIK_ASKPASS_HOST=${servers[i]} ; export MIK_ASKPASS_USER=${users[i]} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${users[i]}@${servers[i]} \"/bin/bash -lc 'SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /bin/umount -fl ${apphomes[i]}/Middleware_wls/user_projects/domains/${SUITE_DOMAIN_NAME} ; /bin/rm -rf ${apphomes[i]}/Middleware_wls/user_projects/domains/${SUITE_DOMAIN_NAME} ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /bin/umount -fl ${apphomes[i]}/Middleware_wls/user_projects/applications/${SUITE_DOMAIN_NAME} ; /bin/rm -rf ${apphomes[i]}/Middleware_wls/user_projects/applications/${SUITE_DOMAIN_NAME}'\""
done
for i in `/usr/bin/seq 1 ${#servers[*]}`;
do
  /bin/bash -c "export MIK_ASKPASS_HOST=${servers[i]} ; export MIK_ASKPASS_USER=${users[i]} ; export SSH_ASKPASS=${MANAGEABLE_INSTALL_TOOL_DIR}/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${users[i]}@${servers[i]} \"/bin/bash -lc 'cd ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/utils/uninstall ; ${WEBLOGIC_MIDDLEWARE_HOME_DIR}/utils/uninstall/uninstall.sh -mode=silent'\""
done

#--------------------------------------------------------------------------------
# Clean miscellaneous

for i in `/usr/bin/seq 1 ${#servers[*]}`;
do
  /bin/bash -c "export MIK_ASKPASS_HOST=${servers[i]} ; export MIK_ASKPASS_USER=${users[i]} ; export SSH_ASKPASS=${MANAGEABLE_INSTALL_TOOL_DIR}/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${users[i]}@${servers[i]} \"/bin/bash -lc '/bin/rm -rf ${apphomes[i]}/Middleware_wls ; /bin/rm -rf ~/bea'\""
done
/bin/rm -rf $OSM_HOME_DIR
