#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################

#This script performs the following 
  #Creates weblogic domain using domain template jar
  #Exctends domain with ADF and EM applications using domain extension templates

# Version 1.0
# Rajesh Prabakarn
############################################################

use File::Copy;

require "commoninfo.properties";

$WLST_HOME="$WEBLOGIC_HOME/common/bin";

  if(! -f "$WLST_HOME/wlst.sh") {
     print"Invalid weblogic home location configured in commoninfo.properties. The required files $WLST_HOME/wlst.sh are not found \n";
	die "Error: Couldn't find the file $!";
  }

  if(! -f "$DOMAIN_TEMPLATE") {
     print"Invalid domain template location configured in commoninfo.properties $DOMAIN_TEMPLATE \n";
        die "Error: Couldn't find the file $!";
  }

  if(-d "$DOMAIN_HOME") {
        die "Error: Weblogic domain directory ( $DOMAIN_HOME ) already exist \n $!";
  }
#generate domain creation python script
&gen_domainpy();

#Weblogic domain creation for suite environment
&weblogic_domain();

sub weblogic_domain {
   $cmd="$WLST_HOME/wlst.sh wlstscripts/createdomain.py";
   &print_console();
   system($cmd);
   print"$cmd\n";
   #print "confirm whether domain is created";<stdin>;
}

sub gen_domainpy {
  open(DOMAINPY,">wlstscripts/createdomain.py");
      print DOMAINPY "readTemplate('$DOMAIN_TEMPLATE')\;\n";
      print DOMAINPY "cd('/Security/base_domain/User/weblogic')\;\n";
      print DOMAINPY "cmo.setPassword('$ADMIN_PASSWORD')\;\n";
      print DOMAINPY "cd('/Servers/AdminServer')\;\n";
      print DOMAINPY "set('ListenPort', $ADMIN_PORT)\;\n";
      print DOMAINPY "set('ListenAddress','$ADMIN_HOST')\;\n";
      print DOMAINPY "cd('/Servers/ASAP_MS1')\;\n";
      print DOMAINPY "set('ListenPort', $ASAP_MANAGEDSERVER_PORT)\;\n";
      print DOMAINPY "set('ListenAddress','$ASAP_MANAGEDSERVER_HOST')\;\n";
      print DOMAINPY "cd('/Servers/OSM_MS1')\;\n";
      print DOMAINPY "set('ListenPort', $OSM_MANAGEDSERVER_PORT)\;\n";
      print DOMAINPY "set('ListenAddress','$OSM_MANAGEDSERVER_HOST')\;\n";
      print DOMAINPY "cd('/Servers/UIM_MS1')\;\n";
      print DOMAINPY "set('ListenPort', $UIM_MANAGEDSERVER_PORT)\;\n";
      print DOMAINPY "set('ListenAddress','$UIM_MANAGEDSERVER_HOST')\;\n";
      print DOMAINPY "writeDomain('$DOMAIN_HOME')\;\n";
      print DOMAINPY "closeTemplate()\;\n";
      print DOMAINPY "exit()\;\n";
   close(DOMAINPY);
}


sub print_console {
      print"readTemplate('$DOMAIN_TEMPLATE')\;\n";
      print"cd('/Security/base_domain/User/weblogic')\;\n";
      print"cmo.setPassword('$ADMIN_PASSWORD')\;\n";
      print"cd('/Servers/AdminServer')\;\n";
      print"set('ListenPort', $ADMIN_PORT)\;\n";
      print"set('ListenAddress','$ADMIN_HOST')\;\n";
      print"cd('/Servers/ASAP_MS1')\;\n";
      print"set('ListenPort', $ASAP_MANAGEDSERVER_PORT)\;\n";
      print"set('ListenAddress','$ASAP_MANAGEDSERVER_HOST')\;\n";
      print"cd('/Servers/OSM_MS1')\;\n";
      print"set('ListenPort', $OSM_MANAGEDSERVER_PORT)\;\n";
      print"set('ListenAddress','$OSM_MANAGEDSERVER_HOST')\;\n";
      print"cd('/Servers/UIM_MS1')\;\n";
      print"set('ListenPort', $UIM_MANAGEDSERVER_PORT)\;\n";
      print"set('ListenAddress','$UIM_MANAGEDSERVER_HOST')\;\n";
      print"writeDomain('$DOMAIN_HOME')\;\n";
      print"closeTemplate()\;\n";
      print"exit()\;\n";
}


if(! -d "$DOMAIN_HOME") {
        die "Error: Weblogic domain directory ( $DOMAIN_HOME ) not created successfully \n $!";
}
