#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################

#This script performs the following 
  #Creates weblogic domain using domain template jar
  #Exctends domain with ADF and EM applications using domain extension templates

# Version 1.0
# Rajesh Prabakarn
############################################################

use File::Copy;

require "commoninfo.properties";

$WLST_HOME="$WEBLOGIC_HOME/common/bin";
$JRFTEMPLATE_LOC="$MIDDLEWARE_HOME/oracle_common/common/templates/applications/jrf_template_11.1.1.jar";
$EMTEMPLATE_LOC="$MIDDLEWARE_HOME/oracle_common/common/templates/applications/oracle.em_11_1_1_0_0_template.jar";

  if(! -f "$WLST_HOME/wlst.sh") {
     print"Invalid weblogic home location configured in commoninfo.properties. The required files $WLST_HOME/wlst.sh are not found \n";
	die "Error: Couldn't find the file $!";
  }

  if(! -f "$JRFTEMPLATE_LOC") {
     print"Invalid JRF template location $JRFTEMPLATE_LOC. Please ensure FMW ADF is installed.\n";
        die "Error: Couldn't find the file $!";
  }

  if(! -f "$EMTEMPLATE_LOC") {
     print"Invalid EM template location $EMTEMPLATE_LOC. Please ensure FMW ADF is installed.\n";
        die "Error: Couldn't find the file $!";
  }

#generate domain creation python script
&gen_extendpy();

#Weblogic domain extension for ADF and EM libraries
&weblogic_domain_extension();

sub weblogic_domain_extension{
   $cmd="$WLST_HOME/wlst.sh wlstscripts/extenddomain.py";
   &print_console();
   system($cmd);
   print"$cmd\n";
   #print "confirm whether domain is extended";<stdin>;
}


sub gen_extendpy {
  open(EXTENDPY,">wlstscripts/extenddomain.py");
      print EXTENDPY "readDomain('$DOMAIN_HOME')\;\n";
      print EXTENDPY "addTemplate('$JRFTEMPLATE_LOC')\;\n";
      print EXTENDPY "addTemplate('$EMTEMPLATE_LOC')\;\n";
      print EXTENDPY "updateDomain()\;\n";
      print EXTENDPY "closeDomain()\;\n";
      print EXTENDPY "readDomain('$DOMAIN_HOME')\;\n";
      print EXTENDPY "assignAll(\"Services\", \"Target\", \"AdminServer,OSM_MS1,UIM_MS1\")\;\n";
      print EXTENDPY "assignAll(\"Library\", \"Target\", \"AdminServer,OSM_MS1,UIM_MS1\")\;\n";
      print EXTENDPY "assignAll(\"AppDeployment\", \"Target\", \"AdminServer,OSM_MS1,UIM_MS1\")\;\n";
      print EXTENDPY "updateDomain()\;\n";
      print EXTENDPY "closeDomain()\;\n";
  close(EXTENDPY);
}


sub print_console {
      print"readDomain('$DOMAIN_HOME')\;\n";
      print"addTemplate('$JRFTEMPLATE_LOC')\;\n";
      print"addTemplate('$EMTEMPLATE_LOC')\;\n";
      print"updateDomain()\;\n";
      print"closeDomain()\;\n";
      print"readDomain('$DOMAIN_HOME')\;\n";
      print"assignAll(\"Services\", \"Target\", \"AdminServer,OSM_MS1,UIM_MS1\")\;\n";
      print"assignAll(\"Library\", \"Target\", \"AdminServer,OSM_MS1,UIM_MS1\")\;\n";
      print"assignAll(\"AppDeployment\", \"Target\", \"AdminServer,OSM_MS1,UIM_MS1\")\;\n";
      print"updateDomain()\;\n";
      print"closeDomain()\;\n";
}
