#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################
#This script performs the following
#1. The application required pre-install configurations are done here

# Version 1.0
# Rajesh Prabakarn
# 30-Jan-2013 -V3 - ZKUNJU - Updated with content provided by RPRABAKA for updCommonInfoPath
#04-Feb-2013  -V4 - ZKUNJU
############################################################

use File::Copy;

$cwd=`pwd`;
chomp($cwd);

#General configurations
#Any pre-install configurations for suite products
print "Generating commoninfo and suite_install.properties...\n";
&gen_commoninfo();
&addAntpathtocommoninfo();
&gen_suiteinfo();
&movePWLCToMWHome();
&updCommonInfoPath();
&editRacdbvalue();
&copynewwljars();
&copySuiteScripts();

sub gen_commoninfo {
    open(TEMPLATE,"templates/commoninfo_template.properties");
        open(COMMON,">commoninfo.properties");
    open(PROP,"templates/suite_customer.values");
    @fileArray = <PROP>;

        @appList=("OSM","UIM","ASAP","OSMPROXY","UIMPROXY","OSM_COHERENCE");
        foreach $app (@appList) {
        $osmPrint="";
        @serverInfo="";
                if($app=~/PROXY/) {
                        if($app=~/OSM/) {
                                $port="orclocom_osm_cluster_PROXY_PORT";
                        }
                        if($app=~/UIM/) {
                                $port="orclocom_uim_cluster_PROXY_PORT";
                        }
                        if($app=~/OSM/ && $ARGV[0] =~/OSM 2 Node Cluster/) {
                                $port="PROXY_PORT";
                        }
                        if($app=~/UIM/ && $ARGV[0] =~/UIM 2 Node Cluster/) {
                                $port="PROXY_PORT";
                        }
                }
		elsif($app =~/OSM_COHERENCE/) {
			$port="OSM_COHERENCE_PORT";
		}
                else{
                        $port=$app."_MANAGEDSERVER_PORT";
                }
        #$servName=$app."_MS";
        @osmInfo=`grep "$port," templates/suite_customer.values`;
          for($i=0;$i<=$#osmInfo;$i++) {
                $x=$i+1;
                $osmHost=(split("\,",$osmInfo[$i]))[1];
                $osmPort=(split("\,",$osmInfo[$i]))[3];
		$servName=(split("\,",$osmInfo[$i]))[0];
		$servPrefix=(split("\_",$servName))[1];
		$mngHost=(split("\\.",$osmHost))[0];
		$mnServerName=$servPrefix."_".$mngHost."_".$osmPort;
		chomp($mnServerName);
                $item="$mnServerName:$osmHost:$osmPort";
                push(@serverInfo,$item);
		if($mnServerName=~/asap/) {
          		$targetASAP="$mnServerName";
		}
		if($mnServerName=~/osm/ && $app =~/^OSM$/) {
          		$targetOSM="$mnServerName";
		}
		if($mnServerName=~/uim/) {
          		$targetUIM="$mnServerName";
		}
          }
                $finList=join("\",\"",@serverInfo);
                $finList=~s/\n//g;
                $finList=~s/^\"\,\"//g;
		if($#serverInfo<=0) {
                	print COMMON "\@$app = ()\;\n";
		}
		else {
                	print COMMON "\@$app = (\"$finList\")\;\n";
		}
        }
    $pattern=grep(/orclocom_osm_cluster,/,@fileArray);
    if($pattern != '0'){
        $targetOSM="OSM_CLUSTER";
        push(@clustArray,$targetOSM);
    }
    $pattern=grep(/orclocom_uim_cluster,/,@fileArray);
    if($pattern != '0'){
        $targetUIM="UIM_CLUSTER";
        push(@clustArray,$targetUIM);
    }
        $clusterList=join("\",\"",@clustArray);
        $clusterList=~s/^\"\,\"//g;
        if($clusterList=~/OSM_CLUSTER|UIM_CLUSTER/) {
             print COMMON "\@CLUSTERS = (\"$clusterList\")\;\n";
             #print COMMON "\@CLUSTERS = (\"OSM_CLUSTER\"\,\"UIM_CLUSTER\")\;\n";
        }
        else {
             print COMMON "\@CLUSTERS = ()\;\n";
        }



        close(COMMON);

        open(COMMON,">>commoninfo.properties");
        while(<TEMPLATE>) {
            chomp($_);
			if($_ =~/ADMIN_HOST/){
				$repToken = (split("\%",$_))[1];
				$mapVal = `grep ADMIN_PORT templates/suite_customer.values`;
				$mapVal=~s/\n//g;
				$mapVal = (split("\,",$mapVal))[1];
				$_=~s/\%$repToken\%/$mapVal/g;
			}
    		        if($_ =~/%STAGE_LOCATION%/){
		               $_=~s/%STAGE_LOCATION%/$cwd/g;
		        }
	               if($_ =~/\%/) {
                        @tmparr= (split("\%",$_));
                        foreach $token (@tmparr) {
                                $repToken = (split("\%",$_))[1];
                                $mapVal = `grep ",$repToken," templates/suite_customer.values`;
                                $mapVal=~s/\n//g;
                                $mapVal = (split("\,",$mapVal))[3];
                                $_=~s/\%$repToken\%/$mapVal/
			}
            }
			print COMMON "$_\n";
        }
		close(COMMON);
}


sub gen_suiteinfo {
    open(SUITE,">suite_install.properties");
	open(TEMPLATE,"templates/suite_install_template.properties");
    while(<TEMPLATE>) {
        chomp($_);
                if($^O =~/solaris/i) {
                        $_=~s/72ServerLinux/72ServerSolaris/g;
                }
		if($_ =~/%OSM_TARGET%/){
			$_=~s/%OSM_TARGET%/$targetOSM/g;
		}
		if($_ =~/%UIM_TARGET%/){
			$_=~s/%UIM_TARGET%/$targetUIM/g;
		}
		if($_ =~/%ASAP_TARGET%/){
			$_=~s/%ASAP_TARGET%/$targetASAP/g;
		}
		if($_ =~ /%HANDLER_FACTORY%/ && $targetOSM=~/OSM_CLUSTER/) {
			$_=~s/%HANDLER_FACTORY%/com.mslv.oms.handler.cluster.ClusteredHandlerFactory/g;
		}
		else {
			$_=~s/%HANDLER_FACTORY%/com.mslv.oms.security.HandlerFactory/g;
		}
		if($_ =~/ADMIN_HOST/){
			$repToken = (split("\%",$_))[1];
			$mapVal = `grep ADMIN_PORT templates/suite_customer.values`;
			$mapVal=~s/\n//g;
			$mapVal = (split("\,",$mapVal))[1];
			$_=~s/\%$repToken\%/$mapVal/g;
				
		}
        if($_ =~/\%/) {
			#$repToken = (split("\%",$_))[1];
			@tmparr= (split("\%",$_));
			foreach $token (@tmparr) {
				$repToken = (split("\%",$_))[1];
				$mapVal = `grep ",$repToken," templates/suite_customer.values`;
#print "grep $repToken templates/suite_customer.values \n";
				$mapVal=~s/\n//g;
            			$tag = (split("\,",$mapVal))[0];
            			$mapVal = (split("\,",$mapVal))[3];
            			$_=~s/\%$repToken\%/$mapVal/g;
			}
        }
			print SUITE "$_\n";
    }
	close(SUITE);
}

sub updCommonInfoPath {
    require "commoninfo.properties";
    @files=("prePWLCInit.pl","postPWLCInit.pl");
    foreach $file (@files) {
        print "update commoninfo properties location on $file \n";
        print "update suite_install properties location on $file \n";
        open(INIT,"$MIDDLEWARE_HOME/CustomScripts/pwlc/scripts/customization/$file");
        open(TMPINIT,">$MIDDLEWARE_HOME/CustomScripts/pwlc/scripts/customization/swp_$file");
        while(<INIT>) {
                $repvalue="$cwd"."/commoninfo.properties";
                $repvalue1="$cwd"."/suite_install.properties";
                chomp($_);
                $_=~s/$commonInfo="commoninfo.properties"/$commonInfo="$repvalue"/;
                $_=~s/$suiteInfo="suite_install.properties"/$suiteInfo="$repvalue1"/;
                print TMPINIT "$_\n";
        }
        close(TMPINIT);
        close(INIT);
        rename("$MIDDLEWARE_HOME/CustomScripts/pwlc/scripts/customization/swp_$file","$MIDDLEWARE_HOME/CustomScripts/pwlc/scripts/customization/$file");
    }
}

sub addAntpathtocommoninfo {
        require "commoninfo.properties";
        $cmd="find $MIDDLEWARE_HOME -name \"org.apache.ant*\"";
        $antpath=`$cmd`;
        chomp($antpath);
        print "path of ant is $antpath\n";
        open(COMIN,"commoninfo.properties");
        open(COMINTMP,">commoninfo.properties_tmp");
        while(<COMIN>)
        {
                if($_=~/MANAGED_SERVER_START_POLL_SLEEP/)
                {
                        $_="\$MANAGED_SERVER_START_POLL_SLEEP=\"6000\";\n\$ANT_PATH=\"$antpath\";\n";
                        print COMINTMP "$_";
                }
                else
                {
                        print COMINTMP "$_";
                }

        }
        close(COMINTMP);
        close(COMIN);
        rename("commoninfo.properties_tmp","commoninfo.properties");
}

sub movePWLCToMWHome {
	require "commoninfo.properties";
	$cmd="rm -rf $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
	$cmd="mkdir $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
	$cmd="mv pwlc $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
}

sub copynewwljars {
        require "commoninfo.properties";
        $cmd="find $WEBLOGIC_HOME -name \"wlclient.jar\" | grep \"server\"";
        $wlclientjar=`$cmd`;
        chomp($wlclientjar);
        $cmd="find $WEBLOGIC_HOME -name \"wljmxclient.jar\" | grep \"server\"";
        $wljmxjar=`$cmd`;
        chomp($wljmxjar);
        print "Copying $wlclientjar and $wljmxjar to pwlc/lib\n";
        $cmd="cp -r $wlclientjar $wljmxjar $MIDDLEWARE_HOME/CustomScripts/pwlc/lib/";
        system($cmd);
        $cmd="chmod -R 755 $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
}

sub copySuiteScripts {      
	require "commoninfo.properties"; 
        $cmd="cp commoninfo.properties $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
        $cmd="cp cluster_start_mngserver.pl $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
        $cmd="cp cluster_poststart_mngserver.pl $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
        $cmd="cp startMng.xml $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
        $cmd="chmod -R 755 $MIDDLEWARE_HOME/CustomScripts";
        system($cmd);
}

sub editRacdbvalue {
        $val = `grep IS_RAC_DB templates/suite_customer.values`;
        $val=~s/\n//g;
        $true_val = (split("\,",$val))[3];
        print "enbale rac db is $true_val\n";
        open(SUIT,"suite_install.properties");
        open(SUIT_TMP,">suite_install.properties_tmp");
        while(<SUIT>){
                chomp($_);
                if($_=~ /osm.db.type.rac/)
                {
                        if($true_val=~/true/){
                                $_ = "osm.db.type.rac=Yes";
                        }
                        else{
                                $_ = "osm.db.type.rac=No";
                        }
                        print "modified line is $_\n";
                        print SUIT_TMP "$_\n";
                }
                else{print SUIT_TMP "$_\n";}
        }
        close(SUIT);
        close(SUIT_TMP);
        rename("suite_install.properties_tmp","suite_install.properties");
}

