#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

echo "Configuration read"

echo "Prevalidating installation environment"

$JAVA_HOME/bin/java -cp $THIS_DIR/../common:$THIS_DIR/../../common prevalidate $THIS_DIR/../..


echo "Installation environment prevalidated"
#--------------------------------------------------------------------------------
# Generate Install Tool Driver Files
echo "Generating installation driver files"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo JAVA_HOME=$JAVA_HOME>> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo PASSWORDS_ENCRYPTED=$PASSWORDS_ENCRYPTED>> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOME_DIR=$WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo SUITE_DOMAIN_NAME=$SUITE_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo SUITE_DOMAIN_HOME_DIR=$SUITE_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo MANAGEABLE_INSTALL_TOOL_DIR=$MANAGEABLE_INSTALL_TOOL_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_SCRIPT_MODULE_NAME=$OSM_SCRIPT_MODULE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo JAVA_HOME=$JAVA_HOME>> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOME_DIR=$WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOST=$WEBLOGIC_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_PORT=$WEBLOGIC_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_ADMIN_USER=$WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_ADMIN_USER_PASSWORD=$WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo SUITE_DOMAIN_HOME_DIR=$SUITE_DOMAIN_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo SUITE_DOMAIN_NAME=$SUITE_DOMAIN_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_HOST=$DATABASE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_PORT=$DATABASE_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SID=$DATABASE_SID >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYSTEM_USER_NAME=$DATABASE_SYSTEM_USER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYSTEM_USER_PASSWORD=$DATABASE_SYSTEM_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_GLOBAL_NAME=$DATABASE_GLOBAL_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYS_USER_NAME=$DATABASE_SYS_USER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SYS_USER_PASSWORD=$DATABASE_SYS_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo MANAGEABLE_INSTALL_TOOL_DIR=$MANAGEABLE_INSTALL_TOOL_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_SCRIPT_MODULE_NAME=$OSM_SCRIPT_MODULE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_MEDIA_DOWNLOAD_DIR=$OSM_MEDIA_DOWNLOAD_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_HOME_DIR=$OSM_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
if [ $OSM_CLUSTER -eq 1 ]
then
  echo OSM_MANAGED_SERVER_NAME=$CLUSTER_NAME_OSM >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
else
  echo OSM_MANAGED_SERVER_NAME=$MSERVER_OSM_NAME_1 >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
fi
if [ $OSM_CLUSTER -eq 1 ]
then
  echo HANDLER_FACTORY=com.mslv.oms.handler.cluster.ClusteredHandlerFactory >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
else
  echo HANDLER_FACTORY=com.mslv.oms.security.HandlerFactory >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
fi
echo DATABASE_RAC=${DATABASE_RAC} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_RAC_TYPE=${DATABASE_RAC_TYPE} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_RAC_LISTENER=${DATABASE_RAC_LISTENER} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_HOST_2=${DATABASE_HOST_2} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_PORT_2=${DATABASE_PORT_2} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SID_2=${DATABASE_SID_2} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_GLOBAL_NAME_2=${DATABASE_GLOBAL_NAME_2} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

echo MSERVER_OSM_PORT_1=${MSERVER_OSM_PORT_1} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo MSERVER_OSM_SSLPORT_1=${MSERVER_OSM_SSLPORT_1} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo MSERVER_OSM_HOSTNAME_1=${MSERVER_OSM_HOSTNAME_1} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo COMMON_ORACLE_HOME_DIR=${COMMON_ORACLE_HOME_DIR} >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

echo MDS_DATABASE_SCHEMA_NAME=$MDS_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo MDS_DATABASE_SCHEMA_PASSWORD=$MDS_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OPSS_DATABASE_SCHEMA_NAME=$OPSS_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OPSS_DATABASE_SCHEMA_PASSWORD=$OPSS_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo IAU_APPEND_DATABASE_SCHEMA_PASSWORD=$IAU_APPEND_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties 
echo IAU_VIEWER_DATABASE_SCHEMA_NAME=$IAU_VIEWER_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo IAU_APPEND_DATABASE_SCHEMA_NAME=$IAU_APPEND_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo IAU_VIEWER_DATABASE_SCHEMA_PASSWORD=$IAU_VIEWER_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo STB_DATABASE_SCHEMA_PASSWORD=$STB_DATABASE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo STB_DATABASE_SCHEMA_NAME=$STB_DATABASE_SCHEMA_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo JTA_TIMEOUT=$JTA_TIMEOUT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_REPORTING_DB_PASSWORD=$OSM_REPORTING_DB_PASSWORD>> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_RULE_SCHEMA_PASSWORD=$OSM_RULE_SCHEMA_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo OSM_DB_TEMP_TABLE_SPACE=$OSM_DB_TEMP_TABLE_SPACE >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo MDS_DATABASE_SCHEMA_PREFIX=$MDS_DATABASE_SCHEMA_PREFIX >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo COHERENCE_CLUSTER_NAME=$COHERENCE_CLUSTER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo COHERENCE_CLUSTER_UNICAST_PORT=$COHERENCE_CLUSTER_UNICAST_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo COHERENCE_WELL_KNOWN_ADDRESSES=$COHERENCE_WELL_KNOWN_ADDRESSES >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/osm_database_cfg.sql.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/osm_database_cfg.sql

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/rcu_password_answers.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/rcu_password_answers


$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/suite_install.properties.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/suite_install.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/create_osm_domain.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/create_osm_domain.py
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo "Installation driver files generated"

#-------------------------------------------------------------------------------
# Collect media

echo "Collecting media"

echo "Media collected"
#-------------------------------------------------------------------------------
# Install OSM foundation

$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/install_osm_foundation.sh

#--------------------------------------------------------------------------------
# Blanket Configure Shell
source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm
# TODO blanket
############ modify the ant version ant version ###############################
export ANT_HOME=$COMMON_ORACLE_HOME_DIR/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8
export PATH=$ANT_HOME/bin:${PATH}

#--------------------------------------------------------------------------------
# Install OSM

echo "Calculating deploy model"

if [ $OSM_CLUSTER -eq 0 ]
then
  OSM_DEPLOY_MODEL="OSM Single Node"
elif [ $OSM_CLUSTER -eq 1 ]
then
  OSM_DEPLOY_MODEL="OSM 2 Node Cluster"
else
  echo "Unsupported options combination."
  false
fi
echo Deploy Model is \"$OSM_DEPLOY_MODEL\"

echo "Deploy model calculated"

echo "Preparing commoninfo.properties"

echo -e "\n" >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties
/bin/bash -c "set -a ; source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/knobs ; $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common generate_topology >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties"

echo -e "\n\$JAVA_HOME = \"${JAVA_HOME}\";" >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties
echo -e "\n1;" >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties

echo "commoninfo.properties prepared"


#Setup the PWLC tool -START
echo "Initializing PWLC"
/bin/sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties'\";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/prePWLCInit.pl
/bin/sed -i '/\$commonInfo=/c\$commonInfo=\"'$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/commoninfo.properties'\";' $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/customization/postPWLCInit.pl
cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts
/bin/sh $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/init_steps.sh
echo "Initialized PWLC"
#Setup the PWLC tool -END

#################RCU schema #################################################
echo " APPLICATIONS_HOME_DIR $APPLICATIONS_HOME_DIR" 

#####/bin/mkdir -p $APPLICATIONS_HOME_DIR/logs


# TODO create ODI schema

$COMMON_ORACLE_HOME_DIR/bin/rcu -silent -createRepository -databaseType ORACLE -connectString $DATABASE_HOST:$DATABASE_PORT:$DATABASE_SID -dbUser $DATABASE_SYS_USER_NAME -dbRole sysdba -variables RCU_LOG_LOCATION=$APPLICATIONS_HOME_DIR/logs -schemaPrefix $MDS_DATABASE_SCHEMA_PREFIX -component MDS -component IAU -component IAU_APPEND -component IAU_VIEWER -component OPSS -component UCSUMS -component WLS -component STB -f < $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/rcu_password_answers

echo "RCU Schemas created"

if [ $DATABASE_RAC == 'No' -o $DATABASE_INSTALL == 1  ]
then
	echo "Configuring database"
	/bin/sh -c "source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm ; $DATABASE_CLIENT_ORACLE_HOME_DIR/bin/sqlplus $DATABASE_SYS_USER_NAME/$DATABASE_SYS_USER_PASSWORD@//$DATABASE_HOST:$DATABASE_PORT/$DATABASE_GLOBAL_NAME as sysdba @$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/osm_database_cfg.sql"

	echo "Database configured"
fi

#################RCU schema #################################################
echo "Creating WebLogic domain"

/bin/sh -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/setup_entry.sh createDomain,createBootFileForAdminServer,createClusters,createServers ; cd $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm ; $PERL_PROGRAM $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/updateProxyAppDescriptors.pl"
#the above line has been commented out to introduce the python calls below
###NVK -- $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/create_osm_domain.py.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/create_osm_domain.py

###NVK - MOVED BELOW -- /bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $WEBLOGIC_HOME_DIR/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/create_osm_domain.py"

$PERL_PROGRAM -pi.bak -e 's/PORT_MEM_ARGS=.*/PORT_MEM_ARGS="-XX:MaxPermSize=2048M -Xms2024m -Xmx3096m"/' $SUITE_DOMAIN_HOME_DIR/bin/setDomainEnv.sh

echo "WebLogic domain created"

echo "Extending WebLogic domain"

#######/bin/sh -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/setup_entry.sh extendDomain \\\$MIDDLEWARE_HOME/oracle_common/common/templates/applications/jrf_template_11.1.1.jar,\\\$MIDDLEWARE_HOME/oracle_common/common/templates/applications/oracle.em_11_1_1_0_0_template.jar"
######/bin/sh -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/setup_entry.sh extendDomain \\\$MIDDLEWARE_HOME/oracle_common/common/templates/wls/oracle.jrf_template_12.1.3.jar"

/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $WEBLOGIC_HOME_DIR/../oracle_common/common/bin/wlst.sh $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/create_osm_domain.py"

/bin/sh -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/setup_entry.sh createProxyServers"

echo "WebLogic domain extended"

echo "Executing OSM pre-installation steps"

/bin/sh -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm ; $PERL_PROGRAM $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/preinstall_suiteapps.pl \"$OSM_DEPLOY_MODEL\""

echo "OSM pre-installation completed"
#--------------------------------------------------------------------------------
# Placing domain

MASTERED=
source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/osm_lib
populate_osm_servers
for i in `/usr/bin/seq 1 ${#servers[*]}`;
do
  # skip master
  if [ ${servers[i]} == "${WEBLOGIC_HOST}" ] && [ ${apphomes[i]} == "${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}" ]
  then
    continue
  fi
  if [ -z "${MASTERED}" ]
  then
    /bin/bash -c "SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /bin/bash -c 'echo -e \"\n${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR} *(rw)\" >> /etc/exports' ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /usr/sbin/exportfs -r"
    MASTERED="1"
  fi
  /bin/bash -c "export MIK_ASKPASS_HOST=${servers[i]} ; export MIK_ASKPASS_USER=${users[i]} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${users[i]}@${servers[i]} \"/bin/bash -lc '/bin/mkdir -p ${apphomes[i]}/Middleware_wls/user_projects/domains/${SUITE_DOMAIN_NAME} ; SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /bin/mount ${WEBLOGIC_HOST}:${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}/Middleware_wls/user_projects/domains/${SUITE_DOMAIN_NAME} ${apphomes[i]}/Middleware_wls/user_projects/domains/${SUITE_DOMAIN_NAME} ; /bin/mkdir -p ${apphomes[i]}/Middleware_wls/user_projects/applications/${SUITE_DOMAIN_NAME} ; $SUDO_PROGRAM -A -k -E -p '%H:%p' /bin/mount ${WEBLOGIC_HOST}:${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}/Middleware_wls/user_projects/applications/${SUITE_DOMAIN_NAME} ${apphomes[i]}/Middleware_wls/user_projects/applications/${SUITE_DOMAIN_NAME}'\""
done

echo "Configuring domain"
for j in `/usr/bin/seq 1 ${OSM_SERVER_COUNT}`;
do
  eval MANAGED_SERVER_NAME=\$MSERVER_OSM_NAME_${j}
  DOMAIN_HOME_DIR=${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}/Middleware_wls/user_projects/domains/${SUITE_DOMAIN_NAME}
  /bin/mkdir -p ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security
  /bin/rm -f ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security/boot.properties
  /bin/echo username=${WEBLOGIC_ADMIN_USER} >> ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security/boot.properties
  /bin/echo password=${WEBLOGIC_ADMIN_USER_PASSWORD} >> ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security/boot.properties
done
if [ ! -z "$PSERVER_OSM_NAME" ]
then
  MANAGED_SERVER_NAME=$PSERVER_OSM_NAME
  DOMAIN_HOME_DIR=${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}/Middleware_wls/user_projects/domains/${SUITE_DOMAIN_NAME}
  /bin/mkdir -p ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security
  /bin/rm -f ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security/boot.properties
  /bin/echo username=${WEBLOGIC_ADMIN_USER} >> ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security/boot.properties
  /bin/echo password=${WEBLOGIC_ADMIN_USER_PASSWORD} >> ${DOMAIN_HOME_DIR}/servers/${MANAGED_SERVER_NAME}/security/boot.properties
fi
echo "Domain configured"

$WEBLOGIC_HOME_DIR/server/bin/setWLSEnv.sh
source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/osm_lib

start_osm_admin_server
####/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/startAdminServer.sh"

if [ "$OSM_DEPLOY_MODEL" == "OSM 2 Node Cluster" ]
then
  echo "Deploying proxy applications"

  /bin/bash -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/setup_entry.sh deployApplications \\\$OSM_PROXY_DEPLOYMENT"

  echo "Proxy applications deployed"
fi
echo "Starting WebLogic managed servers"

  source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/osm_lib

$WEBLOGIC_HOME_DIR/server/bin/setWLSEnv.sh
start_osm
########/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/startManagedServer.sh
start_osm_proxy

echo "WebLogic managed servers started"


echo "Installing OSM"
cd $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm
$PERL_PROGRAM $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/install_suiteapps.pl osm
cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts

$WEBLOGIC_HOME_DIR/server/bin/setWLSEnv.sh
/bin/sh -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/setup_entry.sh checkDeploymentsState oms STATE_ACTIVE"
######/bin/sh -c "export CONFIG_JVM_ARGS=-Djava.security.egd=file:/dev/./urandom ; $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/checkDeploymentState.sh
echo "OSM installed"

echo "Stopping WebLogic servers"
/bin/sh -c "cd $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts ; $MANAGEABLE_INSTALL_TOOL_DIR/pwlc/scripts/destroy_entry.sh stopManagedServers,pollManagedServerStop,stopAdminServer,pollAdminServerStop"
echo "WebLogic servers stopped"

# TODO osmcoherence_cfg.pl uses DOMAIN_HOME in startup script material generation, but this value needs to be per host; currently will only work if DOMAIN_HOME is the same on every OSM cluster node; furthermore seems like LOTS of files in domain (eg startX scripts) are coded to master domain location, so domain has to be in same place on all osm cluster nodes

######################already changed in install_suiteapps.pl for clustering

#############if [ $OSM_CLUSTER == "1" ]
###########then
  ##########echo "OSM Coherence Configurations"
  #############cd $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm
  ###############$PERL_PROGRAM $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/osmcoherence_cfg.pl
#  for i in `/usr/bin/seq 1 ${#servers[*]}`;
#  do
#    echo "Configuring Coherence"
#    for j in `/usr/bin/seq 1 ${OSM_SERVER_COUNT}`;
#    do
#      eval MANAGED_SERVER_NAME=\$MSERVER_OSM_NAME_${j}
#      DOMAIN_HOME_DIR=${apphomes[i]}/Middleware_wls/user_projects/domains/suite_domain
#      /bin/bash -c "export MIK_ASKPASS_HOST=${servers[i]} ; export MIK_ASKPASS_USER=${users[i]} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${SUITE_DOMAIN_HOME_DIR}/osm-coherence-cluster-config.xml ${users[i]}@${servers[i]}:${apphomes[i]}/Middleware_wls/user_projects/domains/suite_domain/"
#      /bin/bash -c "export MIK_ASKPASS_HOST=${servers[i]} ; export MIK_ASKPASS_USER=${users[i]} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${users[i]}@${servers[i]} \"/bin/bash -lc '/bin/chmod +w ${apphomes[i]}/Middleware_wls/user_projects/domains/suite_domain/bin/start${MANAGED_SERVER_NAME}.sh'\""
#      /bin/bash -c "export MIK_ASKPASS_HOST=${servers[i]} ; export MIK_ASKPASS_USER=${users[i]} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${SUITE_DOMAIN_HOME_DIR}/bin/start${MANAGED_SERVER_NAME}.sh ${users[i]}@${servers[i]}:${apphomes[i]}/Middleware_wls/user_projects/domains/suite_domain/bin/"
#    done
#    echo "Coherence configured"
#  done
  #################echo "OSM Coherence Configurations completed"
############################fi

source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/osm_lib
start_osm_admin_server

echo "Starting WebLogic managed servers"

  source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/osm_lib
  start_osm

echo "WebLogic managed servers started"

echo "Installation Finished"

#### deploy product cartridges Asset. Account, Job
$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/install_productCartridge.sh

echo "Assigning Account workgroups"
/bin/bash -c "export MIK_KNOBS_PATH=accounts_config/accounts_config/assign_workgroup/knobs_osm_assign_workgroups ; $MANAGEABLE_INSTALL_TOOL_DIR/accounts_config/accounts_config/assign_workgroup/accounts_workgroup.sh osm"
echo "Workgroups Assigned"

