#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -x
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

echo "Configuration read"

#-------------------------------------------------------------------------------
# Collect media

echo "Collecting media"

############DB 64bit client version 12.2.0.1.0####################
mik_collect_media DB_CLIENT_64
mik_collect_media OSM
mik_collect_media JBOSS_1_4_1_SP13

echo "Media collected"

#--------------------------------------------------------------------------------
# TODO database client pre-reqs

#--------------------------------------------------------------------------------
# Install Database Client

echo "Installing database client"


/usr/bin/unzip -o -q -d $DATABASE_CLIENT_MEDIA_DOWNLOAD_DIR $DATABASE_CLIENT_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_DB_CLIENT_64

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_HOST=$DATABASE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOST_OS_GROUP_NAME=$WEBLOGIC_HOST_OS_GROUP_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo ORACLE_INVENTORY_DIR=$ORACLE_INVENTORY_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_CLIENT_HOME_DIR=$DATABASE_CLIENT_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_CLIENT_ORACLE_HOME_DIR=$DATABASE_CLIENT_ORACLE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/client.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/client.rsp
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

$DATABASE_CLIENT_MEDIA_DOWNLOAD_DIR/client/runInstaller -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/client.rsp -invPtrLoc ${WEBLOGIC_HOST_APPLICATIONS_HOME_DIR}/oraInst.loc -waitforcompletion || RET_CODE=$?
# OUI return code of 6: The installation was successful after you proceeded by disregarding a few prerequisite checks or warnings.
# OUI return code of 253 (-3): The attempted installation encountered a prerequisite failure. Some of the required prerequisites have not been met. See the logs for details.
case "$RET_CODE" in
"")  ;;
0)  ;;
6)  ;;
253)  ;;
*) false
  ;;
esac
/bin/bash -c "SUDO_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_sudo.sh ; export SUDO_ASKPASS ; $SUDO_PROGRAM -A -k -E -p '%H:%p' $DATABASE_CLIENT_ORACLE_HOME_DIR/root.sh"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_HOST=$DATABASE_HOST >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_SID_UPPERCASE=$DATABASE_SID_UPPERCASE >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_PORT=$DATABASE_PORT >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo DATABASE_GLOBAL_NAME=$DATABASE_GLOBAL_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/tnsnames.ora.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/tnsnames.ora
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

/bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/database/tnsnames.ora $DATABASE_CLIENT_ORACLE_HOME_DIR/network/admin
echo -e "\nADR_BASE = $DATABASE_CLIENT_HOME_DIR" >> $DATABASE_CLIENT_ORACLE_HOME_DIR/network/admin/sqlnet.ora

echo "Database client installed"

#--------------------------------------------------------------------------------
# Install Database Patches if new DB was installed

######## if RAC DB not call config_db.sh
if [ $DATABASE_RAC == 'No' -o $DATABASE_INSTALL == 1  ]
  then
	echo "Configuring database"
	mik_run_remote $DATABASE_HOST ${DATABASE_HOST_OS_USER_NAME} $OSM_SCRIPT_MODULE_NAME/database/config_db.sh $DATABASE_HOST_MANAGEABLE_INSTALL_TOOL_DIR
	echo "Database configured"
fi

#--------------------------------------------------------------------------------
# Blanket Configure Shell
source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/.bashrc_osm
# TODO blanket
##################Lisha############################################
export ANT_HOME=$WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8
export PATH=$ANT_HOME/bin:${PATH}

#--------------------------------------------------------------------------------
# Install WebLogic

source $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/common/osm_lib

populate_osm_servers

for i in `/usr/bin/seq 1 ${OSM_SERVER_COUNT}`;
do
  /bin/cp $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/knobs_weblogic.template $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/knobs_weblogic_${i}
  $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common config_knobs -file=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/knobs_weblogic_${i} -DWEBLOGIC_HOST_APPLICATIONS_HOME_DIR=${apphomes[i]} -DWEBLOGIC_HOST_MEDIA_DOWNLOAD_DIR=${mikhomes[i]}/downloads
  
  mik_run_remote ${servers[i]} ${users[i]} $OSM_SCRIPT_MODULE_NAME/osm/install_weblogic.sh ${mikhomes[i]} $OSM_SCRIPT_MODULE_NAME/osm/knobs_weblogic_${i}
done

#--------------------------------------------------------------------------------
# Prepare OSM

echo "Staging OSM"
/usr/bin/unzip -o -q -d $OSM_MEDIA_DOWNLOAD_DIR $MEDIA_LOC_OSM
/bin/chmod +x $OSM_MEDIA_DOWNLOAD_DIR/InstallLinux.bin
/usr/bin/unzip -o -q -d $OSM_MEDIA_DOWNLOAD_DIR ${MEDIA_LOC_JBOSS_1_4_1_SP13}
#/usr/bin/unzip -o -q -d $OSM_MEDIA_DOWNLOAD_DIR/saxon $OSM_MEDIA_DOWNLOAD_DIR/saxonb9-1-0-7j.zip
echo "OSM staged"

echo "Installation Finished"
