#!/usr/local/bin/perl

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################

#This script performs the following 
  #Downloads UIM,ASAP and OSM latest packages
  #Generates response files
  #Perform silent instalaltion using response files

############################################################

use File::Copy;
use Cwd;
$cwd = getcwd;

require "commoninfo.properties";
require "decrypt_util.pl";


#General configurations 
chomp($ARGV[0]);

#Install all suite applications (ASAP,OSM and UIM)
if ($ARGV[0]=~/asap/i && $#ASAP>=0) {
	print "Installing ASAP.........\n";
	&asap_install();
}
if ($ARGV[0]=~/uim/i && $#UIM>=0) {
	print "Installing UIM.........\n";
	&uim_install();
}
if ($ARGV[0]=~/osm/i && $#OSM>=0) {
	print "Installing OSM.........\n";
	&osm_install();
}

sub asap_install{
    if( ! -e $asap_pkg){
      #print (STDERR "ASAP package (\'$asap_pkg\') does not exist .... \n exiting....\n");
    }

    chdir "$cwd/asap";
    $ENV{ANT_HOME}="$MIDDLEWARE_HOME/modules/org.apache.ant_1.7.1";
    $cmd="$MIDDLEWARE_HOME/modules/org.apache.ant_1.7.1/bin/ant -f build.xml";
    print "calling $cmd \n";
    system($cmd);
    print"$cmd\n";
}

sub osm_install{  

     if ($#CLUSTERS > -1) {		      #print (STDERR "osm package (\'$osm_pkg\') does not exist .... \n exiting....\n");
	       &coherencecfg();		
      }		
      else {		
	       print "Skipping OSM cluster configuration...\n";		
	       system("/bin/touch osm-coherence-cluster-config.xml");		
     }
		

    if( ! -e $osm_pkg){
      #print (STDERR "osm package (\'$osm_pkg\') does not exist .... \n exiting....\n");
    }

   
    chdir "$cwd/osm";
    $ENV{ANT_HOME}="$MIDDLEWARE_HOME/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8";
    $cmd="$ENV{ANT_HOME}/bin/ant -f build.xml";
    print "calling $cmd \n";
    system($cmd);
    if (index($cmd, "fail") != -1) {
        $cmd= "$cmd\nPlease note : DB patches to be installed for successful installation of OSM. If they aren't, the install fails.\n";
    }
    print"$cmd\n";
}



sub coherencecfg {		
	#@OSM_COHERENCE		
	   open(COHERENCE,"> osm-coherence-cluster-config.xml");		
	        print "creating osm coherence config file osm-coherence-cluster-config.xml \n";		
	         print COHERENCE "        <BEA-parameter>\n";		
	         print COHERENCE "            <parameter-label>Create-Coherence-Config</parameter-label>\n";		
	         print COHERENCE "            <parameter-value>true</parameter-value>\n";		
	         print COHERENCE "        </BEA-parameter>\n";		
	         print COHERENCE "        <BEA-parameter>\n";		
	         print COHERENCE "            <parameter-label>Coherence-Cluster-Name</parameter-label>\n";		
	         print COHERENCE "            <parameter-value>OSM_Cluster</parameter-value>\n";		
	         print COHERENCE "        </BEA-parameter>\n";		
	         print COHERENCE "        <BEA-parameter>\n";		
	         print COHERENCE "            <parameter-label>Coherence-Cluster-Unicast-Port</parameter-label>\n";		
	         print COHERENCE "            <parameter-value>17001</parameter-value>\n";		
	         print COHERENCE "        </BEA-parameter>\n";		
	         $i=0;		
	         foreach $osm (@OSM_COHERENCE) {		
	            $i=$i+1;		
	            $osmname = (split(":",$osm))[0];$osmhost = (split(":",$osm))[1];$osmport = (split(":",$osm))[2];		
	            print COHERENCE "        <BEA-parameter>\n";		
	            print COHERENCE "            <parameter-label>Well-Known-Address-Listen-Address-$i</parameter-label>\n";		
	            print COHERENCE "            <parameter-value>$osmhost</parameter-value>\n";		
	            print COHERENCE "        </BEA-parameter>\n";		
	            print COHERENCE "        <BEA-parameter>\n";		
	            print COHERENCE "            <parameter-label>Well-Known-Address-Listen-Port-$i</parameter-label>\n";		
	            print COHERENCE "            <parameter-value>17001</parameter-value>\n";		
	            print COHERENCE "        </BEA-parameter>\n";		
	         }		
	         print COHERENCE "        <BEA-parameter>\n";		
	         print COHERENCE "            <parameter-label>Number-Coherence-Well-Known-Addresses</parameter-label>\n";		
	         print COHERENCE "            <parameter-value>$i</parameter-value>\n";		
	         print COHERENCE "        </BEA-parameter>\n";		
	#@OSMPROXY		
	         foreach $osm (@OSMPROXY) {		
	            $osmname = (split(":",$osm))[0];$osmhost = (split(":",$osm))[1];$osmport = (split(":",$osm))[2];		
	            print COHERENCE "        <BEA-parameter>\n";		
	            print COHERENCE "            <parameter-label>Frontend-Host</parameter-label>\n";		
	            print COHERENCE "            <parameter-value>$osmhost</parameter-value>\n";		
	            print COHERENCE "        </BEA-parameter>\n";		
	            #print COHERENCE "        <BEA-parameter>\n";		
	            #print COHERENCE "            <parameter-label>Frontend-HTTPS-Port</parameter-label>\n";		
	            #print COHERENCE "            <parameter-value>0</parameter-value>\n";		
	            #print COHERENCE "        </BEA-parameter>\n";		
	            print COHERENCE "        <BEA-parameter>\n";		
	            print COHERENCE "            <parameter-label>Frontend-HTTP-Port</parameter-label>\n";		
	            print COHERENCE "            <parameter-value>$osmport</parameter-value>\n";		
	            print COHERENCE "        </BEA-parameter>";		
	         }		
	}


sub uim_install{
    if ($^O =~ /linux/) {
   	 &uim_preinstall();
    }
    if( ! -e $uim_pkg){
      #print (STDERR "uim package (\'$uim_pkg\') does not exist .... \n exiting....\n");
    }

    chdir "$cwd/uim";
    $ENV{ANT_HOME}="$MIDDLEWARE_HOME/modules/org.apache.ant_1.7.1";
    $cmd="$MIDDLEWARE_HOME/modules/org.apache.ant_1.7.1/bin/ant -f build.xml";
    print "calling $cmd \n";
    system($cmd);
    print"$cmd\n";

    sleep(600);

    #copy aspectjweaver.jar,aspectjtools.jar,aspectjrt.jar to domain/lib location
     if(-e "$ASPECTJ_LOCATION") {
     	if(!-e "$ASPECTJ_LOCATION/aspectjweaver.jar" && !-e "$ASPECTJ_LOCATION/aspectjtools.jar" && !-e "$ASPECTJ_LOCATION/aspectjrt.jar") {
	 	die "Error: The required AspectJ jars (aspectjweaver.jar,aspectjtools.jar,aspectjrt.jar) are not found here $ASPECTJ_LOCATION $!";
     	}
     	else {
     		$cmd="cp $ASPECTJ_LOCATION/aspectj* $DOMAIN_HOME/UIM/lib";
     		system($cmd);
    	 	print"$cmd\n";

     		$cmd="chmod -R 755 $DOMAIN_HOME/UIM/lib/aspectjweaver.jar";
     		system($cmd);
     		$cmd="chmod -R 755 $DOMAIN_HOME/UIM/lib/aspectjtools.jar";
     		system($cmd);
     		$cmd="chmod -R 755 $DOMAIN_HOME/UIM/lib/aspectjrt.jar";
     		system($cmd);
     	}
     }
	
}


sub uim_preinstall {
   #create MDS schema using the connection and MDS schema information configured in properties file

  if(!-e $RCU_LOCATION) {
    print"Invalid RCU executable location configured $RCU_LOCATION\n";
        die "Error: Couldn't find the file $!";
  }

   open(SUITEPROP,"suite_install.properties");
   while(<SUITEPROP>) {
     if($_=~/uim.dbuser.input/) {
        $_=(split(/\=/,$_))[1];chomp($_);
        $_=~ s/\{//g;$_=~ s/\}//g;$_=~ s/\"//g;
        $dbhost=(split(/\,/,$_))[0];
        $dbport=(split(/\,/,$_))[1];
        $dbuser=(split(/\,/,$_))[2];
        $encdbpassword=(split(/\,/,$_))[3];
        $dbpassword=&decryptPassword($encdbpassword,$MIDDLEWARE_HOME,$JAVA_HOME);
        $dbservice=(split(/\,/,$_))[4];
     }
     if($_=~/uim.mdsdb.input/) {
        $_=(split(/\=/,$_))[1];chomp($_);
        $_=~ s/\{//g;$_=~ s/\}//g;$_=~ s/\"//g;
        $mdsdbhost=(split(/\,/,$_))[0];
        $mdsdbport=(split(/\,/,$_))[1];
        $mdsdbuser=(split(/\,/,$_))[2];
        $mdsdbuser=~ s/_mds|_MDS//g;
        $encmdsdbpassword=(split(/\,/,$_))[3];
        $mdsdbpassword=&decryptPassword($encmdsdbpassword,$MIDDLEWARE_HOME,$JAVA_HOME);
        $mdsdbservice=(split(/\,/,$_))[4];
     }
   }
   &genpwdfile();
   $cmd="$RCU_LOCATION -createRepository -connectString $dbhost:$dbport:$dbservice -dbUser sys -silent  -dbRole SYSDBA -schemaPrefix $mdsdbuser -component MDS -f < logs/mdspwd.txt > logs/rcu.log";
   print "Executing command.....\n>$cmd \n";
   system($cmd);

  #cleanup mdspwd.txt
   $cmd="rm logs/mdspwd.txt";
   system($cmd);

   &validation();
}

sub genpwdfile{
   open(PWDFILE,">logs/mdspwd.txt");
     print PWDFILE "$dbpassword\n";
     print PWDFILE "$mdsdbpassword\n";
  close(PWDFILE);
}

sub validation {
        open (RESOURCES, "logs/rcu.log") || warn "Unable to open file rcu.log\n";
        $flag="false";
        while(<RESOURCES>) {
                chomp($_);
                print "$_\n";
                if($_=~/Metadata Services/ && $_=~/Success/) {
                        $flag="true";
                }
        }
        close(RESOURCES);
        if($flag=~/true/) {
                print"The Metadata Services (MDS) user created successfully\n";
        }
        else {
                die "Error: The Metadata Services (MDS) user is not created successfully$!";
        }
}

