#!/bin/bash

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=$( cd `/usr/bin/dirname ${BASH_SOURCE}` > /dev/null ; /bin/pwd )

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH  
fi

source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

echo "Configuration read"

#-------------------------------------------------------------------------------
# Collect media
set -x
echo "Collecting media"

######################
mik_collect_media FMW

echo "Media collected"

#--------------------------------------------------------------------------------
# Install WebLogic

echo "Installing WebLogic"

/usr/bin/unzip -o -q -d $WEBLOGIC_MEDIA_DOWNLOAD_DIR $WEBLOGIC_MEDIA_DOWNLOAD_DIR/$MEDIA_NAME_FMW
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

echo WEBLOGIC_MIDDLEWARE_HOME_DIR=$WEBLOGIC_MIDDLEWARE_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo WEBLOGIC_HOME_DIR=$WEBLOGIC_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties
echo JAVA_HOME=$JAVA_HOME >> $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/wls_cfg.rsp.template > $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/wls_cfg.rsp

mkdir -p $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR
echo "inventory_loc=$WEBLOGIC_HOST_APPLICATIONS_HOME_DIR" >> $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR/oraInst.loc
echo "$JAVA_HOME/bin/java -d64 -jar $WEBLOGIC_MEDIA_DOWNLOAD_DIR/fmw_12.2.1.3.0_infrastructure.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/wls_cfg.rsp -invPtrLoc $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR/oraInst.loc"
$JAVA_HOME/bin/java -d64 -jar $WEBLOGIC_MEDIA_DOWNLOAD_DIR/fmw_12.2.1.3.0_infrastructure.jar -silent -responseFile $MANAGEABLE_INSTALL_TOOL_DIR/$OSM_SCRIPT_MODULE_NAME/osm/wls_cfg.rsp -invPtrLoc $WEBLOGIC_HOST_APPLICATIONS_HOME_DIR/oraInst.loc

echo "WebLogic installed"

#--------------------------------------------------------------------------------
# Install EclipseLink patches

#echo "Applying EclipseLink patches"

#/usr/bin/unzip -o -q -d $WEBLOGIC_MEDIA_DOWNLOAD_DIR/p15842881 $WEBLOGIC_MEDIA_DOWNLOAD_DIR/p15842881_1036_Generic.zip
#/bin/cp $WEBLOGIC_MEDIA_DOWNLOAD_DIR/p15842881/patch-catalog_18584.xml $WEBLOGIC_MEDIA_DOWNLOAD_DIR/p15842881/patch-catalog.xml
#/bin/bash -c "cd $WEBLOGIC_MIDDLEWARE_HOME_DIR/utils/bsu ; $WEBLOGIC_MIDDLEWARE_HOME_DIR/utils/bsu/bsu.sh -install -patchlist=PAJL -patch_download_dir=$WEBLOGIC_MEDIA_DOWNLOAD_DIR/p15842881 -prod_dir=$WEBLOGIC_HOME_DIR"

#echo "EclipseLink patches applied"
