#!/usr/local/bin/perl

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


#This software and related documentation are provided under a license agreement 
#containing restrictions on use and disclosure and are protected by intellectual 
#property laws. Except as expressly permitted in your license agreement or 
#allowed by law, you may not use, copy, reproduce, translate, broadcast, modify, 
#license, transmit, distribute, exhibit, perform, publish, or display any part, 
#in any form, or by any means. Reverse engineering, disassembly, or 
#decompilation of this software, unless required by law for interoperability, is 
#prohibited.
#The information contained herein is subject to change without notice and is not 
#warranted to be error-free. If you find any errors, please report them to us in 
#writing.
#If this is software or related documentation that is delivered to the U.S. 
#Government or anyone licensing it on behalf of the U.S. Government, the 
#following notice is applicable:
#U.S. GOVERNMENT END USERS: Oracle programs, including any operating system, 
#integrated software, any programs installed on the hardware, and/or 
#documentation, delivered to U.S. Government end users are "commercial computer 
#software" pursuant to the applicable Federal Acquisition Regulation and agency-
#specific supplemental regulations. As such, use, duplication, disclosure, 
#modification, and adaptation of the programs, including any operating system, 
#integrated software, any programs installed on the hardware, and/or 
#documentation, shall be subject to license terms and license restrictions 
#applicable to the programs. No other rights are granted to the U.S. Government.
#This software or hardware is developed for general use in a variety of 
#information management applications. It is not developed or intended for use in 
#any inherently dangerous applications, including applications that may create a 
#risk of personal injury. If you use this software or hardware in dangerous 
#applications, then you shall be responsible to take all appropriate fail-safe, 
#backup, redundancy, and other measures to ensure its safe use. Oracle 
#Corporation and its affiliates disclaim any liability for any damages caused by 
#use of this software or hardware in dangerous applications.
#Oracle and Java are registered trademarks of Oracle and/or its affiliates. 
#Other names may be trademarks of their respective owners.
#Intel and Intel Xeon are trademarks or registered trademarks of Intel 
#Corporation. All SPARC trademarks are used under license and are trademarks or 
#registered trademarks of SPARC International, Inc. AMD, Opteron, the AMD logo, 
#and the AMD Opteron logo are trademarks or registered trademarks of Advanced 
#Micro Devices. UNIX is a registered trademark of The Open Group.
#This software or hardware and documentation may provide access to or 
#information on content, products, and services from third parties. Oracle 
#Corporation and its affiliates are not responsible for and expressly disclaim 
#all warranties of any kind with respect to third-party content, products, and 
#services. Oracle Corporation and its affiliates will not be responsible for any 
#loss, costs, or damages incurred due to your access to or use of third-party 
#content, products, or services.


############################################################
#This script performs the following
#     Configure coherence parameter file for OSM cluster
############################################################

use File::Copy;

require "commoninfo.properties";

#Starting from OSM 7.3.0 coherence cluster configuration is taken care by OSM installer.So no need of explicit operation here.
if ($#CLUSTERS > -1 && $OSM_VERSION_GT_THAN_7241=~/false/) {
   &coherencecfg();
}
else {
   print "Skipping this configuration...\n";
}


sub coherencecfg {
   open(COHERENCE,"> $DOMAIN_HOME/osm-coherence-cluster-config.xml");
        print "creating osm coherence config file $DOMAIN_HOME/osm-coherence-cluster-config.xml \n";
         print COHERENCE "<cluster-config>\n";
         print COHERENCE "    <member-identity>\n";
         print COHERENCE "    <!--\n";
         print COHERENCE "Choose a unique name for the cluster, such that no other OSM instance in your network would have the same name\n";
         print COHERENCE "    -->\n";
         print COHERENCE "    <cluster-name system-property=\"tangosol.coherence.cluster\">OSM_Cluster</cluster-name>\n";
         print COHERENCE "    </member-identity>\n";
         print COHERENCE "    <unicast-listener>\n";
         print COHERENCE "    <!--\n";
         print COHERENCE "Add more <socket-address>socket_address</socket-address> elements to well-known addresses, one for each member in your OSM WebLogic cluster.\n";
         print COHERENCE "    -->\n";
         print COHERENCE "    <well-known-addresses>\n";
	 $i=1;
	 foreach $osm (@OSM_COHERENCE) {
            $osmname = (split(":",$osm))[0];$osmhost = (split(":",$osm))[1];$osmport = (split(":",$osm))[2];
			print COHERENCE "        <socket-address id=\"$i\">\n";
			print COHERENCE "        <address>$osmhost</address>\n";
			print COHERENCE "        <port>$osmport</port>\n";
			print COHERENCE "        </socket-address>\n";
			&osm_startupscript();
			$i=$i+1;
	 }	 
         print COHERENCE "    </well-known-addresses>\n";
         print COHERENCE "    </unicast-listener>\n";
         print COHERENCE "</cluster-config>\n";

}

sub osm_startupscript {

        open(WLSCRIPT,"$DOMAIN_HOME/bin/startManagedWebLogic.sh");
        open(OSMMNG1,">$DOMAIN_HOME/bin/start$osmname.sh");

        $add1 = "export JAVA_OPTIONS=\"\$\{JAVA_OPTIONS\} -Dosm.coherence.cluster.config.override=$DOMAIN_HOME/osm-coherence-cluster-config.xml  -Dtangosol.coherence.localhost=$osmhost -Dtangosol.coherence.localport=$osmport -Dtangosol.coherence.management=all\"";

   while(<WLSCRIPT>) {
        chomp($_);
        if($_=~/export JAVA_OPTIONS/) {
                $origline=$_;
                $_="$origline\n\n$add1\n";
        }
        print OSMMNG1 "$_\n";
   }
        close(OSMMNG1);
        close(WLSCRIPT);
	system("chmod 744 $DOMAIN_HOME/bin/start$osmname.sh");

}
