#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################
#This script performs the following 
#1. The application required pre-install configurations are done here

# Version 1.0
# Rajesh Prabakarn
############################################################

use File::Copy;
require "commoninfo.properties";
require "decrypt_util.pl";
#General configurations 

#Any pre-install configurations for suite products
chomp($_);
if($ARGV[0]=~/OSM Single Node|OSM 2 Node Cluster|Suite/ && $#OSM>=0) {
	&osm_preinstall();
}
if($ARGV[0]=~/ASAP Single Node|Suite/ && $#ASAP>=0) {
	&asap_preinstall();
}

if($#ARGV==-1 && $#OSM>=0) {
	&osm_preinstall();
}
if($#ARGV==-1 && $#ASAP>=0) {
	&asap_preinstall();
}

sub asap_preinstall{

  if(! -f "$JCONN_LOCATION") {
     print"Invalid JCONN template location $JCONN_LOCATION\n";
        die "Error: Couldn't find the file $!";
  }

   #copy jconn2.jar to domain/lib location
   $cmd="cp $JCONN_LOCATION $DOMAIN_HOME/lib";
   system($cmd);
   print"$cmd\n";

   $cmd="rm -rf $ENV{'HOME'}/InstallShield";
   system($cmd);
   print"$cmd\n";

  open(SETDOMAIN,"$DOMAIN_HOME/bin/setDomainEnv.sh");
  open(NEWSETDOMAIN,">$DOMAIN_HOME/bin/setDomainEnv.sh_new");
  while(<SETDOMAIN>) {
    if($_=~/# SET THE CLASSPATH/) {
       $origline=$_;
       $_="export CLASSPATH=$DOMAIN_HOME/lib/jconn2.jar:$DOMAIN_HOME/lib/jconn4.jar:\$CLASSPATH\n$origline";
    }
     print NEWSETDOMAIN "$_";
  }
   close(NEWSETDOMAIN);
   close(SETDOMAIN);
   rename("$DOMAIN_HOME/bin/setDomainEnv.sh_new","$DOMAIN_HOME/bin/setDomainEnv.sh");
   print " configured CLASSPATH in weblogic setdomain.sh ($DOMAIN_HOME/bin/setDomainEnv.sh) \n";

  #to generate tnsnames.ora
  &genasap_tnsnames();
}

sub osm_preinstall {

  if(! -f "$DOMAIN_HOME/bin/setDomainEnv.sh") {
     print"Invalid JCONN template location $DOMAIN_HOME/bin/setDomainEnv.sh\n";
        die "Error: Couldn't find the file $!";
  }

#configure user mem args in setDomain.sh
  open(SETDOMAIN,"$DOMAIN_HOME/bin/setDomainEnv.sh");
  open(NEWSETDOMAIN,">$DOMAIN_HOME/bin/setDomainEnv.sh_new");
  while(<SETDOMAIN>) {
    if($_=~/# IF USER_MEM_ARGS/) {
       $origline=$_;
       $_="USER_MEM_ARGS=\"-Xms1024m -Xmx2048m -XX:PermSize=768m -XX:MaxPermSize=768m\"\nexport USER_MEM_ARGS\n\n$origline"; 
    }
     print NEWSETDOMAIN "$_";
  }
   close(NEWSETDOMAIN);
   close(SETDOMAIN);
   rename("$DOMAIN_HOME/bin/setDomainEnv.sh_new","$DOMAIN_HOME/bin/setDomainEnv.sh");
   print " configured USER_MEM_ARGS in weblogic setdomain.sh ($DOMAIN_HOME/bin/setDomainEnv.sh) \n";
}

sub genasap_tnsnames {
    open(SUITEPROP,"suite_install.properties");
   while(<SUITEPROP>) {
	chomp($_);
    if($_=~/asap.db.host/) {
		$asap_dbhost=(split(/\=/,$_))[1];
	}
    if($_=~/asap.db.port/) {
		$asap_dbport=(split(/\=/,$_))[1];
	}
    if($_=~/asap.db.sid/) {
		$asap_dbsid=(split(/\=/,$_))[1];
	}
    if($_=~/asap.db.service/) {
		$asap_dbservice=(split(/\=/,$_))[1];
	}
   }

   open(TNSFILE,">templates/tnsnames.ora");
	print TNSFILE "$asap_dbsid =\n";
	print TNSFILE "  (DESCRIPTION =\n";
	print TNSFILE "    (ADDRESS = (PROTOCOL = TCP)(HOST = $asap_dbhost)(PORT = $asap_dbport))\n";
	print TNSFILE "   (CONNECT_DATA =\n";
	print TNSFILE "      (SERVER = DEDICATED)\n";
        print TNSFILE "      (SERVICE_NAME = $asap_dbservice)\n";
	print TNSFILE "   )\n";
	print TNSFILE "  )\n";
  close(TNSFILE);
}
