# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

#Purpose: 
# This script (uim-cartridge-deployment.pl) takes care of the following
# 1. Imports data from commoninfo.properties and suite_install.properties
# 2. Generate cartridge-build.properties with required data for deploying UIM cartridges
# 3. The cartridges are deploying by invoking scripted cartridge deploy tool

# Version 1.0
# Rajesh Prabakarn
#02/02/2013 - ZKUNJU - Added updatePWLCInput, deployAndList,initCommonVariables, validateDeployment method 
#removed code of Cartridge property file updates
#02/02/2013 - ZKUNJU - Removed the logic of using UIM user for UIM Cartridge deployment
#-----------------------------------------------------------------------------

use Cwd;
$cwd = getcwd;

require "commoninfo.properties";
my $asapEnvID = "";

&fetch_asapEnvID();
&initCommonVariables();
&updatePWLCInput();
&deploy();
&listAndValidate();

sub fetch_asapEnvID {
	open(INSTALL_PROP,"suite_install.properties");

	while(<INSTALL_PROP>) {
		chomp($_);
		if($_ =~ /asap.core.envid/) {
			$asapEnvID = (split("=",$_))[1];
			print "ASAP Environment ID is $asapEnvID\n";
		}                
		if($_ =~ /uim.cmwsuser.input/) {
			$cmws_array= (split("=",$_))[1];
                        $CMWSUSER= (split("\"",$cmws_array))[1];
                        #$CMWSUSER_PASSWD= (split("\"",$cmws_array))[3];
			my $javacmd ="java -cp . CMWUserInput $cwd/suite_install.properties $cwd/UIM_CM_USER.properties";
			$CMWSUSER_PASSWD=`$javacmd`;
			
		}
                if($_ =~ /uim.wls.servername/) {
                        $uimtarget= (split("=",$_))[1];
                        $uimtarget= (split("\"",$uimtarget))[1];
                        print "uim target server is $uimtarget\n";
                }
	}
	close(INSTALL_PROP);
}

sub initCommonVariables {
	chdir "$PWLC_LOCATION/pwlc/scripts";
	$cartDir="$DOMAIN_HOME/UIM/cartridges/base/";
	$superCartDir="$cwd";
	@cartridges=("ora_uim_baseextpts_cartproj.jar","ora_uim_basemeasurements_cartproj.jar","ora_uim_baserulesets_cartproj.jar",
		     "ora_uim_basetechnologies_cartproj.jar","ora_uim_basespecifications_cartproj.jar","ora_uim_basephone_mgmt_cartproj.jar",
		     "ora_uim_canada_tn_cartproj.jar","ora_uim_norway_tn_cartproj.jar","ora_uim_saudi_arabia_tn_cartproj.jar",
		     "ora_uim_uk_tn_cartproj.jar","ora_uim_us_tn_cartproj.jar");
	@cartSuffix="_cartproj.jar";
	$entry="/bin/sh ".$PWLC_LOCATION."/pwlc/scripts/cartridgetools_entry.sh";
	$pwlcCommonArgs="UIM_WLADMIN_HOST UIM_WLADMIN_PORT UIM_CMWS_USER UIM_CMWS_PASSWORD UIM_CART_TYPE UIM_CMWS_TARGET";

}

sub updatePWLCInput {
	$pwlcInputFile=$PWLC_LOCATION."/pwlc/scripts/_platform_wlcommands_inputs.properties";
	$strupdates="UIM_WLADMIN_HOST=".$ADMIN_HOST."\n";
	$strupdates=$strupdates."UIM_WLADMIN_PORT=".$ADMIN_PORT."\n";
	$strupdates=$strupdates."UIM_CMWS_USER=".$CMWSUSER."\n";
	$strupdates=$strupdates."UIM_CMWS_PASSWORD=".$CMWSUSER_PASSWD."\n";
	$strupdates=$strupdates."UIM_CART_TYPE="."Inventory"."\n";
	$strupdates=$strupdates."UIM_CMWS_TARGET=".$uimtarget."\n";
	$strupdates=$strupdates."UIM_CMWS_DEPLOY_PROPERTIES="."model.ACTIVATION_ENVIRONMENT_ID=".$asapEnvID."\n";

	print "Updating file ".$pwlcInputFile." with UIM Cartridge deployment updates\n";
	open (MYFILE, ">>$pwlcInputFile");
	print MYFILE "#Added by uim-cartridge-deployment.pl\n";
	print MYFILE $strupdates;
	close (MYFILE);
	print "Updated file ".$pwlcInputFile." with UIM Cartridge deployment updates\n";
}

sub deploy {	
	print "UIM Cartridge deployment started \n";
	$pwlcCartDeployEntry=$entry." "."deploy"." ".$pwlcCommonArgs;
	
	foreach $cartridge (@cartridges) {
                if($asapEnvID ne ""){
		$cmd = $pwlcCartDeployEntry." ".$cartDir."/".$cartridge." "."UIM_CMWS_DEPLOY_PROPERTIES";
                }
                else{
                $cmd = $pwlcCartDeployEntry." ".$cartDir."/".$cartridge."";
                }
		print "Deploying Cartridge $cartridge using command $cmd \n";
		system($cmd);
		print "Deployed Cartridge $cartridge \n";
	}
	
        print "UIM Cartridge deployment completed \n";
}


sub listAndValidate {
	$cartListOut="$cwd/cartlist.log";
	print "UIM Cartridge listing started \n";
	$pwlcCartListEntry=$entry." "."list"." ".$pwlcCommonArgs." > $cartListOut";
	system($pwlcCartListEntry);	

        open (RESOURCES, "$cartListOut") || warn "Unable to open file $cartListOut\n";	
	$allActiveCarts="";
        while(<RESOURCES>) {
                chomp($_);
		print "$_ \n";
		$allActiveCarts=$allActiveCarts.$_.",";	              		
        }
	print "UIM Cartridge listing completed \n";

	foreach $cartridge (@cartridges) {
		$cartridge =~ s/@cartSuffix//;
		if (index($allActiveCarts, $cartridge) == -1) {	    		 
			die "UIM Cartridge $cartridge is not deployed \n"."Error: UIM Mobile solution cartridges are not deployed successfully.\n$!";
		}
	}	
        close(RESOURCES);
	print "UIM Mobile solution cartridges are deployed successfully \n";  
}
