#!/usr/local/bin/perl

# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


############################################################

#This script performs the following 
  #Downloads UIM,ASAP and OSM latest packages
  #Generates response files
  #Perform silent instalaltion using response files

############################################################

use File::Copy;
use Cwd;
$cwd = getcwd;

require "commoninfo.properties";
require "decrypt_util.pl";

#General configurations 
chomp($ARGV[0]);

#Install all suite applications (ASAP,OSM and UIM)
if ($ARGV[0]=~/asap/i) {
	print "Update ASAP response.........\n";
    	@passwords =("asap.db.password|DBPassword","asap.wls.admin.password|WLSPassword","asap.wl.admin.password|ASAP_ADMIN_PASSWORD","asap.monitor.password|ASAP_MONITOR_PASSWORD","asap.operator.password|ASAP_OPERATOR_PASSWORD","asap.ws_user.password|ASAP_WS_USER_PASSWORD","asap.cmws_studio.password|ASAP_CMWS_STUDIO_PASSWORD");
    	$rspLoc = "$cwd/asap/config/asap72ServerLinux.response";
	&updateRSP();
}
if ($ARGV[0]=~/uim/i) {
	print "Update UIM response.........\n";
    	@passwords =("uim.db.password|DB_USER_PASSWD");
    	$rspLoc = "$cwd/uim/config/uim72ServerLinux.response";
	&updateRSP();
	#split based on position ( format : properties_tag|rsp_tag|position)
	@ouipwds=("uim.ldapuser.input|LDAP_USER_INPUT|1^2","uim.cmwsuser.input|INPUT_CMWSUSER_DETAILS|1^2","uim.mdsdb.input|MDS_DB_USER_INPUT|3","uim.wlserver.input|APP_USER_INPUT|3","uim.appschema.input|APP_SCHEMA_INPUT|1","uim.dbuser.input|DB_USER_INPUT|3");
	&OUI_response_update();
}
if ($ARGV[0]=~/osm/i) {
	print "Update OSM response.........\n";
    	@passwords =("osm.wls.admin.password|WLPassword","osm.db.admin.password|DBAdminPassword","osm.db.password|OSMDBPasssword","osm.ruleEngine.Schema.Password|RuleEngineDBPassword","osm.admin.Password|OSMAdminPassword","osm.db.reporting.password|ReportingDBPassword");
    	$rspLoc = "$cwd/osm/config/osm_install_cfg.xml";
	&updateRSP();
}

sub updateRSP {
    foreach $item (@passwords) {
      $password=(split(/\|/,$item))[0];
      $rsptag=(split(/\|/,$item))[1];
      open(SUITEPROP,"suite_install.properties");
        while(<SUITEPROP>) {
		chomp($_);
                if($_ =~ /$password/) {
                        $pwd=(split(/\=/,$_))[1];
			$asapPassword=&decryptPassword($pwd,$MIDDLEWARE_HOME,$JAVA_HOME);
                }
        }
	open(RSP,"$rspLoc");
	open(TMPRSP,"> $rspLoc"."_tmp");
	while(<RSP>) {
		chomp($_);
		$_=~s/\@$rsptag\@/$asapPassword/g;
		print TMPRSP "$_\n";
	}
	rename("$rspLoc"."_tmp","$rspLoc");
     }
}


sub OUI_response_update {
    foreach $item (@ouipwds) {
      $password=(split(/\|/,$item))[0];
      $rsptag=(split(/\|/,$item))[1];
	  $pos=(split(/\|/,$item))[2];
	  @position=(split(/\^/,$pos));
	  foreach $p (@position) {
    	     open(SUITEPROP,"suite_install.properties");	
             while(<SUITEPROP>) {
                chomp($_);
                if($_ =~ /$password/) {
                        $pwd=(split(/\,/,$_))[$p];
			$pwd=(split(/\"/,$pwd))[1];
                        $decpwd=&decryptPassword($pwd,$MIDDLEWARE_HOME,$JAVA_HOME);
			$_=~s/$pwd/$decpwd/g;
			$newline=(split(/\=/,$_))[1];
                }
             }
             open(RSP,"$rspLoc");
             open(TMPRSP,"> $rspLoc"."_tmp");
             while(<RSP>) {
               	chomp($_);
               	$_=~s/\@$rsptag\@/$newline/;
               	print TMPRSP "$_\n";
             }
		rename("$rspLoc"."_tmp","$rspLoc");
	 }
    }
}
