#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH  
fi

source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

# CPQ WebService calls for Quote to Order processing

export http_proxy=http://${HTTP_PROXY_HOST}:${HTTP_PROXY_PORT}
export https_proxy=https://${HTTPS_PROXY_HOST}:${HTTPS_PROXY_PORT}


#Invoke GetParts to see if the product sync happened successfully.

echo PART=$PART >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo CPQ_ADMIN_USER_NAME=$CPQ_ADMIN_USER_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo CPQ_ADMIN_USER_PASSWORD=$CPQ_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getparts.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getparts.xml

http_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getparts.xml $CPQ_URL/v2_0/receiver/parts -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getparts_response.xml)

echo "Finds Parts call completed with Response Code "$http_code

# Status of 200 is a succesfull request
if [ $http_code -eq "200" ]
then

   RECORDS_PRESENT=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getparts_response.xml '//bm:records_returned/text()')
   echo "No of records present are "$RECORDS_PRESENT
   
   if [ $RECORDS_PRESENT -ne "0" ]
	then
		echo "Product Sync Successful"
	fi
else
	echo "Unable to find parts"
	exit
fi 
#Invoke cpqInstance/v2_0/receiver/configuration - To generate quote id

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createquote.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createquote.xml

http_cq_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createquote.xml $CPQ_URL/v2_0/receiver/configuration -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createquote_response.xml)

echo "Create Quote call completed with Response Code "$http_cq_code

# Status of 200 is a succesfull request 
if [ $http_cq_code -eq "200" ]
then

   QUOTE_ID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createquote_response.xml '//bmt:id/text()')
   echo "QUOTE_ID returned is "$QUOTE_ID
   
   if [ $QUOTE_ID -ne "0" ]
	then
		echo "Create Quote Successful with quote ID "$QUOTE_ID
	fi
else
	echo "Unable to create quote"
	exit
fi  

echo QUOTE_ID=$QUOTE_ID >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisepricing.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisepricing.xml
#Using above quote Id Invoke ocFinalizePricing

http_fp_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisepricing.xml $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisepricing_response.xml)

echo "Finalise Pricing completed with response code "$http_fp_code

# Status of 200 is a succesfull request 
if [ $http_fp_code -eq "200" ]
then
 
   FP_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisepricing_response.xml '//bm:success/text()')
   echo "Finalise Pricing Response "$FP_RESP
   
   if [ "$FP_RESP" = true ]
	then
		echo "Finalise Pricing Successful"
	fi
else
	echo "Unable to Finalise Pricing"
	exit
fi 

#Using above quote Id Invoke ocFinalizeContract

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisecontract.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisecontract.xml 

http_fc_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisecontract.xml  $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisecontract_response.xml)

echo "Finalise Contract completed with response code "$http_fc_code

# Status of 200 is a succesfull request 
if [ $http_fc_code -eq "200" ]
then

   FC_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/finalisecontract_response.xml '//bm:success/text()')
   echo "FC_RESP value:::::::::"$FC_RESP
   
   if [ "$FC_RESP" = true ]
	then
		echo "Finalise Contract Successful"
	fi
else
	echo "Unable to Finalise Contract"
	exit
fi 

#Using above quote Id Invoke ocGenerateProposal

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/generateproposal.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/generateproposal.xml

http_gp_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/generateproposal.xml  $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/generateproposal_response.xml)

echo "Generate Proposal completed with response code "$http_gp_code

# Status of 200 is a succesfull request 
if [ $http_gp_code -eq "200" ]
then
  
   GP_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/generateproposal_response.xml '//bm:success/text()')
   echo "Generate Proposal is response code "$GP_RESP
   
   if [ "$GP_RESP" = true ]
	then
		echo "Generate Proposal Successful"
	fi
else
	echo "Unable to Generate Proposal"
	exit
fi

#Using above quote Id Invoke CreateOrder - Asynchronous call

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createorder.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createorder.xml

http_co_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createorder.xml  $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createorder_response.xml)

echo "Create Order return response code "$http_co_code

# Status of 200 is a succesfull request 
if [ $http_co_code -eq "200" ]
then
   CO_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createorder_response.xml '//bm:success/text()')
   echo "Create Order Response Code is  "$CO_RESP
   
   if [ "$CO_RESP" = true ]
	then
		echo "Create Order Successful"
	fi
fi

#Using above quote Id Invoke getQuote - to retrive order id

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getquote.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getquote.xml

http_getorder_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getquote.xml  $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getquote_response.xml)

echo $http_getorder_code

# Status of 200 is a succesfull request 
if [ $http_getorder_code -eq "200" ]
then
 
   ORDERNUMBER=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getquote_response.xml '//bm:ocOrderIDList/text()')
   echo "OrderIDList Returned "$ORDERNUMBER
   
   ORDER=${ORDERNUMBER%[*}  # get the part before the braces
   
   echo "Order Number Generated is "$ORDER
   
   if [ $ORDER -ne "0" ]
	then
		echo "Create Order Successful:::"$ORDER
	fi
fi

#befroe submitting order - call osm create accounts api to get account details


#befroe submitting order - call osm create accounts api to get account details
USERNAMETOKEN='UsernameToken-sample'
NUMBER=$(shuf -i 2000-65000 -n 1)
USERNAMETOKEN_NUMBER=$USERNAMETOKEN$NUMBER


echo USERNAMETOKEN_NUMBER=$USERNAMETOKEN_NUMBER >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo OSM_USER=$OSM_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo OSM_PWD=$OSM_PWD >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties


if [ $CREATE_NEW_ACCOUNT -ne "0" ]
then

	ACC_NUM=$(shuf -i 1-300 -n 1)	
	echo ACC_NUM=$ACC_NUM >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createentities.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createentities.xml

http_ce_code=$(/usr/bin/curl -u $OSM_USER:$OSM_PWD -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createentities.xml $OSM_URL -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createentities_response.xml)

echo "Create Entities is completed with response code "$http_ce_code

	# Status of 200 is a succesfull request 
	if [ $http_ce_code -eq "200" ]
	then  
	   ENTITYID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createentities_response.xml '//Id/text()')
	   echo "Generate Create Entities response code "$ID
	   
	   if [ $ENTITYID -ne "0" ]
		then
			echo "Create Entities Successful"
		fi
	else
		echo "Unable to Create Entities"
		exit
	fi
fi


	
if [ $CREATE_NEW_ACCOUNT -eq "0" ]
	then
		echo ACC_ID=$ACC_ID >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties	
else
	echo ACC_ID=$ENTITYID >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
fi

	$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity.xml

	http_ge_code=$(/usr/bin/curl -u $OSM_USER:$OSM_PWD -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity.xml $OSM_URL -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity_response.xml)

	echo "Get Entities is completed with response code "$http_ge_code

	# Status of 200 is a succesfull request 
	if [ $http_ge_code -eq "200" ]
	then
	
	   ID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity_response.xml '//Id/text()')
	   ACCOUNT_NUMBER=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity_response.xml '//osmc:accountNumber/text()')
	   ACCOUNT_NAME_ID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity_response.xml '//Name/text()')
	   ACCOUNT_NAME=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity_response.xml '//osmc:companyName/text()')
	   BILLING_PROFILE_ID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity_response.xml '//osmc:primaryBillingProfile/osmc:id/text()')
	   ADDRESS_ID=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getentity_response.xml '//osmc:primaryAddress/osmc:id/text()')
	   
	   echo "Generate Create Entities response code "$ID
	   
	   echo "ACCOUNT_NUMBER "$ACCOUNT_NUMBER
	   echo "ACCOUNT_NAME_ID "$ACCOUNT_NAME_ID
	   echo "ACCOUNT_NAME "$ACCOUNT_NAME
	   echo "BILLING_PROFILE_ID "$BILLING_PROFILE_ID
	   echo "ADDRESS_ID "$ADDRESS_ID
	   
	   if [ $ID -ne "0" ]
		then
			echo "Get Entities Successful"
		fi
	else
		echo "Unable to Get Entities"
		exit
	fi


#enrich the order with account header details

echo ID=$ID >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo ORDER=$ORDER >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo ACCOUNT_NUMBER=$ACCOUNT_NUMBER >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo ACCOUNT_NAME_ID=$ACCOUNT_NAME_ID >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo ACCOUNT_NAME=$ACCOUNT_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo BILLING_PROFILE_ID=$BILLING_PROFILE_ID >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
echo ADDRESS_ID=$ADDRESS_ID >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties


$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccount.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccount.xml

http_ua_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccount.xml  $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccount_response.xml)

echo "Update Transaction for Header level account details is completed with response code "$http_ua_code

# Status of 200 is a succesfull request 
if [ $http_ua_code -eq "200" ]
then  
   UA_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccount_response.xml '//bm:success/text()')
   echo "Generate Create Entities response code "$UA_RESP
   
   if [ "$UA_RESP" = true ]
	then
		echo "Update Account header level Successful"
	fi
else
	echo "Unable to Update Account header level "
	exit
fi


#enrich the order with account details - line level

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccountlinelevel.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccountlineitem.xml

http_uall_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccountlineitem.xml  $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccountlineitem_response.xml)

echo "Update Transaction for Line level account details is completed with response code "$http_uall_code

# Status of 200 is a succesfull request 
if [ $http_uall_code -eq "200" ]
then  
   UALL_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/updateaccountlineitem_response.xml '//bm:success/text()')
   echo "Update account Line Item Level "$UALL_RESP
   
   if [ "$UALL_RESP" = true ]
	then
		echo "Update Account Line level Successful"
	fi
else
	echo "Unable to Update Account Line level "
	exit
fi


#Using above Order Id Invoke submit order
#echo ORDER=$ORDER >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/submitorder.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/submitorder.xml

http_so_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/submitorder.xml  $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/submitorder_response.xml)

echo $http_so_code

# Status of 200 is a succesfull request 
if [ $http_so_code -eq "200" ]
then
  
   SO_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/createorder_response.xml '//bm:success/text()')
   echo "SO_RESP value:::::::::"$SO_RESP
   
   if [ "$SO_RESP" = true ]
	then
		echo "Submit Order Successful"
	fi
fi

echo "Order Processing...."
sleep 6m
echo "Check Order Sttus.."

#Using above Order Id Invoke submit order
echo ORDER=$ORDER >> $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties

$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getorderstatus.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getorderstatus.xml

http_gos_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getorderstatus.xml $CPQ_URL/v2_0/receiver/commerce/oraclecpqo -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getorderstatus_response.xml)

echo "Get Order Status Response Code is " $http_gos_code

# Status of 200 is a succesfull request 
if [ $http_gos_code -eq "200" ]
then
  
   GO_RESP=$(/usr/bin/xpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/getorderstatus_response.xml '//bm:ocStatus/text()')
    
	echo "Status Of Order Is "$GO_RESP   
	
	if [ "$SO_RESP" == "COMPLETE" ]
	then
		echo "Order Status is not Completed Successfully"
	fi
   
fi

/bin/rm $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/map.properties
#Using above Order Id Invoke GetOrderStatus