#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

source $THIS_DIR/../common/knobs
source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib
echo "Configuration read"

#-----------------------------------------------------------------------------
# Build tests


#Resolve BRM CM Port and Password

echo "Building tests"

/bin/mkdir -p $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib

if [ $RODOD_TOPOLOGY == 1 -o $RODOD_TOPOLOGY == 2 ]
then
/bin/bash -c "export MIK_ASKPASS_HOST=${SIEBEL_HOST} ; export MIK_ASKPASS_USER=${SIEBEL_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${SIEBEL_HOST_OS_USER_NAME}@${SIEBEL_HOST}:${SIEBEL_HOST_APPLICATIONS_HOME_DIR}/siebel/siebsrvr/classes/Siebel.jar $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib"
/bin/bash -c "export MIK_ASKPASS_HOST=${SIEBEL_HOST} ; export MIK_ASKPASS_USER=${SIEBEL_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${SIEBEL_HOST_OS_USER_NAME}@${SIEBEL_HOST}:${SIEBEL_HOST_APPLICATIONS_HOME_DIR}/siebel/siebsrvr/classes/SiebelJI_enu.jar $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib"
/bin/bash -c "export MIK_ASKPASS_HOST=${BRM_HOST} ; export MIK_ASKPASS_USER=${BRM_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${BRM_HOST_OS_USER_NAME}@${BRM_HOST}:${BRM_HOME_DIR}/portal/7.5/jars/pcm.jar $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib"
/bin/bash -c "export MIK_ASKPASS_HOST=${BRM_HOST} ; export MIK_ASKPASS_USER=${BRM_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY= ; /usr/bin/setsid /usr/bin/scp -o StrictHostKeyChecking=no ${BRM_HOST_OS_USER_NAME}@${BRM_HOST}:${BRM_HOME_DIR}/portal/7.5/jars/pcmext.jar $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib"

/bin/mkdir -p $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/build/classes
$JAVA_HOME/bin/javac -d $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/build/classes -classpath $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/Siebel.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcm.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcmext.jar -sourcepath $MANAGEABLE_INSTALL_TOOL_DIR/common/src-apis $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/pingTest2.java
$JAVA_HOME/bin/javac -d $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/build/classes $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/AppendDateProductXML.java

#mik_run_remote $PDC_WEBLOGIC_HOST $PDC_WEBLOGIC_HOST_OS_USER_NAME importreferencedata/importrefdata/go_import_pdc.sh $PDC_WEBLOGIC_HOST_MANAGEABLE_INSTALL_TOOL_DIR
time_millis=`date +%s`
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/build/classes AppendDateProductXML $time_millis $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/Prod_Email.xml
fi
echo "Tests built"

#-----------------------------------------------------------------------------
# Run tests
if [ $RODOD_TOPOLOGY == 1 ]
   then
	echo "Siebel only topology selected"
	flag=$(/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; /usr/bin/xpath $AIA_HOME_DIR/comms_home/source/soainfra/apps/config/AIAConfigurationProperties.xml \\\"/AIAConfiguration/SystemConfiguration/ModuleConfiguration[@moduleName=\\\\\\\"Hybrid\\\\\\\"]/Property[@name=\\\\\\\"isCloudEnabled\\\\\\\"]/text()\\\"'\"")
	if [[ $flag == *'true'* ]]    
	   then
		mik_run_remote_with_args $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME pingtests/pingtests/update_aiaconf.sh $AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR pingtests/common/knobs false
	fi
	echo "Syncing Product in Siebel"
	/bin/bash -c "export MIK_ASKPASS_HOST=${PDC_WEBLOGIC_HOST} ; export MIK_ASKPASS_USER=${PDC_WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${PDC_WEBLOGIC_HOST_OS_USER_NAME}@${PDC_WEBLOGIC_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; cd $PDC_HOME_DIR/apps/bin; export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED | ./ImportExportPricing -import -pricing $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/Prod_Email.xml -ow '\""
	$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/build/classes:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/Siebel.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/SiebelJI_enu.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcm.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcmext.jar pingTest2 $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME "$time_millis CME Email Service1"

   elif [ $RODOD_TOPOLOGY == 2 ]
   	then
		echo "Siebel and CPQ Coexistent topology selected"
	     	flag=$(/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; /usr/bin/xpath $AIA_HOME_DIR/comms_home/source/soainfra/apps/config/AIAConfigurationProperties.xml \\\"/AIAConfiguration/SystemConfiguration/ModuleConfiguration[@moduleName=\\\\\\\"Hybrid\\\\\\\"]/Property[@name=\\\\\\\"isCloudEnabled\\\\\\\"]/text()\\\"'\"")
		if [[ $flag == *'false'* ]]
		   then
			echo "Syncing Product in Siebel"
		        /bin/bash -c "export MIK_ASKPASS_HOST=${PDC_WEBLOGIC_HOST} ; export MIK_ASKPASS_USER=${PDC_WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${PDC_WEBLOGIC_HOST_OS_USER_NAME}@${PDC_WEBLOGIC_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; cd $PDC_HOME_DIR/apps/bin; export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED | ./ImportExportPricing -import -pricing $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/Prod_Email.xml -ow '\""
		        $JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/build/classes:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/Siebel.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/SiebelJI_enu.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcm.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcmext.jar pingTest2 $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME "$time_millis CME Email Service"
			mik_run_remote_with_args $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME pingtests/pingtests/update_aiaconf.sh $AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR pingtests/common/knobs true
			# Already product sync done for CPQ in importreferencedata which should be called before running pingtest
			echo "Syncing Product in CPQ"
                        ###/bin/bash -c "export MIK_ASKPASS_HOST=${PDC_WEBLOGIC_HOST} ; export MIK_ASKPASS_USER=${PDC_WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${PDC_WEBLOGIC_HOST_OS_USER_NAME}@${PDC_WEBLOGIC_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; cd $PDC_HOME_DIR/apps/bin; export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED | ./ImportExportPricing -import -pricing $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/Prod_Email.xml -ow '\""
			##########
			# CPQ order processing code goes here
			sleep 5m
			$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/cpq_quotetoorder.sh
			#########
		   elif [[ $flag == *'true'* ]]
			then
				# Already product sync done for CPQ in importreferencedata which should be called before running pingtest
				echo "Syncing Product in CPQ"
                	        ###/bin/bash -c "export MIK_ASKPASS_HOST=${PDC_WEBLOGIC_HOST} ; export MIK_ASKPASS_USER=${PDC_WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${PDC_WEBLOGIC_HOST_OS_USER_NAME}@${PDC_WEBLOGIC_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; cd $PDC_HOME_DIR/apps/bin; export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED | ./ImportExportPricing -import -pricing $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/Prod_Email.xml -ow '\""
                        	##########
	                        # CPQ order processing code goes here
				sleep 5m
				$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/cpq_quotetoorder.sh
        	                #########
				mik_run_remote_with_args $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME pingtests/pingtests/update_aiaconf.sh $AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR pingtests/common/knobs false
				echo "Syncing Product in Siebel"
                	        /bin/bash -c "export MIK_ASKPASS_HOST=${PDC_WEBLOGIC_HOST} ; export MIK_ASKPASS_USER=${PDC_WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${PDC_WEBLOGIC_HOST_OS_USER_NAME}@${PDC_WEBLOGIC_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; cd $PDC_HOME_DIR/apps/bin; export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED | ./ImportExportPricing -import -pricing $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/Prod_Email.xml -ow '\""
				$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/build/classes:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/Siebel.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/SiebelJI_enu.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcm.jar:$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/lib/pcmext.jar pingTest2 $SIEBEL_HOST $SIEBEL_ENTERPRISE_NAME "$time_millis CME Email Service"
		fi
   else
	echo "CPQ only topology selected"
	# Already product sync done for CPQ in importreferencedata which should be called before running pingtest
        flag=$(/bin/bash -c "export MIK_ASKPASS_HOST=${AIA_MIDDLEWARE_HOST} ; export MIK_ASKPASS_USER=${AIA_MIDDLEWARE_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${AIA_MIDDLEWARE_HOST_OS_USER_NAME}@${AIA_MIDDLEWARE_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; /usr/bin/xpath $AIA_HOME_DIR/comms_home/source/soainfra/apps/config/AIAConfigurationProperties.xml \\\"/AIAConfiguration/SystemConfiguration/ModuleConfiguration[@moduleName=\\\\\\\"Hybrid\\\\\\\"]/Property[@name=\\\\\\\"isCloudEnabled\\\\\\\"]/text()\\\"'\"")
	if [[ $flag == *'false'* ]]
            then
                mik_run_remote_with_args $AIA_MIDDLEWARE_HOST $AIA_MIDDLEWARE_HOST_OS_USER_NAME pingtests/pingtests/update_aiaconf.sh $AIA_MIDDLEWARE_HOST_MANAGEABLE_INSTALL_TOOL_DIR pingtests/common/knobs true
        fi
        echo "Syncing Product in CPQ"
        #/bin/bash -c "export MIK_ASKPASS_HOST=${PDC_WEBLOGIC_HOST} ; export MIK_ASKPASS_USER=${PDC_WEBLOGIC_HOST_OS_USER_NAME} ; export SSH_ASKPASS=$MANAGEABLE_INSTALL_TOOL_DIR/common/askpass_ssh.sh ; export DISPLAY=:0 ; /usr/bin/setsid /usr/bin/ssh -Y -t -t -o StrictHostKeyChecking=no ${PDC_WEBLOGIC_HOST_OS_USER_NAME}@${PDC_WEBLOGIC_HOST} \"/bin/bash -lc 'unset DISPLAY ; export MIK_KNOBS_PATH ; cd $PDC_HOME_DIR/apps/bin; export JAVA_HOME=$JAVA_HOME; echo $PDC_KEYSTORE_CRED | ./ImportExportPricing -import -pricing $MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/src/Prod_Email.xml -ow '\""
	##########
        # CPQ order processing code goes here
	sleep 5m
	$MANAGEABLE_INSTALL_TOOL_DIR/pingtests/pingtests/cpq_quotetoorder.sh
        #########
fi
