/*

 Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

 The MIT License (MIT)

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/
public class pingTest1 {
  public static void main(String[] args) throws Throwable {

    String brmHost = args[0];
    String siebelHost = args[1];
    String siebelEnterpriseName = args[2];
    int brmcmPort = Integer.parseInt(args[3]);
    String brmcmPassword = args[4];
    
    BrmProduct product = new BrmProduct();
    product.name = "RODOD Solution Test Product " + System.currentTimeMillis();
    product.amount = 24.95;
    String product_name="MFC-VOIP - CON_BASIC_ACCESS";
    //BrmUtil.createProduct("root.0.0.0.1", brmcmPassword, brmHost, brmcmPort, product);

    boolean synched = false;
    long expire = System.currentTimeMillis() + 120000;
    while (System.currentTimeMillis() < expire)
    {
      boolean exists = SiebelUtil.checkProductExists(siebelHost, 2321, siebelEnterpriseName, "SADMIN", "sadmin123", product_name);
      if (exists)
      {
        System.out.println("BRM Product named \"" + product_name + "\" \nSUCCESSFULLY synched into Siebel.\n");
        synched = true;
        break;
      }
      System.out.println("Sync of BRM Product named \"" + product_name + "\" to Siebel in progress...");
      Thread.sleep(10000);
    }
    if (!synched) {
      System.out.println("FAILED: product didn't sync.");
      System.exit(2);
    }
    
    Thread.sleep(30000);
    SiebelUtil.enrichProduct(siebelHost, 2321, siebelEnterpriseName, "SADMIN", "sadmin123", product_name);
    Thread.sleep(30000);

    SiebelAccount account = new SiebelAccount();
    account.name = "RODOD Solution Test Account";
    account.addressStreet = "123 Mallard Ln";	
    account.addressCity = "Quackersville";	
    account.addressState = "NH";	
    account.addressZipCode = "02139";	
    account.addressCountry = "USA";	
    account.contactFirstName = "RODOD Solution";	
    account.contactLastName = "Test Account"; 
    SiebelUtil.establishAccount(siebelHost, 2321, siebelEnterpriseName, "SADMIN", "sadmin123", account);
    
    SiebelSalesOrder order = new SiebelSalesOrder();
    order.accountName = account.name;
    order.productName = product_name;
    SiebelUtil.createSalesOrder(siebelHost, 2321, siebelEnterpriseName, "SADMIN", "sadmin123", order);

    boolean pass = false;     
    expire = System.currentTimeMillis() + 240000;
    while (System.currentTimeMillis() < expire)
    {
      String status = SiebelUtil.getOrderStatus(siebelHost, 2321, siebelEnterpriseName, "SADMIN", "sadmin123", order);
      System.out.println("Siebel Order Status: " + status + " ...Still Processing order...");
      if (status.equals("Complete"))
      {
        pass = true;
        break;
      }
      Thread.sleep(10000);
    }

    if (pass) {
      System.out.println("PASSED");
    } else {
      System.out.println("FAILED: order didn't complete");
      System.exit(2);
    }
  }
}
