#!/bin/bash

# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.



# TODO check shell

THIS_DIR=`/usr/bin/dirname ${BASH_SOURCE}`

trap "echo INSTALLATION FAILED" ERR
set -e
set -E
set -o pipefail

echo "Reading configuration"

if [ -z "$MIK_KNOBS_PATH" ]
then
  MIK_KNOBS_FILE=$THIS_DIR/../common/knobs
else
  MIK_KNOBS_FILE=$THIS_DIR/../../$MIK_KNOBS_PATH
fi

source $MIK_KNOBS_FILE

source $MANAGEABLE_INSTALL_TOOL_DIR/common/mik_lib

source $MANAGEABLE_INSTALL_TOOL_DIR/common/media_map

echo "Configuration read"

#-------------------------------------------------------------------------------
# Get AIAMW topology information
$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/prepare_aia_topology.sh
source $MANAGEABLE_INSTALL_TOOL_DIR/$AIA_SCRIPT_MODULE_NAME/aiafp/aia_topology

cp $AIA_HOME_DIR/comms_home/source/soainfra/apps/config/AIAConfigurationProperties.xml $AIA_HOME_DIR/comms_home/source/soainfra/apps/config/AIAConfigurationProperties.xml.backup
flag=$1
sed -i 's/\(<[^"]*"isCloudEnabled">\)\([^<]*\)\(<[^>]*\)/\1'${flag}'\3/g' $AIA_HOME_DIR/comms_home/source/soainfra/apps/config/AIAConfigurationProperties.xml
#sed -i -- 's/{participatingapplications.cpq.server.host}/slc03gcd.us.oracle.com/g' $AIA_HOME_DIR/comms_home/source/soainfra/apps/config/AIAConfigurationProperties.xml


echo "CPQ flag set to ${flag} in AIAConfiguration..."

echo "Committing metadata"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties
echo AIA_HOME_DIR=$AIA_HOME_DIR >> $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties
echo AIA_INSTANCE_NAME=$AIA_INSTANCE_NAME >> $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/UpdateMetaDataConf.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/UpdateMetaDataConf.xml
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties
/bin/bash -c "source $AIA_WEBLOGIC_DOMAIN_HOME_DIR/soa/aia/bin/aiaenv.sh ; $AIA_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR/oracle_common/modules/thirdparty/org.apache.ant/1.9.8.0.0/apache-ant-1.9.8/bin/ant -f $AIA_MIDDLEWARE_WEBLOGIC_MIDDLEWARE_HOME_DIR/soa/aiafp/Install/AID/AIAInstallDriver.xml -DDeploymentPlan=$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/UpdateMetaDataConf.xml -DUsername=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER -DPassword=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD -DPropertiesFile=$AIA_WEBLOGIC_DOMAIN_HOME_DIR/soa/aia/bin/AIAInstallProperties.xml"

echo "Metadata committed"
echo "ReloadProcess started in AIA"

/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER >> $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties
echo AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD=$AIA_MIDDLEWARE_WEBLOGIC_ADMIN_USER_PASSWORD >> $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties
$JAVA_HOME/bin/java -cp $MANAGEABLE_INSTALL_TOOL_DIR/common template -map=$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties -in=$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/reloadprocess_request.xml.template > $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/reloadprocess_request.xml
/bin/rm -f $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/importrefdata/map.properties

reload_status_code=$(/usr/bin/curl -X POST -H "Content-Type: text/xml;charset=UTF-8" -H "SOAPAction: \"process\"" --data-binary \@$MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/reloadprocess_request.xml  http://$AIA_HTTPFRONTEND_HOST:$AIA_HTTPFRONTEND_PORT/soa-infra/services/default/ReloadProcess/reloadconfigurationprocess_client_ep -w '%{http_code}' -o $MANAGEABLE_INSTALL_TOOL_DIR/$IMPORT_REFERENCE_SCRIPT_NAME/data/reloadprocess_response.xml)
if [[ $reload_status_code -ge 200 && $reload_status_code -lt 300 ]]
then
   echo "ReloadProcess completed in AIA"
else
   echo "ReloadProcess failed in AIA"
   exit 1
fi
