#!/usr/local/bin/perl
# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.

# The MIT License (MIT)

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


#11/30/2012  ZKUNJU         Created
#04/04/2013 RPRABAKA  Replace sed commands with file handler to make platform independent

use File::Basename;
my $dirname = dirname(__FILE__);
$commonInfo="commoninfo.properties";
$suiteInfo="suite_install.properties";
require "$commonInfo";
&fetch_UimLocation();
&configurePWLC();

sub fetch_UimLocation {
        open(INSTALL_PROP,"$suiteInfo");

        while(<INSTALL_PROP>) {
                chomp($_);
                if($_ =~ /uim_base.dir/) {
                        $uim_loc = (split("=",$_))[1];
                        print "UIM LOCATION IS  $uim_loc\n";
                }
        }
        close(INSTALL_PROP);
	
}

sub configurePWLC {
        print "Configuring PWLC \n";
        $javaHome=$JAVA_HOME;
        $mwHome=$MIDDLEWARE_HOME;
        $pwlcLocation=$dirname."/../../";
        $uim_location=substr $uim_loc, 1, -1;        

        $pwlcVariableFile=$pwlcLocation."/scripts/common_variables.sh";
        print "Updating $pwlcVariableFile \n";
        open(VAR,"$pwlcVariableFile");
        open(TMPVAR,">tmp_pwlcVariableFile");
        while(<VAR>) {
                chomp($_);
                if($_=~m/^JAVA_HOME/) {
                        $_="JAVA_HOME\=$javaHome";
                }
                if($_=~m/^MIDDLEWARE_HOME/) {
                        $_="MIDDLEWARE_HOME\=$mwHome";
                }
                if($_=~m/^PLATFORM_WLCOMMANDS_DIR/) {
                        $_="PLATFORM_WLCOMMANDS_DIR\=$pwlcLocation";
                }
                if($_=~m/^COMMON_INFO_LOC/) {
                        $_="COMMON_INFO_LOC\=$commonInfo";
                }
                if($_=~m/^UIM_LOCATION/) {
                        $_="UIM_LOCATION\=$uim_location";
                }

                print TMPVAR "$_\n";
        }
        rename(tmp_pwlcVariableFile,$pwlcVariableFile);
        print "Updated $pwlcVariableFile \n";

        system("mkdir -p ".$pwlcLocation."/logs");
        $pwlcLogConfig=$pwlcLocation."/scripts/logging.config";
        print "Updating $pwlcLogConfig \n";
        $pwlcLogLocation=$pwlcLocation."/logs/PWLC%u.log";
        open(CFG,"$pwlcLogConfig");
        open(TMPCFG,">tmp_pwlcLogConfig");
        while(<CFG>) {
                chomp($_);
                if($_=~m/^java.util.logging.FileHandler.pattern/) {
                        $_="java.util.logging.FileHandler.pattern\=$pwlcLogLocation";
                }
                print TMPCFG "$_\n";
        }
        rename(tmp_pwlcLogConfig,$pwlcLogConfig);
        print "Updated $pwlcLogConfig \n";
        print "Configured PWLC \n";
        print "PWLC Location = $pwlcLocation \n";
        print "PWLC Logging configuration = $pwlcLogConfig \n";
        print "PWLC Log location = $pwlcLocation"."/logs \n";
}
